//
// ConsolidatedView - Container and API for Consolidated Views and Tables. Read/Write/Interface for display and edits.
//
// Data Defined in "TabData.js". 
//		BIG NOTE:  Tab# == Module#.   SubTab# == Category#
// ***** Auxiliary *************************************************************
function onConViewFinalView(id)		{ CurrentConView.updateFinalView(id); };
function onConViewFinal(a, b)		{ CurrentConView.onFinal(a, b); };
function onConViewExclude(a, b)		{ CurrentConView.onExclude(a, b); };
function onConViewFilter(a, b)		{ CurrentConView.onFilter(a, b); };
function onConViewSort(a, b)		{ CurrentConView.onSort(a, b); };
function onConViewFill(a, b)		{ CurrentConView.onFill(a, b); };
function onConViewPrintView(f)		{ CurrentConView.printView(f); };
function onConViewExport(a, b)		{ CurrentConView.onExport(a, b); };
function onConViewClearList()		{ CurrentConView.onClearList(); };
function onConViewShowReq(a, b)		{ CurrentConView.onShowReq(a, b); };
// *****************************************************************************
// Entries for Filter Rule
var FilterRule = 	[	"Match Text",	// default selected
						"Greater Than",
						"Greater Than or Equal To",
						"Equal To",	// default selected
						"Not Equal To",
						"Less Than",
						"Less Than or Equal To"
						];
// Entries for Filter Column
var FilterColumn = [	"All Columns",
						"Category",
						"No.",
						"Requirement",	// default selected
						"OWQM",
						"CCS",
						"ESM",
						"PHS",
						"CM",
						"Components",
						"Average",
						"Final Rating"
						];

function ConView() {

var self = this;						/* because "this" doesn't work through onclick callbacks */
this.conData = new Array();				/* Array of TabData for each component.   Shortname/TabData */
this.conFileNames = new Array();		/* File names of loaded components. Same index as conData. Just for user msgs. */
this.fileQueue = new Array();			/* Files (with data) selected, but not yet loaded in TabData */
this.fullList = new Array();			/* List of rows of wvData. All of them. */
this.showList = new Array();			/* List of rows of wvData showed to user. After filters applied */
this.filter = new Array();				/* Active Filters */
this.sortOrder = new Array();			/* Active Filters */
this.printViewRestore = new Array();	/* Colors and Styles outside of print view */
this.nrContainer = "nonRequirementsView";/* default. define-able in Create. Table of non-requirements data. */
this.wvContainer = "workingView";		/* default. define-able in Create */
this.addingFile = false;				/* Adding semiphore. One at a time! */
this.filesListView = "filesListView";	/* 'select' container for list of files loaded */
this.gateBtn = null;					/* Object to enable once creation complete */
	
// ***************************************************************************************
// Public API
// ***************************************************************************************
this.Create = function( gateBtn )
{
	this.destroy();
	this.gateBtn = gateBtn;
	this.filter[0] = 0;			// Rule
	this.filter[1] = "";		// Value
	this.filter[2] = 3;			// Column
	this.sortOrder["column"] = 1;
	this.sortOrder["direction"] = "down";
	
	// If files are loaded, release the gate immediate.  Need to rename this routine.
	this.onDataLoad();
	
	// Nothing more until user queues files.
}
//----------------
// A single file has been selected by user.
//
this.queueFile = function( name, data )
{
	this.fileQueue[name] = data;	// add file to queue
	this.addFile();					// if first, get it going.
}
//----------------
// Add next file in queue.  Trigger 'onDataLoad' for any add attempt, succeed or fail.
//
this.addFile = function()
{
	if ( (! this.addingFile) && objectLength(this.fileQueue) )
	{
		// pop
		var name = firstKey(this.fileQueue);	// will be there. just checked length.
		var data = this.fileQueue[name];
		delete this.fileQueue[name];
		
		var ok = false;
		var tmpTabData = new TabData();	// assign directly to conData, else obj dissapears on scope exit.
		var shortname = tmpTabData.getShortNameFromFileData ( data );
		if ( ! shortname )
		{
			alert( "File Contents of '" + name + "' are invalid or not formatted for the Consolidated Files area." );
		} else if ( typeof(this.conData[shortname]) != "undefined" ) {
			alert( "A file for component '" + shortname + "' has already been loaded. You can only load one." );
		} else {
			ok = true;
		}
		
		if ( ok )
		{
			document.getElementById(this.filesListView).disabled = true;
			this.addingFile = true;
			this.conData[shortname] = new TabData();
			this.conData[shortname].Load(shortname, function(){self.onDataLoad();}, data);
			this.conFileNames[shortname] = name;
		} else {
			this.onDataLoad();	// Still allow obj to cycle to next or use others that did work.
		}
	}
}

//----------------
// addFile complete. Either by failure or TabData has attached its script(s) and loaded component data.
//
this.onDataLoad = function()
{
	this.addingFile = false;

	if ( objectLength(this.fileQueue) )
	{
		this.addFile();	// next!
	} else {
		// All queued files loaded. Update and release.
		
		// Update File Status.
		var listView = document.getElementById(this.filesListView);
		listView.options.length = 0;
		listView.disabled = false;
		listView.blur();
		for ( var cdKey in this.conData )
		{
			var a = document.createElement('option');
			a.innerHTML = cdKey;
			listView.appendChild(a);
		}
		
		// Clear any loaded views.
		this.fullList = new Array();

		if ( objectLength( this.conData ) )
		{
			this.updateWorkingView(this.wvContainer);
			try {
				$(function() { $('textarea').autogrow('textarea'); });	// Autogrow all newly created textarea boxes.
			} catch(e2) {
				; // ie8 and maybe 9 does not support this
			}
			if ( this.gateBtn )
			{
				this.gateBtn.disabled = false;
				this.gateBtn.blur();
			}
		}
		/* don't paint with a Switch call. certain styles need to be on-screen when moved/shown. */
	}
};

//----------------
// Is the requested component loaded into the consolidated view?
//
this.isComponentLoaded = function( shortname )
{
	var loaded = false;
	if ( (objectLength(this.conData)) && (typeof(shortname)=="string") )
	{
		for ( var cdKey in this.conData )
		{
			if ( cdKey == shortname )
				loaded = true;
		}
	}
	return loaded;
};

//----------------
// return TabData obj
//
this.getData = function( shortname )
{
	if ( this.isComponentLoaded(shortname) )
		return this.conData[shortname];
	else
		return null;
};

//----------------
// return originating filename of loaded component.
//
this.getFileName = function( shortname )
{
	if ( this.isComponentLoaded(shortname) )
		return this.conFileNames[shortname];
	else
		return null;
};

// ***************************************************************************************
/* private */
// ***************************************************************************************
this.destroy = function()
{
	//if ( this.hasBeenCreated )
	{
		//var myNode = document.getElementById(this.tabContainer);
		//while (myNode.firstChild) {
		//	myNode.removeChild(myNode.firstChild);
		//}
	}
};

//----------------
// Make the Tool Tip Title.  Since the actual title's sitting on screen right beside it, we have chosen to make the TTTitle
// a string of "module-category".  However, questions in Consolidated exist beyond a single component, and hence beyond a defined
// set (or array) of module/category.  For this, grab the Modules array from the first answer's component.  This will work 100%
// in the way EPA is setting up their modules currently.  If in the future they different modules for different 
// components *OTHER* than STR, then this could show a potentially confusing thing, but that's it.
//
this.makeTTTitle = function( rData )
{
	var ttTitle = rData.title; 	// fallback.
	var done = false;
	for ( var comp in rData.answers )
	{
		if ( ! done )
		{
			var tData = this.conData[comp];
			if ( tData )
			{
				var m = tData.getModules();
				ttTitle = m[rData.module][0] + " - " + m[rData.module][1][rData.category-1];
				done = true;
			}
		}
	}
	return ttTitle;
}
//----------------
// Get Category Abbreviation. Questions in Consolidated exist beyond a single component. For this, grab the Module Abbreviation
// array from the first answer's component.  This will work 100% in the way EPA is setting up their modules currently.  
// If in the future they different modules for different components *OTHER* than STR, then this could start showing invalid data.
//
this.getCategoryAbbreviation = function( rData )
{
	var abbr = "" + rData.category; // fallback.
	var done = false;
	for ( var comp in rData.answers )
	{
		if ( ! done )
		{
			var tData = this.conData[comp];
			if ( tData && rData.category )
			{
				abbr = tData.modulesAbbrs[rData.module][1][rData.category - 1];
				done = true;
			}
		}
	}
	return abbr;
}


//----------------
// Update the Non-Requirements table (assuming it's on screen.) (far less complicated than the other views)
//
this.updateNonRequirementsView = function( dID )
{
	var s = "";
	var nrdiv = document.getElementById(dID);
	nrdiv.innerHTML = "";
	//
	// For Each Component, make a header. For Each Module, make a table.
	//
	for ( compName in this.conData )
	{
		if ( typeof(this.conData[compName]) == "object" )	// can be zero/null. just wasn't loaded.
		{
			s += "<h2 class='nonReqViewHeader'> " + compName + "</h2>";
			s += "<table id='nrd" + compName + "' class='nonReqView'>";
			s += "<tr>";
			var colLabels = ["Num", "Module", "Requirement Summary", "Question", "Answer"];
			for (var n in colLabels )
			{
				s += "<td><b>" + colLabels[n] + "</b></td>";
			}
			s += "</tr>";

			var tData = this.conData[compName];
			var questions = tData.getAllQuestions();
			for ( uqi in questions )
			{
				var q = questions[uqi];
				var listUQI = parseInt(uqi);	// ensure number in case we add 100 for collision.
				var type = q.type;
				var rowcount = 0;
				
				if ( type == "req" ) {
					; // ignore
				} else if ( type.search("radiotext") == 0 ) {
					rowcount = 1 + q.textLabels.length;
				} else if ( type.search("checkboxestext") == 0 ) {
					rowcount = 1 + q.textLabels.length;
				} else if ( type.search("text") == 0 ) {
					rowcount = q.textLabels.length
				}
				if ( rowcount )
				{
					var catName = tData.modules[q.module][0];		// if (!tData) CommonModules[q.module][0];
					s += "<tr><td rowspan="+rowcount+">" + q.uqi + "</td>";
					s += "<td rowspan="+rowcount+">" + catName + "</td>";
					s += "<td rowspan="+rowcount+">" + stripQuotes(q.description).substring(0, 512); + "</td>";	// end <tr> later.
				}

				
				if ( type == "req" )
				{
					; // ignore.
				}
				else if ( type.search("radiotext") == 0 )
				{
					s += "<td>" + q.radioLabel + "</td><td>" + tData.getAnswerText("radio" + q.uqi) + "</td></tr>";
					var tx = q.textLabels.length;
					for ( var i=0 ; i < tx ; i++ )
					{
						s += "<tr><td>" + q.textLabels[i] + "</td><td>" + tData.getAnswerText("text" + q.uqi + "_" + (i+1)) + "</td></tr>";
					}
					rowcount++;
					rowcount++;
					// todo:  2,3,4...
				}
				else if ( type.search("checkboxestext") == 0 )
				{
					s += "<td>" + q.checkLabel + "</td><td>" + tData.getAnswerText("check" + q.uqi) + "</td></tr>";
					var tx = q.textLabels.length;
					for ( var i=0 ; i < tx ; i++ )
					{
						s += "<tr><td>" + q.textLabels[i] + "</td><td>" + tData.getAnswerText("text" + q.uqi + "_" + (i+1)) + "</td></tr>";
					}
					rowcount++;
					rowcount++;
					// todo:  2,3,4...
				}
				else if ( type.search("text") == 0 )
				{
					var tx = q.textLabels.length;
					for ( var i=0 ; i < tx ; i++ )
					{
						if ( i > 0 )
							s += "<tr>";
						s += "<td>" + q.textLabels[i] + "</td><td>" + tData.getAnswerText("text" + q.uqi + "_" + (i+1)) + "</td></tr>";
					}
					rowcount++;
				}
			}
			s += "</table>";
		}
	}
	nrdiv.innerHTML = s;
	nrdiv.blur();
}

//----------------
// Update the Working View table (assuming it's on screen.)
//
this.updateWorkingView = function( tID )
{
	this.updateComboBoxes();
	var table = document.getElementById(tID);
	//
	// Clear Out Previous Table. Leave Invisible Row alone.  (The "Header" table is independent.
	for(var r = table.rows.length ; r > 1 ; r--)
	{
		table.deleteRow(1);
	}
	//
	// Gather Data.
	var wvData = this.updateShowList(false);
	var wvKeys = this.applySort( wvData );
	//var wvKeys = sortedKeys(wvData, true).reverse();	// Sort to user-view.
		
	for ( k in wvKeys )
	{
		var uqi = wvKeys[k];
		var rData = wvData[uqi];
		var row1 = table.insertRow(1);
		//
		// This loop just knows the columns of the WV Table.  TODO: Get that dynamic with a cool alogrithm.
		//
		for ( var i=0 ; i <= 13 ; i++ )
		{
			var cell = row1.insertCell(i);
			switch (i)
			{
				case 0: 	cell.className = rData.comGroup.replace("*", "Star");  // "C*" -> "CStar", "C" -> "C".
							cell.innerHTML = rData.comGroup;
							break;
				case 1:		/* cell.innerHTML = rData.category; */
							cell.innerHTML = this.getCategoryAbbreviation(rData);
							break;
				case 2:		cell.innerHTML = rData.uqi;
							break;
				case 3:		var ttID = "toolTip";
							var ttt = this.makeTTTitle(rData);
							var ttTitle = stripQuotes(ttt);
							var ttText = stripQuotes(rData.description).substring(0, 127);
							var infoLink = 
"<a href'#' onMouseOver=\"ddm.pop(event, 'toolTip', '"+ttTitle+"', '"+ttText+"')\" onMouseOut=\"ddm.close()\">"
// "<div id='"+ttID+"' onMouseOver='ddm.cancelCloseTime()' onMouseOut='ddm.closeTime()' style='visibility:hidden;'><p>WHAT UP WHAT UP</p></div>";

	//			"<a id='info' class='info' onclick='onInfo(44);' " +
	//			"onmouseover=\"popTip(event,'info', 'info', 'info')\">
	+ " <img src='img/question_mark.png' alt='info' height='16' width='16'/></a>";
							cell.innerHTML = infoLink + rData.title;
							cell.style.textAlign="left";
							break;
				case 4: case 5: case 6: case 7: case 8: case 9:
							var cellComponent = i-4;
							var cellComponentName = ComponentsIndex[cellComponent];
							if ( ! this.compatibleComGroup(rData, cellComponent) )
							{
								cell.className = "black"; // then blacked out
							} else {
								var a = rData.answers[cellComponentName];
								// If a real value, it's also a link to a tinybox.
								if ((typeof(a) == "undefined") || (! a.length))
								{
									cell.innerHTML = "-";
								} else {
									/*
									// Previous Requirement:  Give any answered field a clickable "star" icon.
									cell.style.position = "relative";
									var infoLink = "<a style='position: absolute; top:0px; left:0px;' " +
									"onMouseOver=\"ddm.pop(event, 'toolTip', " +
										"'" + cellComponentName + "&rsquo;s rating for requirement " + rData.uqi + "' ," +
										"' Click to view entire text and full component responses. ')\" " +
									"onMouseOut=\"ddm.close()\"" + 
									"onClick=\"ddm.close(); onConViewShowReq(" +rData.uqi+ "," + cellComponent + ");\">" + 
									" <img src='img/question_mark.png' alt='info' height='14' width='14'/></a>";
									cell.innerHTML += infoLink + a;
									*/
									// New Requirement: Any answered field is clickable, but only additional-text-containing has "star" icon.
									//var additionalDetails = null; rData.getAnswer("text" + rData.uqi + "_1");
									var starIcon = "";
									var additionalDetails = (this.conData[cellComponentName]) ? 
															this.conData[cellComponentName].getAnswer("text" + rData.uqi + "_1") : "";
									if ( additionalDetails && additionalDetails.length )
									{
										var starIcon = "<a style='position: absolute; top:0px; left:4px;'>" +
											" <img src='img/asterisk.png' alt='asterisk' height='6' width='6'/></a>";
									}
									var infoLink = "<a href='#' style='display:block; width:100%' " +
										"onMouseOver=\"ddm.pop(event, 'toolTip', " +
										"'" + cellComponentName + "&rsquo;s rating for requirement " + rData.uqi + "' ," +
										"' Click to view entire text and full component responses. ')\" " +
										"onMouseOut=\"ddm.close()\"" + 
										"onClick=\"ddm.close(); onConViewShowReq(" +rData.uqi+ "," + cellComponent + ");\">" + 
										a + "</a>";
									
									cell.className = "clickable";
									cell.style.position = "relative";
									cell.innerHTML += starIcon + infoLink;
								}
							}
							break;
				case 10:	cell.innerHTML = rData.numComponents;
							break;
				case 11:	cell.innerHTML = rData.average;
							break;
				case 12:	var tID = "final" + rData.uqi;
							cell.innerHTML = "<input id='"+tID+"' type='text' name='finalrating' value='" + rData.final + "'" +
							" style='width:50%; text-align:center;' " +
							" onblur=\"onConViewFinal('"+tID+"', "+rData.uqi+");\" " + 
							" />";
							break;
				case 13:	var tID = "exclude" + rData.uqi;
							var checked = (rData.exclude) ? " checked " : "";
							cell.innerHTML = "<input id='"+tID+"' type='checkbox' " + checked +
							" style='margin:auto; display:block;' " + 
							" onclick=\"onConViewExclude('"+tID+"', "+rData.uqi+");\" " +
							" /></div>";	// ending div here?????
							break;
				default:
							cell.innerHTML = "error";
							break;						
			}
		}
	}
	table.blur();
	this.updateCategoryLegend(document.getElementById("workingViewCategoryLegend"));
}

//----------------
// Update the (non-editable) Final View table (assuming it's on screen.)
//
this.updateFinalView = function( tID )
{
	var table = document.getElementById(tID);
	//
	// Clear Out Previous Table. Leave Invisible Row alone.  (The "Header" table is independent.
	for(var r = table.rows.length ; r > 1 ; r--)
	{
		table.deleteRow(1);
	}
	//
	// Gather Data.
	var wvData = this.updateShowList(true);
	var wvKeys = this.applySort( wvData );
	//var wvKeys = sortedKeys(wvData, true).reverse();	// Sort to user-view.
		
	for ( k in wvKeys )
	{
		var uqi = wvKeys[k];
		var rData = wvData[uqi];
		var row1 = table.insertRow(1);
		//
		// This loop just knows the columns of the Final Table.  TODO: Get that dynamic with a cool alogrithm.
		//
		for ( var i=0 ; i <= 9 ; i++ )
		{
			var cell = row1.insertCell(i);
			switch (i)
			{
				case 0:		cell.innerHTML = this.getCategoryAbbreviation(rData);
							cell.className = "left";
							break;
				case 1:		cell.innerHTML = rData.uqi;
							break;
				case 2:		cell.innerHTML = rData.title;
							cell.style.textAlign="left";
							cell.style.padding="3px";
							cell.style.paddingLeft="15px";
							break;
				case 3: case 4: case 5: case 6: case 7: case 8:
							var cellComponent = i-3;
							if ( ! this.compatibleComGroup(rData, cellComponent) )
							{
								cell.className = "black"; // then blacked out
							} else {
								var a = rData.answers[ComponentsIndex[cellComponent]];
								cell.innerHTML = ((typeof(a) != "undefined") && (a.length)) ? a : "-";
							}
							break;
				case 9:		cell.className = "right";
							cell.innerHTML = rData.final;
							break;
			}
		}
	}
	table.blur();
	this.updateCategoryLegend(document.getElementById("finalViewCategoryLegend"));
}

//----------------
// Update the (non-editable) Summary View table (assuming it's on screen.)
//
this.updateSummaryView = function( tID )
{
	var table = document.getElementById(tID);
	//
	// Clear Out Previous Table. Leave Invisible Row alone.  (The "Header" table is independent.
	for(var r = table.rows.length ; r > 1 ; r--)
	{
		table.deleteRow(1);
	}
	//
	// Gather Data.
	var wvData = this.updateShowList(true);
	var wvKeys = this.applySort( wvData );
		
	for ( k in wvKeys )
	{
		var uqi = wvKeys[k];
		var rData = wvData[uqi];
		var row1 = table.insertRow(1);
		//
		// This loop just knows the columns of the Summary Table.  TODO: Get that dynamic with a cool alogrithm.
		//
		for ( var i=0 ; i <= 6 ; i++ )
		{
			var cell = row1.insertCell(i);
			switch (i)
			{
				case 0:		cell.innerHTML = "<b>" + this.getCategoryAbbreviation(rData) + "</b>";
							cell.className = "left";
							break;
				case 1:		cell.innerHTML = rData.uqi;
							break;
				case 2:		cell.innerHTML = rData.title;
							cell.style.textAlign="left";
							cell.style.padding="3px";
							cell.style.paddingLeft="15px";
							break;
				case 3:		cell.innerHTML = rData.description;
							cell.style.textAlign="left";
							cell.style.padding="3px";
							cell.style.paddingLeft="15px";
							break;
				// columns 4,5 and 6 are just blank.  But 6 has a border in printview.
				case 6:		cell.className = "right";
							// fall through
				default:
							cell.innerHTML = "&nbsp;";
							break;
			}
		}
	}
	table.blur();
	this.updateCategoryLegend(document.getElementById("summaryViewCategoryLegend"));
}

//----------------
// update the category legend for a given table. @clElem is the dom object.
// Put up a legend for "non STR" categories if any non-STR modules are loaded. (almost always).
// Put up a legend for "str" categories when STR is loaded.
// This configuration is just because the non-STR ones all have the same categories.
//
this.updateCategoryLegend = function ( clElem, module )
{
	var clStr = "";	// html.
	var legendData = {};
	for ( var conKey in this.conData )
	{
		if ( conKey != "STR" )
		{
			legendData["notSTR"] = [];
			legendData["notSTR"][0] = this.conData[conKey].modules;								// Modules
			legendData["notSTR"][1] = this.conData[conKey].modulesAbbrs;						// Module Abbreviations
			legendData["notSTR"][2] = 3;														// Cat Index of Req. (Magic #. fix.)
			legendData["notSTR"][3] = "Component Functional Requirements Categories: ";			// Bolded Header text.
		} else {
			legendData["yesSTR"] = [];
			legendData["yesSTR"][0] = this.conData[conKey].modules;								// Modules.
			legendData["yesSTR"][1] = this.conData[conKey].modulesAbbrs;						// Module Abbreviations
			legendData["yesSTR"][2] = 2;														// Cat Index of Req. (Magic #. fix.)
			legendData["yesSTR"][3] = "Technical Requirements Categories: ";					// Bolded Header text.
		}
	}
	for ( var lKey in legendData )
	{
		if ( clStr.length )
			clStr += "<br/>";	// on next iter/line.
			
		var modNames = legendData[lKey][0];
		var modAbbrs = legendData[lKey][1];	// Abbreviations = Categories
		if ( modNames && (typeof(modNames) != "undefined") && modAbbrs )
		{
			var reqMods 		= modNames[legendData[lKey][2]][1];		// Req modules are the categories listed.
			var reqModsAbbrs 	= modAbbrs[legendData[lKey][2]][1];		// Req modules are the categories listed.
			clStr += "<strong>" + legendData[lKey][3] + "</strong>";
			for (var n=1 ; n <= reqMods.length ; n++)
			{
				clStr += "" + reqModsAbbrs[n-1] + "=" + reqMods[n-1];
				if ( n < reqMods.length )
					clStr += ", ";
			}
			clStr += ".";
		}
	}
	if ( clElem )
	{
		clElem.innerHTML = clStr;
	}
}
//----------------
// Create CSV file output.  The raw string to be handled.
//	@final:  if true, summary. if false, final.
//
this.createCSV = function( tID, summary )
{
	var delim = ",";
	var regx = new RegExp(delim, 'g');	// globally replace. (multiple instances)
	var csvData = pageview_getCurrentPageName() + "\r\n\r\n";	// Give it a title.
	//
	// Gather Data. (operates on showing page.)
	//
	var wvData = this.updateShowList(true);
	var wvKeys = this.applySort( wvData );
	//
	// Get Header, then all Data Rows.  Straight from the DOM table.  Why not?
	//
	for ( var headerData=0 ; headerData < 2 ; headerData++ )
	{
		var tableID = ( headerData == 0 ) ? tID + "Header" : tID;
		var table = document.getElementById(tableID);
		var rowIdx = (summary) ? 1 : 2;	 // Jump  "invisible headers" on final, and "ratings" on final header.
		while ( table && table.rows[rowIdx] )
		{
			var cells = table.rows[rowIdx].cells;
			var i=0;
			while ( cells[i] )
			{
				var content = cells[i].textContent || cells[i].innerText || cells[i].innerHTML;
				content = content.trim();
				csvData += content.replace(regx, "-").replace("&nbsp;","").replace("<b>","").replace("</b>","") + delim;
				i++;
			}
			csvData += "\r\n";
			rowIdx++;
		}
	}
	return csvData;
}
//----------------
// Create CSV file output -- Non-requirements Template.
//	This feature came much later, hence safer to break this out.
//  Grab the data straight from the DOM table (match other export & cleaner than pre-loading an array on paint).
//	Return string for csv file.
//
this.createCSV_NonReq = function()
{
	var csvData = pageview_getCurrentPageName() + "\r\n\r\n";	// Give it a title.
	var nrdiv = document.getElementById(this.nrContainer);
	var kids = nrdiv.childNodes;
	for ( var k=0; k < kids.length; k++ )
	{
		var kid = kids[k];

		if ( kid.tagName == "H2" )
		{
			csvData += "\r\n" + kid.innerHTML + "\r\n";
		}
		else if ( kid.tagName == "TABLE" )
		{
			var table = kid;
			var delim = ",";
			var regx = new RegExp(delim, 'g');	// globally replace. (multiple instances)
			var lastRow = new Array();			// handle row-spans.
			for ( var rIdx=0 ; rIdx < table.rows.length ; rIdx++ )
			{
				var cells = table.rows[rIdx].cells;
				var rowLen = Math.max(lastRow.length, cells.length);	// "csv cells" need to "un-compact" row-spanned cells.
				var nSpanned = rowLen - cells.length;				// number of front-end cells that are spanned and omitted.
				for ( var spanIdx=0 ; spanIdx < nSpanned ; spanIdx++ )
				{
					// add the spanned cell data from the last iteration.
					csvData += lastRow[spanIdx] + delim;
				}
				for ( var cIdx=0 ; cIdx < cells.length ; cIdx++ )
				{
					// add the non-spanned cell data from this iteration.
					var content = cells[cIdx].textContent || cells[cIdx].innerText || cells[cIdx].innerHTML;
					content = content.trim();
					content = content.replace(regx, "-").replace("&nbsp;","").replace("<b>","").replace("</b>","");
					csvData += content + delim;
					lastRow[nSpanned + cIdx] = content;
				}
				csvData += "\r\n";
			}
		} else { ;
			alert ("Unexpected tagName on this page in createCSV_NonReq:  " + kid.tagName );
		}
	}
	return csvData;
}
// ----------------------------------------------------------------------
// Bring in the data. Apply filters. Return ShowList.
//
this.updateShowList = function( fFinalView )
{
	// listItem: CatType, Category, UQI, Title, [ratings], number-of-components, average, final, excluded
	if ( this.fullList.length < 1 )
	{
		// Create Full List. 1 time.
		//
		for ( compName in this.conData )
		{
			if ( typeof(this.conData[compName]) == "object" )	// can be zero/null. just wasn't loaded.
			{
			var tData = this.conData[compName];
			var questions = tData.getAllQuestions();
			for ( uqi in questions )
			{
				var q = questions[uqi];
				var listUQI = parseInt(uqi);	// ensure number in case we add 100 for collision.
				// Filter Requirements!  These views are requirements only.
				if ( q.type == "req" )
				{
					if ( ! this.fullList.hasOwnProperty(listUQI) )
					{
						this.fullList[listUQI] = new cvItem(q);			// add
					} else if ( uqi >= TabData_MinCustomUQI ) {
						// resolve collision and add.
						while ( this.fullList.hasOwnProperty(listUQI) )
						{
							listUQI += 100;
						}
						this.fullList[listUQI] = new cvItem(q);			// and add
						this.fullList[listUQI].uqi = listUQI;
					}
					this.fullList[listUQI].answers[compName] = tData.getAnswer("radio" + q.uqi);	// tData is using "its" uqi.
				}
			}
			}
		}
		//
		// Average and Final.   Average = average of non-zero answers.  Final = maximum rating.
		//
		for ( uqi in this.fullList )
		{
			var flItem = this.fullList[uqi];
			var total = 0;
			for ( compName in flItem.answers )
			{
				var answer = flItem.answers[compName];
				if ( (typeof(answer)!="undefined") && (answer.length) && (parseInt(answer) > 0) )
				{
					flItem.numComponents++;
					total += parseInt(answer);
					flItem.average = Math.round( 100 * total / flItem.numComponents ) / 100;
					flItem.calculatedFinal = Math.max(flItem.calculatedFinal, parseInt(answer));
					flItem.final = flItem.calculatedFinal;
				}
			}
		}
	}
	//
	// Apply Dynamic Filters if 'workingViews'.  Apply only 'exlude' if 'finalViews'.
	//
	this.showList = new Array();
	for ( uqi in this.fullList )
	{
		if ( fFinalView )
		{
			if ( ! this.fullList[uqi].exclude )
				this.showList[uqi] = this.fullList[uqi];
		}
		else
		{
			if ( this.passesFilters(this.fullList[uqi]) )
				this.showList[uqi] = this.fullList[uqi];
		}
	}
	return this.showList;
}

// ----------------------------------------------------------------------
// fill in combo boxes. The filter ones.
//
this.updateComboBoxes = function()
{
	var r = document.getElementById("filterRule");
	var oCount = r.getElementsByTagName("option").length;
	if ( ! oCount )
	{
		for ( a in FilterRule )
		{
			var rule = FilterRule[a];
			var rObj = document.createElement('option');
			rObj.value = a;
			rObj.innerHTML = rule;
			rObj.selected = ( a == 0 );
			r.appendChild(rObj);
		}
	}
	var r = document.getElementById("filterColumn");
	var oCount = r.getElementsByTagName("option").length;
	if ( ! oCount )
	{
		for ( a in FilterColumn )
		{
			var rule = FilterColumn[a];
			var rObj = document.createElement('option');
			rObj.value = a;
			rObj.innerHTML = rule;
			rObj.selected = ( a == 3 );
			r.appendChild(rObj);
		}
	}

}
// ----------------------------------------------------------------------
// apply filters to single cvItem item. return true if pass
//
this.passesFilters = function( rowItem, col )
{
	var pass = false;
	var filRule = this.filter[0];
	var filVal = this.filter[1];
	var filCol = this.filter[2];
	if ( (typeof(col) == "number") && (col > 0) )	// recursive check and setup.
		filCol = col;
	
	if ( !filVal || !filVal.length )
	{
		pass = true;
	} else {
		// Filter *something*
		var regXI = new RegExp(filVal, "i");	// case insensitive compare.
		switch ( parseInt(filCol) )
		{
			case 0: // All.  Recursive!
				for ( var r=1 ; r <= 12 ; r++ )
					pass = pass || this.passesFilters( rowItem, r );
				break;
			case 1: /* Category */		pass = this.compare( this.getCategoryAbbreviation(rowItem.category),	filVal, filRule, true );		break;
			case 2: /* No. */			pass = this.compare( rowItem.uqi,	filVal, filRule, true );			break;
			case 3: /* Requirement */	pass = this.compare( rowItem.title,	filVal, filRule );					break;
			case 4: /* owqm */			pass = this.compare( rowItem.answers["OWQM"],	filVal, filRule, true );break;
			case 5: /* ccs */			pass = this.compare( rowItem.answers["CCS"],	filVal, filRule, true );break;
			case 6: /* esm */			pass = this.compare( rowItem.answers["ESM"],	filVal, filRule, true );break;
			case 7: /* phs */			pass = this.compare( rowItem.answers["PHS"],	filVal, filRule, true );break;
			case 8: /* cm */			pass = this.compare( rowItem.answers["CM"],	filVal, filRule, true );	break;
			case 9: /* s&a */			pass = this.compare( rowItem.answers["S&A"],	filVal, filRule, true );break;
			case 10: /* compoents */	pass = this.compare( rowItem.numComponents,	filVal, filRule, true );	break;
			case 11: /* average */		pass = this.compare( rowItem.average,	filVal, filRule, true );		break;
			case 12: /* final */		pass = this.compare( rowItem.final,	filVal, filRule, true );			break;
		}
	}
	return pass;
}
// ----------------------------------------------------------------------
// apply sort rules to list of cvItems.
// cvList is (/may be) an associative array. So return a sorted Key List.
//
this.applySort = function( cvList )
{
	var keys = [];
	for(var key in cvList)
	{
		if ( cvList.hasOwnProperty(key) )
			keys.push(key);
	}
	// "Insert Sort"
	var sortedKeys = [];
	for ( var i=0 ; i < keys.length ; i++ )
	{
		if ( ! sortedKeys.length )
		{
			sortedKeys.push(keys[i]);	// first.
		} else {
			var startLen = sortedKeys.length;	// when length changes, insert occured.
			for ( var si=0 ; (si < startLen) && (startLen == sortedKeys.length) ; si++ )
			{
				var rhs = cvList[sortedKeys[si]];
				var lhs = cvList[keys[i]];
				if ( this.sortCompare(lhs, rhs) > 0 )
					sortedKeys.splice(si, 0, keys[i]);
				else if ( si == sortedKeys.length-1 )
					sortedKeys.push(keys[i]);
			}
		}
	}
	return sortedKeys;
}
// ----------------------------------------------------------------------
// sortCompare. Compare 2 cvItems by active sort rules. @lhItem @rhItem is a cvItem object.
//				Return 'compare' result;
//
this.sortCompare = function( lhItem, rhItem )
{
	var col = this.sortOrder["column"];
	var rule = (this.sortOrder["direction"] == "down") ? 1 : 5; // GT or LT in 'compare'
	var fN = true;	// numeric compare?
	var fA = false;	// "answer" value? (and therefore subject to grouping check).
	var lhs = 0;
	var rhs = 0;
	
	switch ( col )
	{
		case 1: /* Category */		lhs = lhItem.category;			rhs = rhItem.category;			break;
		case 2: /* No. */			lhs = lhItem.uqi;				rhs = rhItem.uqi;				break;
		case 3: /* Requirement */	lhs = lhItem.title;				rhs = rhItem.title;				fN = false;	break;
		case 4: /* owqm */			lhs = lhItem.answers["OWQM"];	rhs = rhItem.answers["OWQM"];	fA = true;  break;
		case 5: /* ccs */			lhs = lhItem.answers["CCS"];	rhs = rhItem.answers["CCS"];	fA = true;  break;
		case 6: /* esm */			lhs = lhItem.answers["ESM"];	rhs = rhItem.answers["ESM"];	fA = true;  break;
		case 7: /* phs */			lhs = lhItem.answers["PHS"];	rhs = rhItem.answers["PHS"];	fA = true;  break;
		case 8: /* cm */			lhs = lhItem.answers["CM"];		rhs = rhItem.answers["CM"];		fA = true;  break;
		case 9: /* s&a */			lhs = lhItem.answers["S&A"];	rhs = rhItem.answers["S&A"];	fA = true;  break;
		case 10: /* compoents */	lhs = lhItem.numComponents;		rhs = rhItem.numComponents;		break;
		case 11: /* average */		lhs = lhItem.average;			rhs = rhItem.average;			break;
		case 12: /* final */		lhs = lhItem.final;				rhs = rhItem.final;				break;
		case 13: /* Description */	lhs = lhItem.description;		rhs = rhItem.description;		fN = false; break;
		default: /* Use No. */		lhs = lhItem.uqi;				rhs = rhItem.uqi;				break;
	}
	if ( fA && ( (lhItem.comGroup == "T") || (lhItem.comGroup == "TStar") ) )	// if "blacked", negative value.
		lhs = -1;
	if ( fA && ( (rhItem.comGroup == "T") || (rhItem.comGroup == "TStar") )	)	// if "blacked", negative value.
		rhs = -1;

	return this.compare( lhs, rhs, rule, fN );
}
// ----------------------------------------------------------------------
// Run GT/GTE/EQ/NEQ/LTE/LT check on two items. Return bool of comparison.  @lhs, @rhs is a base type.
//
this.compare = function(lhs, rhs, rule, fNumeric)
{
	var pass = false;
	var doNumeric = ( fNumeric && (rule != 0) );	// rule 0 is match text!
	// null or blacked check.
	if ( typeof(lhs) == "undefined" )
		lhs = ( doNumeric ) ? -1000000 : "";
	if ( typeof(rhs) == "undefined" )
		rhs = ( doNumeric ) ? -1000000 : "";

	// type-convert.
	if ( doNumeric )
	{
		lhs = parseFloat(lhs);
		rhs = parseFloat(rhs);
	}
	switch ( parseInt(rule) )
	{
		case 0:	// Match. String no matter what.
			lhs = String(lhs);
			rhs = String(rhs);
			pass = ( lhs.search(new RegExp(rhs, "i")) >= 0 );	// case insensitive.
			break;
		case 1: /* GT  */	pass = ( lhs >  rhs );	break;
		case 2: /* GTE */	pass = ( lhs >= rhs );	break;
		case 3: /* EQ  */	pass = ( lhs == rhs );	break;
		case 4: /* NEQ */	pass = ( lhs != rhs );	break;
		case 5: /* LT  */	pass = ( lhs <  rhs );	break;
		case 6: /* LTE  */	pass = ( lhs <= rhs );	break;
	}
	return pass;
}
// ----------------------------------------------------------------------
// System Technical Requirements (STR) and every other component have mutually
// exclusive questions.  If the uqi is for one, then the other(s) could not possible have an answer associated with it.
// return bool.
//
this.compatibleComGroup = function( rData, componentIdx )
{
	if ( rData )
	{
		var STRidx = keyOf(ComponentsIndex, "STR");
		if ( ( rData.comGroup == "C" ) || ( rData.comGroup == "CStar" ) || ( rData.comGroup == "C*" ) )
			return (componentIdx < STRidx);

		if ( ( rData.comGroup == "T" ) || ( rData.comGroup == "TStar" ) || ( rData.comGroup == "T*" ) )
			return (componentIdx >= STRidx);
	}
	return true; // error on the side of yes?
}

// ----------------------------------------------------------------------
// Print Mode Engage/Disengage.  Show/Hide all the page frames.  Change/Retore html/body colors.
//
this.printView = function( engage )
{
	var pageID = pageview_getCurrentPage(true);			// ID to print-ify.
	var page = document.getElementById(pageID);			// Object Tree to print-ify
	var kids = page.getElementsByTagName("*");			// _ALL_ children of that object.
	// Semiphore
	if ( engage == 1 )
	{
		if ( this.printViewRestore["mode"] == 1 )
			return; // get out. already in print mode
		// else create/reset the restore point.
		this.printViewRestore[pageID] = new Array();
	}
	this.printViewRestore["mode"] = engage;
	//
	// Modify all page elements (and store/restore previous state)
	for ( var k=0 ; k < kids.length ; k++ )
	{
		var kid = kids[k];
		if ( engage == 1 )
		{
			this.printViewRestore[pageID][k] = new Array();
			this.printViewRestore[pageID][k]["color"] = kid.style.color;
			this.printViewRestore[pageID][k]["border"] = kid.style.borderColor;
			this.printViewRestore[pageID][k]["bg"] = kid.style.backgroundColor;
			this.printViewRestore[pageID][k]["bgImg"] = kid.style.backgroundImage;
			this.printViewRestore[pageID][k]["height"] = kid.style.height;
			this.printViewRestore[pageID][k]["overflowy"] = kid.style.overflowY;
			kid.style.color = "black";
			kid.style.borderColor = "black";
			if ( kid.style.backgroundColor.length ) // not if blank.
				kid.style.backgroundColor = "white";
			if ( ( kid.className == "guidance" ) || ( kid.className == "next" ) )
				kid.style.display = "none";
			if ( ( kid.className == "glassyPrintView20" ) || ( kid.className == "glassyExport" ) )
				kid.style.display = "none";
			if ( (kid.className == "glassyPrint") || (kid.className == "glassyClosePrint") || (kid.className == "glassyExportPrint") )
				kid.style.display = "inline-block";
			if (( kid.tagName == "TH" ) || ( kid.className == "groupHeaderGrey" ))
			{
				// Tragically, Browsers do not print background images by default.  So swap to a "color"
				kid.style.backgroundColor = "#eeeeee";
				kid.style.borderRight = "1px solid black";
				kid.style.borderTop = "1px solid black";
				kid.style.backgroundImage = "none";
				if ( kid.className == "groupHeaderGrey" )
					kid.style.borderLeft = "1px solid black";
			}
			if ( kid.className == "left" )
				kid.style.borderLeft = "1px solid black";
			if ( kid.className == "right" )
				kid.style.borderRight = "1px solid black";
			if ( kid.className == "black" )
			{
				kid.style.backgroundColor = "#eeeeee";
			}
			if ( kid.id == "scrollingTableDiv" )
			{
				// Remove scroll to show entire table contents.
				kid.style.height = "auto";
				kid.style.overflowY = "visible";
			}
		} else {
			kid.style.color = this.printViewRestore[pageID][k]["color"];
			kid.style.borderColor = this.printViewRestore[pageID][k]["border"];
			kid.style.backgroundColor = this.printViewRestore[pageID][k]["bg"];
			if ( ( kid.className == "guidance" ) || ( kid.className == "next" ) )
				kid.style.display = "block";
			if ( ( kid.className == "glassyPrintView20" ) || ( kid.className == "glassyExport" ) )
				kid.style.display = "inline-block";
			if ( (kid.className == "glassyPrint") || (kid.className == "glassyClosePrint") || (kid.className == "glassyExportPrint") )
				kid.style.display = "none";
			if (( kid.tagName == "TH" ) || ( kid.className == "groupHeaderGrey" ))
			{
				kid.style.backgroundColor = "none";
				kid.style.border = "none";
				kid.style.backgroundImage = this.printViewRestore[pageID][k]["bgImg"];
			}
			if ( kid.className == "black" )
			{
				kid.style.backgroundColor = "none";
			}
			if ( kid.id == "scrollingTableDiv" )
			{
				// Restore table scroll.
				kid.style.height 	= this.printViewRestore[pageID][k]["height"];
				kid.style.overflowY	= this.printViewRestore[pageID][k]["overflowY"];
			}
		}
	}
	// The frame.
	if ( engage == 1 )
	{
		this.printViewRestore["body"] = document.body.style.backgroundColor;
		document.body.style.backgroundColor = "white";
	} else {
		document.body.style.backgroundColor = this.printViewRestore["body"];
	}
	var display = ( engage == 1 ) ? "none" : "block";
	document.getElementById("banner").style.display = display;
	document.getElementById("footer").style.display = display;
}
// ----------------------------------------------------------------------
// Final value text field has changed. save.
//
this.onFinal = function( id, uqi )
{
	var tObj = document.getElementById(id);
	var val = tObj.value;
	if ( (val != 0) && (val != 1) && (val != 2) && (val != 3) )
	{
		alert( "'" + val + "' is not a valid value for the Final Rating.  Please enter a number from 0 to 3.  See the Rating Key above the table for details.");
		tObj.focus();
	} else {
		if ( typeof(this.fullList[uqi]) != "undefined" )
			this.fullList[uqi].final = parseInt(val);
	}
};

// ----------------------------------------------------------------------
// exlude check has changed. save.
//
this.onExclude = function( id, uqi )
{
	var a = document.getElementById(id);
	if ( typeof(this.fullList[uqi]) != "undefined" )
		this.fullList[uqi].exclude = a.checked;	
};

// ----------------------------------------------------------------------
// filter value has changed.
//
this.onFilter = function( id, type )
{
	var a = document.getElementById(id);
	this.filter[type] = a.value;
	this.updateWorkingView(this.wvContainer);
}

// ----------------------------------------------------------------------
// fill something.
this.onFill = function( id, col )
{
	this.updateNonRequirementsView(this.nrContainer);
}

// ----------------------------------------------------------------------
// sort value has changed.
//
this.onSort = function( id, col )
{
	// Working, Final, or Summary?
	var viewType = 0;	// Working.
	var imgPrefix = "wv";
	if ( id.search("thf") >= 0 )
	{
		viewType = 1;	// Final
		imgPrefix = "fv";
	}
	if ( id.search("ths") >= 0 )
	{
		viewType = 2;		// Summary
		imgPrefix = "fv";	// ok, same as final because they look the same, but configurable!
	}
	// Direction and column.
	var direction = ( (this.sortOrder["column"] == col) && (this.sortOrder["direction"] == "down") && (this.sortOrder["view"] == viewType) ) ? "up" : "down";
	this.sortOrder["view"] = viewType;
	this.sortOrder["column"] = col;
	this.sortOrder["direction"] = direction;
	// Update Visual Sort Arrows (last/active)
	var last = document.getElementById(this.sortOrder["active"]);
	if ( last )
	{
		last.style.backgroundImage = "url('./img/sort_" + imgPrefix + "_none.png')";
	}
	var active = document.getElementById(id);
	if ( active )
	{
		this.sortOrder["active"] = id;
		active.style.backgroundImage = "url('./img/sort_" + imgPrefix + "_" + direction + ".png')";
	}
	// Do/Update all else.
	switch ( viewType )
	{
		case 2 : this.updateSummaryView("summaryView");		break;
		case 1 : this.updateFinalView("finalView");			break;
		default: this.updateWorkingView(this.wvContainer);	break;
	}
}
// ----------------------------------------------------------------------
// User is exporting/saving table to csv file.
//
this.onExport = function( summary, btn )
{
	if ( btn )
		btn.disabled = true;
	if ( 12 == pageview_getCurrentPage(false) )	// magic number alert!
	{
		var csvData = this.createCSV_NonReq();
		saveTextAs(csvData, "Consolidated_NonRequirements.csv");
	}
	else
	{
		var tID = summary ? "summaryView" : "finalView";	// Should be set member var.
		var csvData = this.createCSV( tID, summary );
		saveTextAs(csvData, "ConsolidatedRequirements_" + tID + ".csv");
	}
	if ( btn )
		btn.disabled = false;
}

// ----------------------------------------------------------------------
// User is clearing all loaded components
//
this.onClearList = function()
{
	for ( var k in this.conData )
		delete this.conData[k];
	this.conData = new Array();
	this.conFileNames = new Array();
	this.fileQueue = new Array();
	this.fullList = new Array();
		
	if ( this.gateBtn )
		this.gateBtn.disabled = true;
	this.onDataLoad();	// Allow onDataLoad to clear out the fileListView.
}

// ----------------------------------------------------------------------
// Pop the read-only tiny box showing question and user input.
//
this.onShowReq = function(uqi, component)
{
	var shortname = ComponentsIndex[component];
	var tView = new TabView();
	tView.CreateAttach(component, null, this.getData(shortname));	// attach our TabData, just to use createQuestionHTML.

	var q = tView.TabData.getQuestion( parseInt(uqi) );
	if ( q == null )
	{
		alert ( "Error. The Requirement was not found (requirement uqi # " + uqi + ")" );
	} else {
		var qHTML = tView.createQuestionHTML(q.uqi, q, "tiny", 0);
		var title = "View Requirement";
		TINY.box.show(TinyBoxHTML(title, qHTML, 2), 0, 750, 0, 0, 0);	// 750 = qContent + padding + margin.
	}
}

}; // end obj

// ***************************************************************************************
// ***************************************************************************************
//
// cvItem. Consolidated View Item.
//
// Simple object encapulating the all data for an item, and therefore a row.  Takes Question on construct.
//
function cvItem( q ) {
							// (C, C*, T, T*).
							// 0-MinTechUQI="C", MinTechUQI-MinCustomUQI="T", MinCustom-(MinCustom+MinTech)=C*, Higher=T*
	this.comGroup			= (q.uqi < TabData_MinCustomUQI) ? 								
								((q.uqi < TabData_MinTechRequirementUQI) ? "C" : "T") :
								((q.uqi < TabData_MinCustomTechUQI) ? "C*" : "T*" );
	this.module				= q.module;
	this.category			= q.category;
	this.uqi				= q.uqi;
	this.title				= q.title;
	this.description		= (q.description == "description") ? q.title : q.description;
	this.answers			= new Array();
	this.numComponents		= 0;				// Num Components with a non-zero rating!
	this.average			= 0;
	this.calculatedFinal	= 0;				// Calculated. Non-user-touched.
	this.final				= 0;				// User-Changeable.
	this.exclude			= false;			// User-Changeable.
}

// ***************************************************************************************
// ***************************************************************************************
//
// File Picker Hook.
//
// Must user-interaction-select files to read/load. This is the callback hook once user chooses one or more.
// Callback to a static function, rather than dynamic attach, because ie8 and 9 do dont have "addEventListener()",
// so the legacy support must involve a conditional there.
//
// Grab contents and feed to ConsolidatedView, which will validate.
//

window.onload = function ()
{ 
	var fc = document.getElementById('fileChooser');
	if ( fc.addEventListener )
		fc.addEventListener('change', function(e){ fileChooserEventListener(e); }, false);
	else
		fc.attachEvent('onchange', function(e){ fileChooserEventListener(e); });
}
// -------------------------------------------
// Get the file name(s) of files selected from the "browse" feature of the browser.
// Routine handles single or multi selection.  Handles FileReader (html5) or ActiveX.
//
function fileChooserEventListener(e)
{
	// Surprise! ie8 and 9 doesn't handle multiple files!  If "files" is not populated, grab "value". singular.
	//			Then place that singular into a one-item array so that everything else can operate off a common ADT.
	// With the file object(s), do not do 'for in'. FileList object has 'length' property.
	//
	var fc = document.getElementById('fileChooser');
	var fileNames = new Array();
	if ( fc.files && fc.files.length )
	{
		fileNames = fc.files;			// html5.
	} else {
		fileNames.push(["name"]);		// ie8 or 9.  create stub one-item fileObj array for loop.
		fileNames[0].name = fc.value;
	}
		
	for ( fIdx=0 ; (fIdx < fileNames.length) ; fIdx++ )
	{
		var fileObj = fileNames[fIdx];
		// Check of the extension match. Don't use 'type' becase that is Windows-filled-in and who knows what it will say later.
		ext = fileObj.name.substr(fileObj.name.lastIndexOf('.'));
		if ( ! ext.match("csv") && ! ext.match("txt") && ! ext.match("text") )
		{
			alert("Cannot Load File '" + fileObj.name + ". File extension is an invalid type. Select a '.csv', '.txt', or '.text' file.");
		} else {
			if ( window.File && window.FileReader && window.FileList && window.Blob )
			{
				//
				// FileReader API Available (HTML5). Use it.
				//
				var fileReaderObj = new FileReader();
				fileReaderObj.file = fileObj;
				fileReaderObj.onload = function (e)
				{
					CurrentConView.queueFile(this.file.name, this.result);
				}
				fileReaderObj.readAsText(fileObj);	// do it. triggering onload callback.
			} else {
				//
				// Attempt to open via ActiveX.
				//
				var content = ToolDB.getFile( fileObj.name );
				if ( content && content.length )
				{
					CurrentConView.queueFile( fileObj.name.split('\\').pop(), content );
				} else {
					alert("Cannot Load File '" + fileObj.name + ". Browser incompatibility or file permission issue."); 
				}
			}
		}
	}
};
