//
// TabData.js
//
// Object controller for the data displayed within all tabs, and the answer data stored to the jstorage/ToolDB database.
//
//		BIG NOTE:  Module #'s and Category #'s cannot be zero.
//
var TabData_MinTechRequirementUQI = 500;	/* Threshold of STR "Tech Requirements" UQIs.  Only for Consolidated "Category" */
var TabData_MinCustomUQI = 1000;			/* Threshold between database uqi's and custom created */
var TabData_MinCustomTechUQI = 1500;		/* Threshold between custom uqi's and custom uqi's in the STR 'Tech Requirements' Comp. */

function TabData() {

var tdself = this;					/* because "this" doesn't work through onclick callbacks */
this.cShort = "";					/* component shortname */
this.cLong = "";					/* component longname */
this.dbScript = "";
this.dbData = null;					/* if set, is contents of data file to use on load.  AND THEREFORE READONLY! */
this.member = "Value";
this.modules;						/* modules and categories array (queried by higher levels (TabView, etc.) */
this.modulesAbbrs;
this.questions;						/* common question array */
this.compQuestions;					/* component-specific question array */
this.answers;
this.answerGroupings;				/* #questions per module/category. and whether they've been answered */
// ***************************************************************************************
// Public API
// ***************************************************************************************
// --------------
// return a specific question by uqi.
// returned array:  [uqi, user facing #, module, category, type, title, text, [continued data]
//
this.getQuestion = function ( uqi )
{
	return new Question(uqi, this.questions[uqi], this.compQuestions);
	
	var baseQ = this.questions[uqi];
	var q = null;
	var userNum = 0;
	for ( var i=0 ; i < this.compQuestions.length ; i++ )
	{
		if ( this.compQuestions[i][0] == uqi )
		{
			var compQ = this.compQuestions[i];
			userNum = i+1;
			// Get/Append/Override Title
			var title = baseQ[1];
			if ( compQ.length >= 5 )
			{
				if      ( compQ[3] == 1 )	title = compQ[4];
				else if ( compQ[3] == 2 )	title += compQ[4];
			}
			// Get/Append/Override Main Text
			var text = baseQ[2];
			if ( compQ.length >= 7 )
			{
				if      ( compQ[5] == 1 )	text = compQ[6];
				else if ( compQ[5] == 2 )	text += compQ[6];
			}
			q = [uqi, userNum, compQ[1], compQ[2], baseQ[0], title, text, baseQ];
			break;
		}
	}
	return q;
};
// --------------
// return an array of questions matching module/category.  0 module = all modules, 0 category = all categories.
//
this.getQuestions =	function ( module, category )
{
	var qs = new Array();
	for ( var i=0 ; i < this.compQuestions.length ; i++ )
	{
		var iModule = this.compQuestions[i][1];
		var iCategory = this.compQuestions[i][2];
		if ( ((module == 0) || (iModule == module)) && ((category == 0) || (iCategory == category)) )
		{
			var uqi = this.compQuestions[i][0];
			qs[uqi] = this.getQuestion(uqi);
		}
	}
	return qs;
};
// --------------
// return all questions
//
this.getAllQuestions = function ( module, category )
{
	return this.getQuestions(0, 0);
};
// --------------
// Sort by userNum, not uqi.  Which means CompQuestion defined order.
this.sortByUserNum = function ( questions )
{
	questions.sort(function(a, b){return a.userNum - b.userNum;});
	return questions;
}

// --------------
// given file file data, determine shortname from string. (With light syntax checking.)
// return null if no data or bad syntax.
//
this.getShortNameFromFileData =	function ( dbStr )
{
	var shortname = null;
	var hIdx = dbStr.indexOf("::");
	if ( hIdx )
	{
		var header = dbStr.substring(0, hIdx);
		var snIdx = header.indexOf(",");
		if ( snIdx )
		{
			shortname = header.substring(0, snIdx);
		}
	}
	return shortname;
}

// --------------
// load questions of given component. asynchronous. callback optional.
// @filedata, optional. If given, file is already loaded. Is file contents.
//
this.Load =	function ( componentShortName, callback, fileData )
{
	this.cShort = componentShortName;
	this.cLong = Components[componentShortName];
	this.answers = new Array();
	this.dbScript = "qdb/data_" + this.cShort + ".js";
	this.dbData = fileData;
	loadScript( this.dbScript );
	setTimeout(function() {tdself.onLoaded(callback);}, 500); // not too fast. 100 allows breath. *5 for safety.
}
this.onLoaded = function(callback)
{
	// Pull and store component-specific globals loaded from the script. That the dynamic loading magic.
	//
	this.modules = ( Modules == null ) ? CommonModules : Modules;	// Null sets to default in "common" script.
	this.modulesAbbrs = ( ModulesAbbrs == null ) ? CommonModulesAbbrs : ModulesAbbrs;	// Null sets to default in "common" script.
	this.questions = Questions;
	this.compQuestions = CompQuestions;
	this.getData();
	this.getCustomQuestions();
	this.setAnswerGroupings();
	//alert ("onLoaded: success.  In fact:" + Questions[1][2]);
	callback();
}
this.getModules = function()
{
	return this.modules;
}
// --------------
//
this.setAnswer = function( id, val )
{
	// first, the real answer
	var valStr = "" + val;				// enforce string conversion
	this.answers[id] = valStr;
	
	// second, set grouping as answered (or not, if there's zero data)
	var agKey = this.stripType(id) + this.stripUQI(id);
	var isAnswered = (valStr.length) ? 1 : 0;
	if ( ! isAnswered )
	{
		// Okay, the value is blank which means the user erased something. Which 99.9% means text field,
		// but if *any* group field is still answered, the group is answered.
		// NOTE: this might change after review to a "mandatory text field or not" structure.
		for ( var loopKey in this.answers )
		{
			if ( (loopKey.search(agKey) >= 0) && (this.answers[loopKey].length) )
				isAnswered = true; // found one.
		}
	}
	if ( this.answerGroupings[agKey] )
		this.answerGroupings[agKey].isAnswered = isAnswered;
}
// --------------
//
this.getAnswer = function( id )
{
	if ( typeof(this.answers[id]) == "undefined" )
		return "";
	return this.answers[id];
}
// --------------
// Get the "text" of the answer. (radio button label, text entry, check box labels.)
//
this.getAnswerText = function( id )
{
	var uqi 	= this.stripUQI(id);
	var idType 	= this.stripType(id);
	var subId	= this.stripSubId(id);
	if ( idType == "req" )
	{
		var a = this.getAnswer("radio" + uqi);	// req answers are stored as "radioXXX".
		return RequirementsOptions[parseInt(a)];
	}
	else if ( idType == "radio" )
	{
		var defineThisSomewhereElseThisOnlyWorksCauseThereIsOnlyYesNo = ["No", "Yes"];
		var a = this.getAnswer(id);
		return defineThisSomewhereElseThisOnlyWorksCauseThereIsOnlyYesNo[parseInt(a)];
	}
	else if ( idType == "text" )
	{
		return this.getAnswer(id);
	}
	else if ( idType == "check" )
	{
		var q = this.getQuestion(uqi);
		var answerText = "";
		for ( var j=1; j <= q.checkBoxLabels.length ; j++ )
		{
			var a = parseInt(this.getAnswer(idType + uqi + "_" + j));
			if ( a )
			{
				if ( answerText.length )
					answerText += ", ";
				answerText += q.checkBoxLabels[j-1];
			}
		}
		return answerText;
	}
	return "getAnswerText: bad id type in request id = " + id;
}
// --------------
// Return the percentage of answered/acknowledged questions in a category.
//		@module.   0 returns percentage of all categories across all modules.
//		@category. 0 returns percentage across all categories for that module.
// *Checkbox groupings count as one question, one answer.
// *Radio groupings count as one question, one answer. But radio buttons will have only one answer in database.
// *If question count is 0, then percent==100.
//
this.percent = function( module, category )
{
	if ( (typeof(module) == "undefined") || (module<1) ) 	module = 0;
	if ( (typeof(category) == "undefined") || (category<1) ) 	category = 0;
	var Qs = 0;
	var As = 0;
	for ( var agKey in this.answerGroupings )
	{
		agObj = this.answerGroupings[agKey];
		if ( ((! module) || (agObj.module == module)) && ((! category) || (agObj.category == category)) )
		{
			Qs++;
			if ( agObj.isAnswered > 0 )
				As++;
		}
	};
	if ( Qs < 1 )
		return 100;
	else
		return Math.floor( (As / Qs) * 100 );
}
// Given question element id of the format <type><uqi>_<subIdentifier> (i.e., "radio44_2" or "radio4", return the uqi.
//
this.stripUQI = function(keyStr)
{
	var subIdIdx = keyStr.lastIndexOf("_");
	var agKey = ( subIdIdx == -1 ) ? keyStr : keyStr.substr(0, subIdIdx);	// trim after _.
	return parseInt(agKey.replace(/\D/g,'')); 								// Turn every non-digit to nothing.
}
// Given question element id of the format <type><uqi>_<subIdentifier> (i.e., "radio44_2" or "radio4", return the type.
//
this.stripType = function(keyStr)
{
	var uqiIdx = keyStr.search(/\d/);
	return keyStr.substr(0, uqiIdx);
}
// Given question element id of the format <type><uqi>_<subIdentifier> (i.e., "radio44_2" or "radio4", return the subIdentifier.
//
this.stripSubId = function(keyStr)
{
	var subIdIdx = keyStr.lastIndexOf("_");
	var subId = ( subIdIdx < 1 ) ? "0" : keyStr.substr(subIdIdx);
	return parseInt(subId.replace(/\D/g,'')); 								// Turn every non-digit to nothing.
}
// Given uqi, get the component question configuration array
//
this.getCompQuestionFromUQI = function(uqi)
{
	for ( var i=0 ; i < this.compQuestions.length ; i++ )
	{
		if ( this.compQuestions[i][0] == uqi )
			return this.compQuestions[i];
	}
	return null;
}
// ---------------------------------
this.makeUQI = function()
{
	//
	// Create a UQI. Guarenteed mathematically unique to only this instance (of course).
	//				 However, use Components array to 'reserve' a block of 100 for each module/component. 
	//				 (Rare) "Consolidate" mode collisions will be handled at that level.
	//				 UQI is in different range for "Tech Requirements".
	//
	var nUQI;
	if ( this.cShort == "STR" )
	{
		nUQI = TabData_MinCustomTechUQI -1;		// Set to Tech Requirements range.
	}
	else
	{
		nUQI = TabData_MinCustomUQI - 1;		// Set to 'normal' custom range.
		var cIdx=0;
		for ( cKey in Components )				// And then set to component-specific range.
		{
			if ( cKey == this.cShort )
				nUQI += ( 100 * cIdx );
			cIdx++;
		}
	}
	// Now increment until a free one is found.
	for ( qkey in this.questions )
		nUQI = Math.max( parseInt(qkey), nUQI );
	nUQI += 1;
	return nUQI;
}

// ---------------------------------
// Create a new, custom question.  Right now, assume it's a "requirement" because there is no
// feature need for non-requirement.  Create Question, add to memory, save title and text as an
// "answer" to be loaded on future return.
//	@qArr:  array of new question values.  Key will have a prefix and a temporary (invalid) uqi encoded.  So pattern search it.
//
this.createQuestion = function( qArr, module, category )
{
	module = parseInt(module);		// may be coming in as string.
	category = parseInt(category);	// may be coming in as string.
	var nUQI = this.makeUQI();
	//
	// Gather 4 requirement pieces of data.  Can be explicit because only requirements are created in this track.
	// (again, pattern search the key)
	//
	var nTitle = "";	var nDescription = "";	var nRadio = "";	var nText = "";
	for ( qkey in qArr )
	{
		if ( qkey.search("title") >= 0 )	nTitle = qArr[qkey];
		if ( qkey.search("desc")  >= 0 )	nDescription = qArr[qkey];
		if ( qkey.search("radio") >= 0 )	nRadio = qArr[qkey];
		if ( qkey.search("text") >= 0 )		nText = qArr[qkey];
	}
	// Create and push question entry into main 'questions' and component 'compQuestions' array.
	// Imperfectly, "Description" is actually defined as "text" in the Question array.
	var nShortDesc = nDescription.slice(0, 256);
	this.questions[nUQI] = ["req", nTitle, nShortDesc, nDescription ];
	this.compQuestions.push([nUQI, module, category]);	
	// Save values.  Including "title", "text" and "type" for custom questions.
	this.setAnswer( "title" + nUQI, 		nTitle );
	this.setAnswer( "description" + nUQI, 	nDescription );
	this.setAnswer( "category" + nUQI, 		category );
	this.setAnswer( "module" + nUQI, 		module );
	this.setAnswer( "type" + nUQI, 			"req" );
	this.setAnswer( "radio" + nUQI, 		nRadio );
	this.setAnswer( "text" + nUQI + "_1",	nText );
	// return a Question object.
	return new Question(nUQI, this.questions[nUQI], this.compQuestions);
}
// ---------------------------------
// Remove a custom question.  Caller should call setData() after all removeQuestion calls are done.
// As with createQuestion, we are currently assuming all are "req" types.
//
this.removeQuestion = function( uqi )
{
	uqi = parseInt(uqi);
	if ( uqi >= TabData_MinCustomUQI )
	{
		this.setAnswer( "title" + uqi, 			"" );
		this.setAnswer( "description" + uqi, 	"" );
		this.setAnswer( "category" + uqi, 		"" );
		this.setAnswer( "module" + uqi, 		"" );
		this.setAnswer( "type" + uqi, 			"" );
		this.setAnswer( "radio" + uqi, 			"" );
		this.setAnswer( "text" + uqi + "_1",	"" );
		
		delete this.questions[uqi];
		for ( var i=0 ; i < this.compQuestions.length ; i++ )
		{
			if ( this.compQuestions[i][0] == uqi )
			{
				delete this.compQuestions[i];
				i = 100000;
			}
		}
	}
}

// ---------------------------------
// Get the alternate text for a given input field.  uqi + index. Index is of the QuestionsAltText
// array, which maps to inputs per type. Up to caller to determine which index it wants.
//
this.getAltText = function( uqi, idx )
{
	var altText = "";	// total default.
	var q = this.questions[uqi];
	if ( q && q.type == "req" && idx < 4 )
		altText = RequirementsOptions[idx];	// req default = visual label.
	if ( ( QuestionsAltText[uqi]) && ( QuestionsAltText[uqi][idx] ) && ( QuestionsAltText[uqi][idx].length ) )
		altText = QuestionsAltText[uqi][idx];
		
	altText = stripQuotes(altText);
	return altText;
}

// ***************************************************************************************
/* private */
// ***************************************************************************************
// --------------
// get from database
//
this.getData = function()
{
	if ( this.cShort )
	{
		var dbStr = "";
		if ( this.dbData && this.dbData.length )
			dbStr = this.dbData;
		else
			dbStr = ToolDB.get(this.cShort);
			
		if ( (dbStr == null) || (dbStr.length < 2) )
		{
			return "";	// key does not exist.  hopefully, first time in this component.
		} else {
			var hIdx = dbStr.indexOf("::");
			if ( hIdx )
			{
				var header = dbStr.substring(0, hIdx);
				var dataStr = dbStr.substring(hIdx+2).replace(",undefined,", "");
				this.answers = this.unserialize(dataStr);
				//alert (" ok, and length is " + this.answers.length + ". and data is: " + dataStr );
				return dataStr;
			}
		}
	}
	else
		return "ERROR: TabData:getData, no key set."
	return "ERROR: TabData:getData. Improper data";
}
// --------------
// save to database. Do NOT save if in READONLY mode.
//
this.setData = function( data )
{
	if ( this.dbData && this.dbData.length )
		return;	// read only.
		
	var stamp = new Date().getTime();
	if ( this.cShort )
	{
		var header = this.cShort + "," + stamp + "::";
		var dataStr = this.serialize(this.answers);
		ToolDB.set(this.cShort, "" + header + dataStr);
	}
	else
		return "ERROR: TabData:setData, no key set."
}
// -----------------------------
// Given array single-dimentional, return delimiter-delimited string.
// Customizing since neither jquery nor json do this (correctly) for data arrays.
//
this.serialize = function(a, delim)
{
	if ( typeof(delim) == "undefined" )
		delim = ",";
	var regx = new RegExp(delim, 'g');	// globally replace. (multiple instances)
	var str = "";
	for ( var key in a )
	{
		if ( a[key].length )
		{
			var val = a[key].replace(regx, "~~");
			str += key + delim + val + delim;
		}
	}
	return str;
};
this.unserialize = function(str, delim)
{
	if ( typeof(delim) == "undefined" )
		delim = ",";
	var a = new Array();
	var strA = str.split(delim);
	for (var i=0 ; i < strA.length ; i++)
	{
		var key = "" + strA[i];
		var val = "" + strA[i+1];
		val = val.replace("~~", ",");
		a[key] = val;
		i++;
	}
	return a;
};
// -------------------------------------------------------------------------------------
// On Load, search loaded answers to custom question data, and load into questions and compQuestions
// feature need for non-requirement.  Create Question, add to memory, save title and text as an
// "answer" to be loaded on future return.
//	@qArr:  array of new question values.  Key will have a prefix and a temporary (invalid) uqi encoded.  So pattern search it.
//
this.getCustomQuestions = function()
{
	for ( aKey in this.answers )
	{
		if ( aKey.search("title") >= 0 )
		{
			// Custom Q!.  Grab everything else (which should be there) and insert to main questions.
			var nUQI = this.stripUQI( aKey );
			try {
				var nTitle 			= this.answers["title" + nUQI];
				var nDescription 	= this.answers["description" + nUQI];
				var nShortDesc 		= nDescription.slice(0, 256);
				var nModule			= this.answers["module" + nUQI] ? this.answers["module" + nUQI] : 3;
				var nCategory		= this.answers["category" + nUQI] ? this.answers["category" + nUQI] : 6;
				var nType			= this.answers["type" + nUQI] ? this.answers["type" + nUQI] : "req";
				// Note: the 'radio' and 'text' answers are sitting in 'answers' and need not be touched.
				
				// Create and push question entry into main 'questions' and component 'compQuestions' array.
				this.questions[nUQI] = [nType, nTitle, nShortDesc, nDescription];
				this.compQuestions.push([nUQI, nModule, nCategory]);	
			} catch (e) {
				;// noop. just skip it.
			}
		}
	}
}

// -------------------------------------------------------------------------------------
// answerGroupings array:  Categorize *type* of questions by module/category. And track whether they've been answered.
//
// This is to provide math (percentages) to the View layer as to whether a user has answered a particular question.
// Answering any of a suite of radios, checkboxes, or text fields counts as ONE.
// (A yes/no radio button with a text field counts as 2, etc.)
// Thus, multiple TYPE fields for SAME uqi count as one.  This mirrors the View layer's scheme.
//
// Structure:
//   [<type><uqi>] = [module, category, answered(boolean)];
//
this.setAnswerGroupings = function()
{
	this.answerGroupings = [];
	var types = ["req", "check", "radio"];	// Define elsewhere?
											// "text" removed.  Text fields have been ruled as not necessary.
	
	for (var i=0 ; i < CompQuestions.length ; i++)
	{
		var uqi 		= CompQuestions[i][0];
		var module 		= CompQuestions[i][1];
		var category 	= CompQuestions[i][2];
		var type 		= Questions[uqi][0];
		// for each "type" encoded in the question definition, increment. (uqi + type = single grouping).
		for ( var t=0 ; t < types.length ; t++ )
		{
			if ( type.search(types[t]) >= 0 )
			{
				// add it!
				var specificType = type.substr(type.search(types[t]), types[t].length);
				if ( specificType == "req" )
					specificType = "radio"; // HACK! Need a conversion. (if req, only the radio is mandatory)
					
				var agKey = specificType + uqi;
				this.answerGroupings[agKey] = new AnswerGroup(module, category, 0);	// exists, and is not answered.
			}
		}
	}
	//
	// Array set and questions categorized.  Now fill whether they've already been answered.
	// Answers are already loaded, and if an answer exists, then the user has clicked on it at least once,
	// thus a check or radio of 0 counts as answered.  A text field of zero length does NOT count as answered.
	//
	for ( var ansId in this.answers )
	{
		// REMEMBER:  this.answers contain the real answers, per field!
		var uqi = this.stripUQI(ansId);
		var type = this.stripType(ansId);

		var agKey = type + uqi;
		var agObj = this.answerGroupings[agKey];
		if ( (ansId != "") && (agObj != null) )
		{
			var answerStr = "" + this.answers[ansId];
			if ( answerStr.length > 0 )
				agObj.isAnswered = 1;	// answered. might be setting this multiple times, which is fine, and whole point.
		} else {
			// Error.  EXCEPT text fields for "req".  They're non-mandatory and not counted in groupings.
			// Also, ignore empty keys.
			if ( 0 )	/* DEBUG */
			if ( ( ansId.trim().length > 0 ) && ((typeof(this.questions[uqi]) == "undefined") || (this.questions[uqi][0] != "req")) )
				alert("ERROR: answerGrouping doesn't exist and it should for answerid: '" + ansId + "'");
		}
	}
}

// -------------------------------------------------------------------------------------
//
this.createCSV = function()
{
	var dbStr = ToolDB.get(this.cShort);
	return dbStr;
};
}; /* end TabData */

// ***************************************************************************************
// ***************************************************************************************
//
// Answer Group.
//
// Simple object encapulating the answer group.
//
function AnswerGroup( m, c, a ) {
	this.module = m;
	this.category = c;
	this.isAnswered = a;
}

