//
// TabView - Container and API for tabbed 'wizard'. Read/Write/Interface for Component questions/requirements gathering and storage.
//
// 		1. Currently, the UI and this object Mandates a subTab row.
//		2. Object allows for different containers. (I.e., drawing on different pages with different data concurrently).
//				This is the "tabContainer" of constructor.
//
// Data Defined and controlled by TabData obj. 
//		BIG NOTE:  Tab# == Module#.   SubTab# == Category#
// ***** Auxiliary *************************************************************
function tabview_switch(a, b) 	{ CurrentTabView.Switch(a, b); };
function tabview_createDataCSV(){ CurrentTabView.createDataCSV(); };
function tabview_createUserCSV(){ CurrentTabView.createUserCSV(); };
function tabview_save(a) 		{ CurrentTabView.onSave(a); };
function tabview_customReq(a, b){ CurrentTabView.customReq(a, b); };
function tabview_finish(a)		{ CurrentTabView.onFinish(a); };
function onTabViewRadio(a, b) 	{ CurrentTabView.onRadio(a, b); };
function onTabViewCheckbox(a) 	{ CurrentTabView.onCheckbox(a); };
function onTabViewText(a) 		{ CurrentTabView.onTextEntry(a); };
function onTabViewRefresh(a) 	{ CurrentTabView.onRefresh(a); };
function onTabViewUpdateAnswer(a){CurrentTabView.onUpdateAnswer(a); };
// *****************************************************************************

function TabView() {

var self = this;					/* because "this" doesn't work through onclick callbacks */
this.TabData = new TabData();
this.modules = null;				/* modules and categories array. (Loaded by TabData) */
this.tabContainer = "Tabs";			/* default.  define-able in Create */
this.subTabContainer = "subTabs";	/* default.  define-able in Create */
this.pageContainer = "tabPageWrapper";	/* default. define-able in Create */
this.hasBeenCreated = false;		/* creation semiphore to avoid unnecessary work on first construct */
this.gateBtn = null;				/* Object to enable once creation complete */
this.cShort = "";					/* current Component */
this.currentTab = 0;
this.currentSubTab = 0;				/* Unnecessary with currentSubTabs, but nice short-hand */
this.currentSubTabs = new Array();	/* Current sub-tabs per-tab. For more intuitive primary-Tab switching */
this.consolidated = new Array();
this.objectActions = new Array();	/* actions for a dynamically created id. see attachActions. */
	
// ***************************************************************************************
// Public API
// ***************************************************************************************
this.Switch =		function( tab, subTab ) 	{ this.aux(tab, subTab); };
this.Initialize =	function() 					{ this.aux(1, 1); };
this.Refresh = 		function() 					{ this.aux(this.currentTab, this.currentSubTab); };
this.Create =		function( componentShortName, gateBtn, tabDiv, subTabDiv, pageDiv ) /* last 3 parameters optional */
{
	this.destroy();
	this.cShort =			componentShortName;
	this.gateBtn =			gateBtn;
	this.consolidated = 	new Array();

	this.tabContainer =    ( typeof(tabDiv) == "undefined" ) ? this.tabContainer : tabDiv;
	this.subTabContainer = ( typeof(subTabDiv) == "undefined" ) ? this.subTabContainer : subTabDiv;
	this.pageContainer =   ( typeof(pageDiv) == "undefined" ) ? this.pageContainer : pageDiv;
	this.TabData.Load(componentShortName, function(){self.onDataLoad();});
	// All further actions in .onDataLoad.
};
//----------------
// Create. But attach an existing TabData. (for "Consolidated View")
//
this.CreateAttach =	function( componentShortName, gateBtn, tabDataObj )
{
	this.destroy();
	this.cShort =			componentShortName;
	this.gateBtn =			gateBtn;
	this.consolidated = 	new Array();
	this.TabData =			tabDataObj;
	this.onDataLoad();		// All further actions.
};
//----------------
// TabData has attached its script(s) and loaded component data
//
this.onDataLoad = function()
{
	this.modules = this.TabData.getModules();
	this.createTabRow();
	this.createSubTabRow();
	this.hasBeenCreated = true;
	try {
		$(function() { $('textarea').autogrow('textarea'); });	// Autogrow all newly created textarea boxes.
	} catch(e2) {
		; // ie8 and maybe 9 does not support this
	}
	if ( this.gateBtn )
	{
		this.gateBtn.disabled = false;
		this.gateBtn.blur();
	}
	setTimeout(function(){self.attachActions();}, 1000);

	//this.Switch(0, 0); /* don't paint. certain styles need to be on-screen when moved/shown. */
};

// ***************************************************************************************
/* private */
// ***************************************************************************************
this.destroy = function()
{
	if ( this.hasBeenCreated )
	{
		var myNode = document.getElementById(this.tabContainer);
		while (myNode.firstChild) {
			myNode.removeChild(myNode.firstChild);
		}
		myNode = document.getElementById(this.subTabContainer);
		while (myNode.firstChild) {
			myNode.removeChild(myNode.firstChild);
		}
		myNode = document.getElementById(this.pageContainer);
		while (myNode.firstChild) {
			myNode.removeChild(myNode.firstChild);
		}
	}
};

// Switch Tab and Subtab.  If current, repaint.
//
this.aux = function(Tab, SubTab)
{
	this.TabData.setData(" and now for something completely different.");
	// If only primary tab defined, pull last active subtab.
	if ( (SubTab < 1) || (typeof(SubTab) == "undefined") )
	{
		SubTab = ( typeof(this.currentSubTabs[Tab]) == "undefined" ) ? 1 : this.currentSubTabs[Tab];
		SubTab = Math.max(SubTab, 1);
	}
	this.switchTab(Tab);
	this.switchSubTab(SubTab);
	this.updateMeters();
	scroll(0,0);
};
	
// ***************************************************************************************
this.switchTab = function(Tab)
{
	var TabContainer = document.getElementById(this.tabContainer);
	this.currentTab = Tab;
	var i = 1;
	for ( var eTab=TabContainer.firstChild ; eTab ; eTab=eTab.nextSibling )
	{
		if (( eTab.tagName == "A" ) || ( eTab.tagName == "a" ))
		{
			if ( objectLength(this.modules) < 4 )
				eTab.className    = (i == Tab) ? "tab_current_lrg" : "tab_grey_lrg";	// < 4, bigger tabs
			else
				eTab.className    = (i == Tab) ? "tab_current" : "tab_grey";
			eTab.blur();
			i++;
		}
	}
	// NOTE: If content-dependent resizing in necessary, harvest from PPDB project.
}; /* switchTab */

// ***************************************************************************************
this.switchSubTab = function(SubTab)
{
	this.currentSubTabs[this.currentTab] = SubTab;	// will create first time.
	this.currentSubTab = SubTab;
	var CurSubTab = null;	// obj. for focus.
	//
	// Show/Hide the subTabs 
	//
	for ( mKey in this.modules )
	{
		var Bar = document.getElementById("subTabBar" + mKey);
		Bar.style.display = ( mKey == this.currentTab ) ? "block" : "none";
		
		for ( var j=1 ; j <= this.modules[mKey][1].length ; j++ )
		{
			var SubTab = document.getElementById("subTab" + mKey + j);
			if ( SubTab )
			{
				var indicator = getFirstElementById(SubTab, "subTabIndicato", "span", "r");
				if (( this.currentTab == mKey ) && ( this.currentSubTab == j ))
				{
					CurSubTab = SubTab;
					SubTab.className   = "subTab_current";
					indicator.style.display = "block";
					tRect = SubTab.getBoundingClientRect();
					iRect = indicator.getBoundingClientRect();
					indicator.style.top = "" + (tRect.bottom - tRect.top - 4) + "px"; /* 4 == border widths. make it dynamic*/
					indicator.style.left = "" + (((tRect.right - tRect.left) / 2) - ((iRect.right - iRect.left) / 2) - 1) + "px";
				} else {
					SubTab.className   = "subTab";
					indicator.style.display = "none";
				}
				SubTab.blur();
			}
		}
		Bar.blur();
	}
	//
	// Update Page Content if needed for this type of subtab
	//
	if ( (this.currentTab == this.getConsolidatedTab()) && (this.currentSubTab != 1) )
	{
		this.updateConsolidatedTable( this.currentSubTab - 1 );
	}
	//
	// Show/Hide Page
	//
	for ( mKey in this.modules )
	{
		for ( var j=1 ; j <= this.modules[mKey][1].length ; j++ )
		{
			var TabPage = document.getElementById("tabPage" + mKey + "" + j);
			if ( TabPage )
			{
				TabPage.style.display = (( this.currentTab == mKey ) && ( this.currentSubTab == j )) ? "block" : "none";
				TabPage.setAttribute("aria-hidden", (( this.currentTab == mKey ) && ( this.currentSubTab == j )) ? "false" : "true" ); // screen-readers
				TabPage.blur();
			}
		}
	}
	if ( CurSubTab )
		CurSubTab.firstChild.focus();	// on a new page, set focus to LINK of the subtab. (because subtab isn't an img)
	//
	// Set Back/Next actions
	//
	var bBack = document.getElementById("tabBack");
	var bNext = document.getElementById("tabNext");
	if ( (this.currentTab == 1) && (this.currentSubTab == 1) )	// If entry point, back to Splash.
	{
		// "SystemTechRequirements" has a different splash... This is what I get for not implementing the full stack wizard.
		bBack.onclick = ( this.cShort == "STR" ) ? function() { pageview_switch(8); } : function() { pageview_switch(5); };
	} else {
		var tabBack =    ( this.currentSubTab == 1 ) ? parseInt(this.currentTab - 1) : this.currentTab;
		var subTabBack = ( this.currentSubTab == 1 ) ? this.modules[this.currentTab-1][1].length : parseInt(this.currentSubTab - 1);
		bBack.onclick = function() { self.Switch(tabBack, subTabBack); };
	}
		
	if ( (this.currentTab == objectLength(this.modules)) && (this.currentSubTab == this.modules[this.currentTab][1].length) )
	{
		bNext.onclick = function() { tabview_finish(1); }; // If last screen, Next out to "Finish"
	} else {
		var crossingTabs = ( this.modules[this.currentTab][1].length <= this.currentSubTab );
		var tabNext =    crossingTabs ? parseInt(this.currentTab) + 1 : this.currentTab;
		var subTabNext = crossingTabs ? 1 : parseInt(this.currentSubTab) + 1;
		bNext.onclick = function(iPassByVal, jPassByVal) 
								{ return function() { self.Switch(iPassByVal, jPassByVal); }; }(tabNext, subTabNext);
	}
	//bBack.blur();
	//bNext.blur();
};

// ----------------------------------------------------------------------
//
this.createTabRow = function()
{
	var sslink = document.getElementById("SpreadsheetLink");
	if ( sslink )
	{
		sslink.innerHTML = "<a href='spreadsheets/" + this.cShort + " Questions and Requirements.xlsx'><img width='30' height='30' src='img/excel.png' title='Spreadsheet of "+this.cShort+" questions and requirements'/></a>";
	}
	
	var container = document.getElementById(this.tabContainer);
	if ( container )
	{
		var first = true;
		for ( mKey in this.modules )
		{
			if ( ! first )
			{
				// If not first iter, put an arrow after the Tab just drawn.  This will not do it for the last.
				var rArrow = document.createElement('img');
				rArrow.setAttribute('src', 'img/arrow-18-xxl.png');
				rArrow.setAttribute('alt', 'arrow');
				rArrow.setAttribute('height', 30);
				rArrow.setAttribute('width', 40);
				rArrow.style.verticalAlign = "middle";
				rArrow.style.marginRight = "2px";
				container.appendChild(rArrow);
			}
			first = false;
			// Create actual tab.
			var classname = ( objectLength(this.modules) < 4 ) ? 'tab_grey_lg' : 'tab_grey';	// < 4, bigger tab.
			var rTab = document.createElement('a');
			rTab.setAttribute('id', 'Tab' + mKey);
			rTab.setAttribute('class', classname);
			rTab.setAttribute('href', '#');
			rTab.onclick = function(passByVal) { return function() { self.Switch(passByVal, 0); }; }(mKey);
			var meter = this.createMeter(mKey, 0);
			rTab.innerHTML = meter + this.modules[mKey][0];
			container.appendChild(rTab);
		}
	}
};

// ----------------------------------------------------------------------
this.createSubTabRow = function()
{
	var container = document.getElementById(this.subTabContainer);
	if ( container )
	{
		var eWrapper = document.createElement('div');	// for the double-border
		eWrapper.id = "subTabBarWrapper";
		eWrapper.className ="subTabBarWrapper";
		container.appendChild(eWrapper);
		
		for ( mKey in this.modules )
		{
			var eBar = document.createElement('div');
			eBar.id = "subTabBar" + mKey;
			eBar.className = "subTabBar";
			eWrapper.appendChild(eBar);
		
			var first = true;
			for ( var j=1 ; j <= this.modules[mKey][1].length ; j++ )	// base 1.
			{
				if ( ! first )
				{			
					// If not first iter, put an arrow after the Tab just drawn.  This will not do it for the last.
					var rArrow = document.createElement('img');
					rArrow.setAttribute('src', 'img/arrow-18-xxl.png');
					rArrow.setAttribute('alt', 'arrow');
					rArrow.setAttribute('height', 25);
					rArrow.setAttribute('width', 30);
					rArrow.style.verticalAlign = "middle";
					rArrow.style.marginBottom = "2px";
					eBar.appendChild(rArrow);
				}
				first = false;
				
				var eSubTab = document.createElement('span');
				eSubTab.setAttribute('id', "subTab" + mKey + "" + j);
				eSubTab.setAttribute('class', "subTab");
				
				eLink = document.createElement('a');
				eLink.setAttribute('href', '#');
				eLink.onclick = function(iPassByVal, jPassByVal) 
								{ return function() { self.Switch(iPassByVal, jPassByVal); }; }(mKey, j);
				eSubTab.onclick = function(iPassByVal, jPassByVal) 
								{ return function() { self.Switch(iPassByVal, jPassByVal); }; }(mKey, j);
				var meter = this.createMeter(mKey, j);
				eLink.innerHTML = meter + this.modules[mKey][1][j-1];
				
				var eIndicator = document.createElement('span');
				eIndicator.setAttribute('id', "subTabIndicator" + mKey + "" + j);
				eIndicator.setAttribute('class', "subTabIndicator");
				eIndicator.style.display = "none";
				
				eSubTab.appendChild(eLink);
				eSubTab.appendChild(eIndicator);
				eBar.appendChild(eSubTab);
			}
		}
		//
		// Create Pages.  Prepend personal breadcrumbs.
		//
		container = document.getElementById(this.pageContainer);
		for ( mKey in this.modules )
		{
			for ( var j=1 ; j <= this.modules[mKey][1].length ; j++ )
			{
				var tabPageName = "tabPage" + mKey + "" + j;
				
				// Create tabPage
				var eTabPage = document.createElement('div');
				eTabPage.id = tabPageName;
				eTabPage.className = "tabPage";
				
				// Create tabPage breadcrumbs
				var crumbs = [Components[this.cShort], this.modules[mKey][0], this.modules[mKey][1][j-1]];
				var s = "";
				for ( var cIdx=0 ; cIdx < crumbs.length ; cIdx++ )
				{
					//s += "<a href='javascript:void();' class='crumb'>" + crumbs[cIdx] + "</a>";
					s += crumbs[cIdx];
					if ( cIdx < (crumbs.length-1) )
						s += "<img src='img/arrow.png' />";
				}
				var crumbHTML = "<div class='breadcrumbs'>" + s + "</div>";
				//
				// Determine if this is "Custom Requirements".  Later, we'll have pages.js define this.
				var isCustomRequirements = ( this.modules[mKey][1][j-1].search("Additional") >= 0 ) ? 1 : 0; // not boolean. 1. 
				//
				// gather static tabPage content. Check for module-specific first, then fall back to common if there.
				// Usually this is for Overview pages, or instructional text before questions.
				//
				var tpContent = null;
				if ( TabPages && (typeof(TabPages[tabPageName]) != "undefined") )
					tpContent = TabPages[tabPageName];
				else if ( CommonTabPages && typeof(CommonTabPages[tabPageName]) != "undefined" )
					tpContent = CommonTabPages[tabPageName];
				else
					tpContent = [0, tabPageName + " content will go here "]; // match TabPages syntax!
				//
				// Gather dynamic page content.
				//
				var content = tpContent ? tpContent[1] : "";
				var questionContent = "";
				var questions = this.TabData.getQuestions(mKey, j);	// Tab==module, subTab==category
				questions = this.TabData.sortByUserNum(questions);
				// Create and append html in that order.
				for ( sortIdx in questions )
				{
					var q = questions[sortIdx];
					questionContent += this.createQuestionHTML(q.uqi, q, "", isCustomRequirements);
				}
				//
				// Determine if this is "Consolidated".  Later, we'll have pages.js define this.
				//
				if ( (mKey == this.getConsolidatedTab()) && j != 1 )
				{
					content = this.createConsolidatedTable( j-1 );	// Consolidate Expected.
				}
				if ( isCustomRequirements )
				{
					questionContent += this.createCustomRequirementsButton( j-1 );
				}
				//
				// Build the actual page.  If no questions or if tabPage content is marked "prepend", then include it.
				//
				var fPrepend = ( tpContent && (tpContent[0] == 1) );
				if ( (fPrepend) || ( questionContent.length < 2 ) )
					eTabPage.innerHTML = crumbHTML + content + questionContent;
				else
					eTabPage.innerHTML = crumbHTML + questionContent;
					
				container.appendChild(eTabPage);
			}
		}
	}
};

// ----------------------------------------------------------------------
// create HTML for question.
//		@uqi:	uqi.
//		@q:		question object
//		@sterile:	optional string.  If anything, prepend to ID, and do not create onclick/onblur actions. (For Tiny Box popup)
//		@editMode:  0=normal, 1=editingExisting, 2=creatingNew
//
this.createQuestionHTML = function(uqi, q, sterile, editMode)
{
	if ( q.type == "req" )
	{
		return this.createReqHTML(uqi, q, sterile, editMode);
	} else if ( q.type.search("radiotext") == 0 ) {
		var numTextFields = Math.max(1, parseInt(q.type.replace("radiotext", "")));
		return this.createRadioText2HTML(uqi, q, 1, numTextFields, sterile, editMode);
	} else if ( q.type.search("checkboxestext") == 0 ) {
		var numTextFields = Math.max(1, parseInt(q.type.replace("checkboxestext", "")));
		return this.createCheckboxesTextHTML(uqi, q, numTextFields, sterile, editMode);
	} else if ( q.type.search("text") == 0 ) {
		var numTextFields = Math.max(1, parseInt(q.type.replace("text", "")));
		return this.createRadioText2HTML(uqi, q, 0, numTextFields, sterile, editMode);
	} else {
		return "unknown question type: " + q.type + " in question " + uqi;
	}
	
};

// ----------------------------------------------------------------------
// q. Question object.
//
this.createReqHTML = function (qNum, q, sterile, editMode)
{
	var rName = "radio" + qNum;
	var curVal = this.TabData.getAnswer(rName);

	var s = "";
	if ( editMode != 2 )	//normal
	{
		s += "<div id='qheader'>";
		if ( editMode == 1 )
		{
			// But if editMode is 1, it's a Custom Requirement and gets edit/delete buttons.
			s += "<button type='button' class='qEdit'   title='Edit' onclick='tabview_customReq(2, "+qNum+");'>&nbsp;</button>";
			s += "<button type='button' class='qDelete' title='Delete' onclick='tabview_customReq(3, "+qNum+");'>&nbsp;</button> ";
		}
		s += "Requirement " + q.userNum + ":&nbsp;&nbsp;&nbsp;" + q.title + "</div>";
		s += "<div id='qanswer'>";
		s += "<span id='qcontent'>" + q.text + "</span>";
	} else {
		// Editing or Creating custom in a tinybox. Title and Text and editable/saveable.
		s += "<div id='qheader'>New Requirement: No. " + q.userNum + "</div>";
		s += "<div id='qheader'>Title:<br/><textarea id='"+sterile+"title" + qNum + "' class='qEditTitle' maxlength='255' onfocus='TINY.box.onFocusClear(this);'>" + q.title + "</textarea></div>";
		s += "<div id='qanswer' style='margin-left:0px;'>";
		s += "<span id='qcontent' style='margin-left:25px;'>Requirement Text:<br/><textarea id='"+sterile+"description"+qNum+"' class='qEditText' rows='8' onfocus='TINY.box.onFocusClear(this);'>" + q.text + "</textarea></span>";
	}
	//	
	// For styling, the label must appear immediately after 'input'.  The label visually lays over the input.
	//
	var tableId = makeString(sterile) + "radioReq" + rName;
	s += "<span id='qanswerRight'>";
		s += "<table class='radioReq' id='"+tableId+"'><tr>"
		s += 	"<td class='label0'>Don't Need It</td>";
		s +=	"<td class='label1'>Would Be Nice</td>";
		s += 	"<td class='label2'>Highly Desired</td>";
		s +=	"<td class='label3'>Critical</td>";
		s += "</tr>";
		s += "<tr>";
		for ( var idx=0 ; idx < 4 ; idx++ )
		{
			// class covers color. rName is per-question. idx is value AND color AND id.
			var rId = makeString(sterile) + rName + "_" + idx;
			var rGroupName = makeString(sterile) + rName;
			var altText = this.TabData.getAltText(qNum, idx);
			var className = "radio" + idx;
			if ( idx == 3 )
				s += "<td style='border-right:none;'>";
			else
				s += "<td>";
			s += 	"<input id='"+rId+"' class='"+className+"' type='radio' name='"+rGroupName+"' " +
					"aria-label='" + altText + "' value='" + idx + "' ";
			
			if ( makeString(sterile).length < 1 ) {
				this.objectActions.push([rId, "onclick", function(v1,v2)
										{return function(){onTabViewRadio(v1, v2);};}(rName,idx)]);
			} else {
				this.objectActions.push([rId, "onclick", function(v1)
										{return function(){onTabViewRefresh(v1);};}(tableId)]);	// Just refresh, not save.
			}
			if ( curVal == ("" + idx) )	// careful of that JS trick of empty string equals zero.
				s += " checked ";
			s += "/>";
			s += "<label>&nbsp;</label></td>";
		}
		s += "</tr>";
		s += "</table>";
		//
		// And the text box
		//
		var textLabel = (q.textLabel) ? q.textLabel : "Additional Details:";
		var tName = "text" + qNum + "_1";
		var tVal = this.TabData.getAnswer(tName);
		var tId = makeString(sterile) + tName;
		var altText = this.TabData.getAltText(qNum, idx);
	
		s += "<span id='qcontentRight'>" + textLabel + "</span><br/>"; // qData[(qDataIdx+q)]
		s += "<textarea id='"+tId+"' name='" + tName + "' class='qtextRight' rows='4' maxlength='255' aria-label='"+altText+"' ";
		if ( makeString(sterile).length < 1 ) {
			this.objectActions.push([tId, "onblur", function(v1)
									{return function(){onTabViewText(v1);};}(tName)]);
		}
		s += ">" + tVal + "</textarea>";
	
		s += "</span>"; // qanswerRight
	s += "</div>";
	return s;
};
// ----------------------------------------------------------------------
// Unless specified in extended data, it is assumed the radio button is a Yes/No.
// 		NOTE - TODO : The extended data isn't supported yet, and everything is a yes/no.
//
this.createRadioText2HTML = function(qNum, q, numRadioQuestions, numTextQuestions, sterile, editMode)
{
	var rName = "radio" + qNum;
	var curVal = this.TabData.getAnswer(rName);

	// Title
	var s = "<div id='qheader'>Question " + q.userNum + ":&nbsp;&nbsp;&nbsp;" + q.title + "</div>";
	// Main question
	s += "<div id='qanswer'><span id='qcontent'>" + q.text + "</span></div>";
	
	// Radio
	if ( numRadioQuestions )
	{
	var tableId = makeString(sterile) + "radioReq" + rName;
	s += "<div id='qanswer'>";
	s += "<span id='qcontent' style='width:336px;'>" + q.radioLabel + "</span>";	// 336=500-164 = width text - width 2btn radio.
	s += "<table class='radioReq' id='"+tableId+"'><tr>";
	s += 	"<td class='label0'>No</td>";	// black.
	s +=	"<td class='label0'>Yes</td>";	// Feature change. Customer wantes No and Yes to both be black. was "label12 green".
	s += "</tr>";
	s += "<tr>";
	for ( var idx=0 ; idx < 2 ; idx++ )
	{
		// For styling, the label must appear immediately after 'input'.  The label visually lays over the input.
		// id needed? class covers color. rName is per-question. idx is value and color and id.
		var rId = makeString(sterile) + rName + "_" + idx;
		var className = "radio" + (idx * 0); // Feature Change. Customer wants No and Yes to both be black.
		var altText = this.TabData.getAltText(qNum, idx);
  		s += "<td><input id='"+rId+"' class='" + className + "' type='radio' name='"+rName+"' value='" + idx + "'" +
				"aria-label='altText' ";
			if ( makeString(sterile).length < 1 ) {
				this.objectActions.push([rId, "onclick", function(v1,v2)
										{return function(){onTabViewRadio(v1, v2);};}(rName,idx)]);
			} else {
				this.objectActions.push([rId, "onclick", function(v1)
										{return function(){onTabViewRefresh(v1);};}(tableId)]);	// Just refresh, not save.
			}
			if ( curVal == ("" + idx) )		// careful of that JS trick where empty string equals zero.
				s += " checked ";
		s += "/>";
		s += "<label>&nbsp;</label></td>";
	}
	s += "</tr>";
	s += "</table>";
	s += "</div>";
	}
	else {
	 var breakpoint = 4;
	}
	// Text questions.
	if ( (typeof(numTextQuestions) == "undefined") || isNaN(numTextQuestions) )
		numTextQuestions = 1;
	for ( var qIdx=1 ; qIdx <= numTextQuestions ; qIdx++ )
	{
		var tName = "text" + qNum + "_" + qIdx;
		var tVal = this.TabData.getAnswer(tName);
		var tId = makeString(sterile) + tName;
		var altText = this.TabData.getAltText(qNum, qIdx + 1);	// base 1 + the 2 for Yes and No.

		s += "<div id='qanswer'>";
		s += "<span id='qcontent'>" + q.textLabels[qIdx-1] + "</span><br/>"; // qData[(qDataIdx+q)]
		s += "<textarea id='" + tId + "' name='" + tName + "' class='qtext' rows='4' maxlength='255' aria-label='"+altText+"' ";
		if ( makeString(sterile).length < 1 ) {
			this.objectActions.push([tId, "onblur", function(v1)
									{return function(){onTabViewText(v1);};}(tName)]);
		}
		s += ">" + tVal + "</textarea>";
		s += "</div>";
	}

	return s;
};
// ----------------------------------------------------------------------
this.createCheckboxesTextHTML = function(qNum, q, numTextQuestions, sterile, editMode)
{
	var s = "<div id='qheader'>Question " + q.userNum + ":&nbsp;&nbsp;&nbsp;" + q.title + "</div>";
	// Main question
	s += "<div id='qanswer'><span id='qcontent'>" + q.text + "</span></div>";
	
	// Checkboxes
	s += "<div id='qanswer'>";
	s += "<span id='qcontent' style='width:450px;'>" + q.checkLabel + "</span><br/>";
	s += "<div class='qcheckboxWrapper'>";
	for ( var idx=0 ; idx < q.checkBoxLabels.length ; idx++ )
	{
		var cName = "check" + qNum + "_" + (idx + 1);
		var cVal = this.TabData.getAnswer(cName);
		var cId = makeString(sterile) + cName;
		var altText = this.TabData.getAltText(qNum, idx);
		var className = "qcheckbox";
  		s += "<label class='" + className + "'><input type='checkbox' id='"+cId+"' name='"+cName+"' aria-label='"+altText+"' ";
		if ( makeString(sterile).length < 1 ) {
			this.objectActions.push([cId, "onclick", function(v1)
									{return function(){onTabViewCheckbox(v1);};}(cId)]);
		}
		if ( cVal == "1"  )
			s += " checked ";
		s += "/>";
		s += q.checkBoxLabels[idx];
		s += "</label><br/>";
	}
	s += "</div>";
	s += "</div>";
	
	// Text questions.
	if ( (typeof(numTextQuestions) == "undefined") || isNaN(numTextQuestions) )
		numTextQuestions = 1;
	for ( var qIdx=1 ; qIdx <= numTextQuestions ; qIdx++ )
	{
		var tName = "text" + qNum + "_" + qIdx;
		var tVal = this.TabData.getAnswer(tName);
		var tId = makeString(sterile) + tName;
		var altText = this.TabData.getAltText(qNum, (qIdx + q.checkBoxLabels.length - 1));

		s += "<div id='qanswer'>";
		s += "<span id='qcontent'>" + q.textLabels[qIdx-1] + "</span><br/>";
		s += "<textarea id='" + tId + "' name='" + tName + "' class='qtext' rows='4' maxlength='255' aria-label='"+altText+"' ";
		if ( makeString(sterile).length < 1 ) {
			this.objectActions.push([tId, "onblur", function(v1)
									{return function(){onTabViewText(v1);};}(tName)]);
		}
		s += ">" + tVal + "</textarea>";
		s += "</div>";
	}

	return s;
};

// ----------------------------------------------------------------------
// AttachActions.  The lovely ie8/9 browsers fail to create onclick and onblur actions if they are in the innerhtml when
// an object is dynamically created.  Even when the functions are static.  This works on every other browser. ie8 ____.
// To compensate, actions are queued during creation, and this is called back after the paint.  This routine then
// attaches functions to the existing dom objects.
//
this.attachActions = function ()
{
	var action;
	for (var n=0 ; n < this.objectActions.length ; n++)
	{
		action = this.objectActions[n];
		if ( action )
		{
			var obj = document.getElementById(action[0]);
			if ( obj )
			{
				if ( action[1] == "onclick" )
					obj.onclick = action[2];
				if ( action[1] == "onblur" )
					obj.onblur = action[2];
			}
		}
	};
}

// ----------------------------------------------------------------------
// The Consolidated View Table.  Create the table and structural array. 'update' fills it in with data.
// @mKey = The module.
//
this.createConsolidatedTable = function ( mKey )
{
	this.consolidated[mKey] = new Array();

	var tableId = "consolidated" + mKey;
	var questions = this.TabData.getQuestions(mKey, 0);
	questions = this.TabData.sortByUserNum(questions);
	for ( var sortIdx in questions )
	{
		var q = questions[sortIdx];
		var uqi = q.uqi;
		//
		// Per-question, add all sub-questions.
		//
		this.consolidated[mKey][uqi] = new Array();
		var type = q.type;
		if ( type == "req" )
		{
			this.consolidated[mKey][uqi]["radio" + uqi] = ["req", 1];
		}
		else if ( type.search("radiotext") == 0 )
		{
			this.consolidated[mKey][uqi]["radio" + uqi] = ["radio", 1];
			this.consolidated[mKey][uqi]["text" + uqi] = ["text", q.textLabels.length];
		}
		else if ( type.search("checkboxestext") == 0 )
		{
			this.consolidated[mKey][uqi]["check" + uqi] = ["check", 1];
			this.consolidated[mKey][uqi]["text" + uqi] = ["text", q.textLabels.length];
		}
		else if ( type.search("text") == 0 )
		{
			this.consolidated[mKey][uqi]["text" + uqi] = ["text", q.textLabels.length];
		}
	}
	//
	// And then create the visual table(s).  This module only!
	//
	cMKey = mKey;
	var reqModule = this.getConsolidatedTab() - 1;	// Requirements is the one before Consolidated. (define this in pages.js?)
	var s = "<div class='conWrapper'>";
	if ( cMKey != reqModule )	// Every question is it's own group. (Expected Uses, Data to be Managed, Arch & Constraints)
	{
	    s += "<span class='conWrapperLeftPane' style='width:100%;'>";
		// Left Pane Header
		var tco = 1;	// Title Color Oscilator.  GUI-only.  Cycle through classes on conTitle for shading effect.
		for ( var sortIdx in questions )
		{
			var q = questions[sortIdx];
			var cUqi = q.uqi;
			tco++;
			var numRows = 0;
			s += "<table id='" + tableId + cUqi + "' class='conTable'><tr>"
			s += 	"<td class='conNumber' rowspan='ROWSPANREPLACE'>" + q.userNum + "</td>";
			s += 	"<td class='conTitle" + ((tco%2)+1) + "' rowspan='ROWSPANREPLACE'>" + q.title + "</td>";
			for (var cGroups in this.consolidated[cMKey][cUqi] )
			{
				// Specific Group (individual text field, radio button suite, individual check box
				var sgType = this.consolidated[cMKey][cUqi][cGroups][0];
				var	sgItems = this.consolidated[cMKey][cUqi][cGroups][1];
				for ( var sgItem=1 ; sgItem <= sgItems ; sgItem++ )
				{
					var aId, qLabel;
					if ( sgType == "req" )   { qLabel = q.radioLabel;				aId = sgType + cUqi; }
					if ( sgType == "radio" ) { qLabel = q.radioLabel;				aId = sgType + cUqi; }
					if ( sgType == "check" ) { qLabel = q.checkLabel;				aId = sgType + cUqi; }
					if ( sgType == "text" )  { qLabel = q.textLabels[sgItem - 1];	aId = sgType + cUqi + "_" + sgItem; }
					
					var answerText = this.TabData.getAnswerText(aId);
					var tdId = "con" + aId;

					if ( numRows > 0 )
						s += "</tr><tr>";
					s += "<td class='conText'>" + qLabel + "</td>";
					s += "<td class='conAnswer' id='" + tdId + "'>" + answerText + "</td>";
					this.objectActions.push([tdId, "onclick", function(v1)
											{return function(){onTabViewUpdateAnswer(v1);};}(q.uqi)]);

					numRows++;
				}
			}
			s = s.replace("ROWSPANREPLACE", "" + numRows);
			s = s.replace("ROWSPANREPLACE", "" + numRows);
		}
		s += "</tr></table>";
		s += "</span>"; // left pane
		s += "<span class='conWrapperRightPane' style='width:20px;'>";
			s += "&nbsp;"	// Visually empty, but its presence forces word wrapping.
		s += "</span>"; // end right pane.
	}
	else // cMKey is a requirements module.  Do Category-based grouping.  (Requirements)
	{
	    s += "<span class='conWrapperLeftPane'>";
		// Left Pane Header
		s += "<div class='conWrapperReqHeader'>";
			s+= "<table class='conTable'><tr><td class='conCategory'>Category</td><td class='conNumber'>No.</td><td class='conTitleReq'>Requirement</td><td class='conAnswerReq0'>Rating</td><td class='conAnswerTextReq'>Additional Details</td></tr></table>";
		s += "</div>";
		// Left Pane Content (individual tables)
		s += "<div class='conWrapperReq'>";
		var tco = 1;			// Title Color Oscilator.  GUI-only.  Cycle through classes on conTitle for shading effect.
		var lastCategory = 0;	// last category while looping through questions.  Crossing thresholds ends the grouping.
		var numRows = 0;		// for this category
		for ( var sortIdx in questions )
		{
			var q = questions[sortIdx];
			var cUqi = q.uqi;
			var thisCategory = q.category;
			if ( thisCategory != lastCategory )
			{
				if ( lastCategory > 0 )
				{
					s += "</table>";
					s = s.replace("ROWSPANREPLACE", "" + numRows);
					numRows = 0;
				}
				s += "<table id='" + tableId + "_cat" + thisCategory + "' class='conTable'><tr>"
				s += "<td class='conCategory" + ((tco%2)+1) + "' rowspan='ROWSPANREPLACE'>" + this.modules[mKey][1][thisCategory-1] + "</td>";
				lastCategory = thisCategory;
				tco++;
			} else {
				s += "<tr>";
			}
			
			if ( q.type != "req" )
				alert ( "ALERT: Someone put a non-requirement question in the Requirements Category.  That's a no-no." );
			
			var reqAnswerId = "radio" + q.uqi;
			var textAnswerId = "text" + q.uqi + "_1";			// Additional Text.   TODO: Magic id there...
			reqAnswer = this.TabData.getAnswer(reqAnswerId);	// the integer.  will be used for class and actual text.
			reqAnswer = (reqAnswer == "") ? "-" : reqAnswer;	// dash if unanswered.
			textAnswer = this.TabData.getAnswer(textAnswerId);
			
			s += "<td class='conNumber'>" + q.userNum + "</td>";
			s += "<td class='conTitleReq'>" + q.title + "</td>";
			s += "<td class='conAnswerReq" + reqAnswer + "' id='con" + reqAnswerId + "'>" + reqAnswer + "</td>";
			s += "<td class='conAnswerTextReq' id='con" + textAnswerId + "'>" + textAnswer + "</td>";
			this.objectActions.push(["con"+reqAnswerId, "onclick", function(v1)
									{return function(){onTabViewUpdateAnswer(v1);};}(q.uqi)]);
			this.objectActions.push(["con"+textAnswerId, "onclick", function(v1)
									{return function(){onTabViewUpdateAnswer(v1);};}(q.uqi)]);
			s += "</tr>";
			numRows++;
		}
		s += "</table>";	// end last table
		s = s.replace("ROWSPANREPLACE", "" + numRows);	// close up last table.
		s += "</div>"									// end content.
		s += "</span>"									// end left pane.
		s += "<span class='conWrapperRightPane'>";		// start right pane.
		// Right Pane Header - "Legend Key" 
		s += "<div class='conWrapperLegendHeader'>";
		s +=   "<table class='conTable'><tr><td class='conCategory'>Rating Key</td></tr></table>";
		s += "</div>";
		// Right Pane Content - "Legend Key"
		s += "<div class='conWrapperLegend'><table>";
		s += "<tr><td class='key'>Unanswered</td><td class='conAnswerReq-'>" + "-" + "</td></tr>";
		for ( var r=0 ; r < RequirementsOptions.length ; r++ )
		{
			s+= "<tr><td class='key'>" + RequirementsOptions[r] + "</td><td class='conAnswerReq"+r+"'>" + r + "</td></tr>";
		}
		s += "</table></div>";	// end table and content
		s += "</span>"; // end right pane.
		s += "</div>"; // wrapper
	}
	
	s += "</div>";
	return s;
}
// ----------------------------------------------------------------------
// (Re-)fill table with current values
//
this.updateConsolidatedTable = function ( mKey )
{
	cMKey = mKey;
	for ( var cUqi in this.consolidated[cMKey] )
	{
		for (var cGroups in this.consolidated[cMKey][cUqi] )
		{
			// Specific Group (individual text field, radio button suite, individual check box
			var sgType = this.consolidated[cMKey][cUqi][cGroups][0];
			var	sgItems = this.consolidated[cMKey][cUqi][cGroups][1];
			for ( var sgItem=1 ; sgItem <= sgItems ; sgItem++ )
			{
				//
				// "req" types get radio&text, and change the class too...
				//
				if ( sgType == "req" )
				{
					// req radio
					var answerId = "radio" + cUqi;
					var answer = this.TabData.getAnswer(answerId);
					answer = (answer == "") ? "-" : answer;	// dash if unanswered. IE doesn't show empty spans.
					var tdId = "con" + answerId;
					var tdObj = document.getElementById(tdId);
					if ( tdObj )
					{
						tdObj.innerHTML = "<a href='#'>" + answer + "</a>";	// link for keyboard tabbing.
						tdObj.className = "conAnswerReq" + answer;
					}
					// req additional details
					answerId = "text" + cUqi + "_" + sgItem;
					tdObj = document.getElementById("con" + answerId);
					if ( tdObj )
					{
						tdObj.innerHTML = this.TabData.getAnswer(answerId) + "&nbsp;";	// IE doesn't show empty spans
					}
				} else {
					var answerId = (sgType == "text") ? sgType + cUqi + "_" + sgItem : sgType + cUqi;
					var answerText = this.TabData.getAnswerText(answerId);
					var tdId = "con" + answerId;
					var tdObj = document.getElementById(tdId);
					if ( tdObj )
					{
						tdObj.innerHTML = "<a href='#'>" + answerText + "</a>&nbsp;";  // link for 508c tabbing
					}
}	}	}	}	}

// ----------------------------------------------------------------------
// The Custom Requirements. Paint what's there, and then "add more" html.
//
this.createCustomRequirementsButton = function ( mKey )
{
	var s = "";
	s += "<div id='qheader'><button type='button' aria-label='Add Requirement' class='glassyAddRequirement' onclick='tabview_customReq(1, 0);'/></div>";
	return s;
}

// ----------------------------------------------------------------------
// Add/Edit/Delete Custom Requirement.  Add/Edit: Create Tiny Box. Delete: Pop a JS confirmation.
//
this.customReq = function ( action, uqi )
{
	if ( action == 1 )
	{
		// Add
		var qs = this.TabData.getQuestions(this.currentTab, 0);
		var q = qs.pop();	// q is now the first requirement. We don't care.
		// Sanitize.
		q.uqi = this.TabData.makeUQI();
		q.title = "Enter Title";
		q.text = "Enter Description";
		var qHTML = this.createQuestionHTML(q.uqi, q, "create", 2);
		var title = "Create Additional Requirement";
	
		TINY.box.show(TinyBoxHTML(title, qHTML, true), 0, 750, 0, 0, 0);	// 750 = qContent + padding + margin.
		setTimeout(function(){self.attachActions();}, 1000);
		//TINY.box.neuter(); // due to "Insane Chrome Bug", cannot neuter. trust the questionHTML to have been made properly.
	}
	if ( action == 2 )
	{
		// Edit
		var q = this.TabData.getQuestion( parseInt(uqi) );
		if ( q == null )
		{
			alert ( "Error. The Requirement was not found (requirement uqi # " + uqi + ")" );
		} else {
			var qHTML = this.createQuestionHTML(q.uqi, q, "tiny", 2);
			var title = "Edit Additional Requirement";
	
			TINY.box.show(TinyBoxHTML(title, qHTML, true), 0, 750, 0, 0, 0);	// 750 = qContent + padding + margin.
			setTimeout(function(){self.attachActions();}, 1000);
			//TINY.box.neuter(); // due to "Insane Chrome Bug", cannot neuter. trust the questionHTML to have been made properly.
		}
	}
	if ( action == 3 )
	{
		// Delete
		var q = this.TabData.getQuestion( parseInt(uqi) );
		if ( q == null )
		{
			alert ( "Error. The Requirement was not found (requirement uqi # " + uqi + ")" );
		} else {
			if ( confirm("Are you sure you wish to delete the additional requirement: " + q.title + "?") )
			{
				this.TabData.removeQuestion(uqi);								// Delete Q from TabData.
				this.TabData.setData();											// Set TabData to database.
				pageview_reloadTabView( "Removing Additional Requirement..." );	// Destroy all and reload from db.
				return;															// And GET OUT!
			}
		}
	}
}

// ----------------------------------------------------------------------
// User has clicked Next on the end of the Consolidated run.  Check to see if
// they have satisfied all requirements. If so, continue, if not, message.
//
this.onFinish = function ( a )
{
	var tab = this.getConsolidatedTab();
	var reqModule = this.getConsolidatedTab();	// Requirements is the one before Consolidated. (define this in pages.js?)
	var percent = this.getMeterPercent(tab, reqModule);
	if ( percent <= 98 )
	{
		alert("You must provide a rating for all requirements before continuing.  Click any field(s) you wish to change and a pop-up window will appear allowing you to enter information or edit the previously entered information.");
	} else {
		pageview_switch(7);
	}
}
// ----------------------------------------------------------------------
// Force a DOM redraw of element (and all sub-elements).  See Insane Chrome Bug in onRadio.
// Set toggle visibility vs display. The refresh happens, but does not disrupt geometry of screen.
//
this.forceRedraw = function( e )
{
	return;	// Insane Chrome Bug no longer occurs.  And this refresh breaks keyboard access.
	if ( e )
	{
		var dType = e.style.visibility;
		e.style.visibility = "hidden";
		setTimeout(function(){ e.style.visibility = dType;},5); // short as possible.
	}
}
// ----------------------------------------------------------------------
// Force a DOM redraw of element by id.
//
this.onRefresh = function( id )
{
	//this.forceRedraw(document.getElementById(id));
}
// ----------------------------------------------------------------------
// radio button selected. save.
//
this.onRadio = function(rName, val)
{
	//alert("onRadio: " + rName + ", " + val );
	if (( rName.search("tiny") != 0 ) && ( rName.search("create") != 0 ))
	{
		this.TabData.setAnswer(rName, val);
		this.updateMeters();
	}
	// Insane Chrome Bug Fix. Chrome stopped showing the radio properly, spontaniously 11/25/2014.
	// So force a redraw.  That does it.
	// March/2015:  Chrome no longer does it and ICBF is no longer needed.  whatever.
	//this.forceRedraw(document.getElementById("radioReq" + rName));
};
// ----------------------------------------------------------------------
// checkbox clicked. save.
//
this.onCheckbox = function(cName)
{
	var cObj = document.getElementById(cName);
	var val = (cObj.checked) ? 1 : 0;
	this.TabData.setAnswer(cName, val);
	this.updateMeters();
};
// ----------------------------------------------------------------------
// text field has changed. save.
//
this.onTextEntry = function(tName)
{
	var tObj = document.getElementById(tName);
	var val = tObj.value;
	//alert( "onTextEntry: " + tName + ", " + val );
	this.TabData.setAnswer(tName, val);
	this.updateMeters();
};
// ----------------------------------------------------------------------
// TinyBox value is being saved.  Trust it.
// @arr = array of all user input elements.  key=id, val=val (or check value)
//
this.onSave = function( arr )
{
	// alert("onSave: " + arr.toString() );
	// Determine if creating or saving existing.
	var fCreate = false;
	var fNeedReload = false;
	for ( k in arr )
		fCreate = fCreate || ( k.search("create") >= 0 );
	//
	if ( fCreate )
	{
		// Create Q in db and truly save to file.
		var newQ = this.TabData.createQuestion( arr, this.currentTab, this.currentSubTab );	// tab/sub == module, category
		this.TabData.setData();
		// Reload EVERYTHING to avoid nasty inserts.  Then GET OUT.
		pageview_reloadTabView("Saving Additional Requirement...");
		return;
	}
	else
	{
		for ( tName in arr )
		{
			var val = arr[tName];
			var tID = tName.replace(new RegExp("tiny", 'g'), "");	// tID is now the "real" q's id.  ('tinytiny' prefix used on edit)
			var a = document.getElementById(tID);
			if ( ! a )
			{
				// Saving custom information which does not have a "real" mirror.  (or error)
				if ( ( tID.search("title") == 0 ) || ( tID.search("description") == 0 ) )
				{
					this.TabData.setAnswer(tID, val);
					fNeedReload = true;
				} else {
					alert("error on save: " + tID);
				}
			}
			else if ( a.type == "radio" )
			{
				a.checked = true;
				a.click();								// Trigger front-door state and saving action.
			}
			else if ( a.type == "checkbox" )
			{
				a.checked = (val) ? false : true;		// BACKWARDS! on purpose.
				a.click();								// Reverse the backwards and trigger front-door saving action.
			}
			else
			{
				a.value = val;
				if ( a.click )
					a.click();							// triggers front-door saving action radio/check
				if ( a.onblur )
					a.onblur();							// triggers front-door saving action text.
				// note: cannot check hasAttribute(). If an action is dynamically attached, it doesn't count as an attribute.
			}
		}
	}
	// Put to file.
	this.TabData.setData();

	// Refresh screens.  Either just consolidated or reload the world.
	if ( fNeedReload )
		pageview_reloadTabView( "Saving Additional Requirement..." );
	else
		setTimeout(function(){self.updateConsolidatedTable( self.currentSubTab - 1 );}, 160); //up screen showing. asynchronously.
};
// ----------------------------------------------------------------------
// request to edit answer from Consolidated View.  Launch a popup editor.
//
this.onUpdateAnswer = function(uqi)
{
	var q = this.TabData.getQuestion(uqi);
	var qHTML = this.createQuestionHTML(uqi, q, "tiny");
	var title = "Edit " + ((q.type == "req") ? "Requirement" : "Question");
	
	TINY.box.show(TinyBoxHTML(title, qHTML, true), 0, 750, 0, 0, 0);	// 750 = qContent + padding + margin.
	setTimeout(function(){self.attachActions();}, 1000);
	//TINY.box.neuter();													// kill onclick and onblur actions. "Save" is the only game.
};

// ----------------------------------------------------------------------
// Which major tab is the Consolidated one for this Component? It's the last one.
//
this.getConsolidatedTab = function()
{
	return (this.modules) ? objectLength(this.modules) : 4;
	// actually, you're in big trouble if there's no modules obj.
}

// ----------------------------------------------------------------------
// create progress meter img.  For Tab size or SubTab size
// meter icons exist every 12%. 
//
this.createMeter = function( tab, subTab, percentIn )
{
	var size = (subTab == 0) ? 35 : 25;		// smaller on subTabs.
	var percent = this.getMeterPercent(tab, subTab, percentIn);
	var iPerc = this.meterMath(percent);	// incremental percentage.
	var src = "img/progressball/ProgressBall_" + iPerc + ".png";
	var id = "meter" + tab + "_" + subTab;
	var meter = "<img id='"+id+"' src='" + src + "' alt='" + iPerc + "' height='"+size+"' width='"+size+"' style='vertical-align: middle; padding-right: 4px;'/>";
	return meter;
};
// ----------------------------------------------------------------------
// Update the meters to a new percentage #.  For SubTab, Main Tab, related Consolidated Subtab, and Main Consolidated Tab.
//		@tabIn, @subTabIn (optional). If both defined, start with that subtab.  Else use current tab/subtab.
//		@percentIn (optional).  If all defined, do that specfic meter and nothing else.
//
this.updateMeters = function( tabIn, subTabIn, percentIn )
{
	var tab = 	 ( typeof(tabIn) == "number" ) ? tabIn : parseInt(this.currentTab);
	var subTab = ( typeof(subTabIn) == "number" ) ? subTabIn : parseInt(this.currentSubTab);
	if ( typeof(percentIn) == "number" )
	{
		this.updateMeter( tab, subTab, percentIn );
	} else if ( tab == this.getConsolidatedTab() ) {
		// Consolidated. Update it, and the entire module it's consolidating.
		this.updateMeter( tab, subTab );
		this.updateMeters( subTab-1, 0 );	// RECURSIVE.
	} else {
		// Normal.
		if ( subTab )
		{
			this.updateMeter( tab, subTab );
		} else if ( tab ) { // updating whole module. Update every subtab.
			var numModules = this.modules[tab][1].length;
			for ( var m=1 ; m <= numModules ; m++ )
			{
				this.updateMeter( tab, m );
			}
		}
		this.updateMeter( this.getConsolidatedTab(), tab+1 );
	}
}
// ----------------------------------------------------------------------
// Update the meters to a new percentage #.  For both subtab and Main tab.
//	@tab and @subTab. Mandatory. (if you optional, use updateMeters())
//  @percentIn (optional). If omitted. Calculate.  If given, ONLY defined tab, not related subtab/mainTab.
//
this.updateMeter = function( tab, subTab, percentIn )
{
	// for subTab and Tab, with possible short-circuits.
	for ( var i=0 ; i <= 1 ; i++ )
	{
		// i == 0, subtab.
		if ( i == 1 )
		{
			// main tab. (possible double-tap)
			subTab = 0;
			if ( typeof(percentIn) == "number" )
				return; // explicit request already handled
		}

		var percent = this.getMeterPercent( tab, subTab, percentIn );
		mObj = document.getElementById("meter" + tab + "_" + subTab);
		if ( mObj )
		{
			var iPerc = this.meterMath(percent);
			var src = "img/progressball/ProgressBall_" + iPerc + ".png";
			mObj.src = src;
			mObj.blur();
		}
	}
};
// ----------------------------------------------------------------------
// get percent for a given tab/subtab.
//	If it's a Consolidated tab, then the subTab represents an entire module. Hence, this routine.
//  If Consoldated and no sub-tab, that represents all questsion across all modules.
//
this.getMeterPercent = function( tab, subTab, percentIn )
{
	if ( tab == this.getConsolidatedTab() )	// Consolidated
	{
		if ( subTab != 1 )	// If subtab==1, its Overview. No module-shift.
		{
			tab = ( subTab>1 ) ? subTab-1 : 0;
			subTab = 0;
		}
	}
	var percent = ( typeof(percentIn) == "number" ) ? percentIn : this.TabData.percent(tab, subTab);
	return percent;
};

// ----------------------------------------------------------------------
// given true percentage, return incremental percentage that actually has an image file for it.  round up.
//
this.meterMath = function( percent )
{
	// values that have associate image files in "img/progressball/".
	var increments = [0, 5, 12, 25, 37, 50, 62, 75, 87, 99, 100];
	for ( var i=0 ; i < increments.length ; i++ )
	{
		if ( percent <= increments[i] )
			return increments[i];
	}
	return 100; // num > 100 given.
};

// ----------------------------------------------------------------------
// create the data CSV file from everything collected.  Have TabData make it, this level offers the Save box.
// @userFriendly:  if false, save the DATA file to be imported.  If 1, create user-readable file.
//
this.createDataCSV = function()
{
	var fileData = this.TabData.createCSV();
	
	// Naming Convention:  IM_requirements_<component>_mmddyyyy-hhmm.csv
	var D = new Date();
	var hh = D.getHours()%12; // massage military and 2-digit.
	var dateStamp = "" + pad0(D.getMonth()+1) + pad0(D.getDate()) + D.getFullYear() + "-" + pad0(hh) + pad0(D.getMinutes());
	var fileName = "IM_requirements_" + this.cShort + "_" + dateStamp + ".csv";
	
	saveTextAs(fileData, fileName);
}
// ----------------------------------------------------------------------
// create the user-readable CSV file from everything collected.  Have TabData make it, this level offers the Save box.
//
this.createUserCSV = function()
{
	var csv = "Number, Module, Title, Text, Answer Provided, Additional Details Provided" + "\r\n\r\n";
	
	var delim = ",";
	var questionContent = "";
	var questions = this.TabData.getQuestions(0, 0);	// 0, 0 = everything.
	questions = this.TabData.sortByUserNum(questions);
	for ( sortIdx in questions )
	{
		var q = questions[sortIdx];
		csv += ( q.type == "req" ) ? "Requirement " + q.userNum : "Question " + q.userNum;
		csv += delim;
		csv += (this.modules[q.module]) ? this.modules[q.module][0] : "-";
		csv += delim;
		csv += this.csvTrim(q.title) + delim;
		csv += this.csvTrim(q.text) + delim;

		// Grab answers, based on type.		
		var aType = "";
		if 		( q.type.search("req") == 0 ) 				{ aType = "req"; }
		else if ( q.type.search("radiotext") == 0 ) 		{ aType = "radio"; }
		else if ( q.type.search("checkboxestext") == 0 ) 	{ aType = "check"; }
		else if ( q.type.search("text") == 0 ) 				{ aType = "text"; }
		
		var numTextFields = Math.max( 1, (parseInt(q.type.replace(/\D/g, "")) || 0) );
		if ( aType != "text" ) {
			csv += this.csvTrim(this.TabData.getAnswerText(aType + q.uqi)) + delim;
		}
		for ( var i=1 ; numTextFields && (i <= numTextFields) ; i++ ) {
			csv += this.csvTrim(this.TabData.getAnswerText("text" + q.uqi + "_" + i)) + delim;
		}
		csv += "\r\n";
	}

	// Naming Convention:  IM_requirements_<component>_mmddyyyy-hhmm.csv
	var D = new Date();
	var hh = D.getHours()%12; // massage military and 2-digit.
	var dateStamp = "" + pad0(D.getMonth()+1) + pad0(D.getDate()) + D.getFullYear() + "-" + pad0(hh) + pad0(D.getMinutes());
	var fileName = "IM_requirements_USER_INFORMATION_" + this.cShort + "_" + dateStamp + ".csv";
	// Give it a nice title header:
	var fileData = "IM Requirements User Information: " + this.cShort + " Component. " + dateStamp + "\r\n\r\n" + csv;
	
	saveTextAs(fileData, fileName);
}
this.csvTrim = function(s){
	var regx = new RegExp(",", 'g');	// globally replace. (multiple instances)
	return s.replace(regx, "-").replace("&nbsp;","").replace("<b>","").replace("</b>","");
}
};	// end TabView

// ----------------------------------------------------------------------
// Auto-grow textareas.  Increase height to remove scrollbars.
//                       Do not decrease, as no defined trigger and don't want to refresh everything on every keyclick.
//						 Per customer, have a maximum grow size, after which let the scroll bar do its thing.
//						 Inception credit to github.com jquery-grab-bag autogrow.
//
(function($)
{
	$.fn.autogrow = function(inputtypes)
	{
		//return this.filter('textarea').each(function()
		return this.filter(inputtypes).each(function()
		{
			var self  = this;
			var $self = $(self);
			var update = function()
			{
				var maxAGHeight = 700; // max pixel height.
				if ( (self.clientHeight < self.scrollHeight) && (self.clientHeight < maxAGHeight) )
				{
					var newH = Math.min( self.scrollHeight + 2, maxAGHeight );
					self.style.height = newH+"px";
					this.Refresh();
				}
			}
			//$self.change(update).keyup(update).keydown(update);
			$self.change(update).keyup(update);
			$(window).resize(update);
			update();
		});
	};
})(jQuery);

