//
// ToolDB.  API wrapper for 'jstorage' and ActiveX FSO.
//
//		The database is a cross-browser key-value store database to persistently store data locally through a browser.
//		jstorage's Under-pinning layer can be prototype or JSON2.
//        We are using JSON2 to avoid the need of using jQuery.noConflict() and altering all subsequent jQuery code.
//
//		jstorage works for all browsers, mostly.  HOWEVER!  ON IE "file://" protocol (and only file protocol)
//		access does not allow "localStorage" which is what jstorage uses.  
//
//		For IE in "file://", ToolDB engages ActiveX and saves key-value data to a physical file.  The file name is the key.
//		This triggers the full ActiveX authentication warning and acceptance to the user.
//		If ActiveX fails, ToolDB falls back and does a session save, which does NOT persist across browser re-launch.
//
// SINGLETON
//		Delay-Load the Singleton so that user gets any potential ActiveX message after the first page draws, but immediately after.
//		All consumers are to use "ToolDB."
//
var ToolDB = null;

function oToolDB () {
this.mode = 0;				// 0==undetermined, 1==ActiveX, 2==jstorage, 3==SessionFallback. Negative==error.
this.stamp;					// validation stamp
this.fso = null;			// if ActiveX, FileStorageObject
this.dbdir = "";			// if ActiveX, db file directory
this.cfdir = "";			// if ActiveX, "ConsolidatedFiles" directory.
this.prefetch = "";			// if prefected, contents of file between prefetch and get. (async temp storage).
this.sessionStorage;		// if Session Storage, the actual "database".  (when ActiveX and jstorage are a bust.)

// ----------------
// Determine proper underpinning storage.  If ActiveX available, create and open file.  If jstorage, trust it.
// **** DO NOT TOUCH JSTORAGE IF IT'S AN IE BROWSER!  JSTORAGE WON'T BE THERE AND THE THREAD WILL THROW ****
//
this.init = function()
{
	// Session mode default until something better is found. (Sure hope it is.)
	this.mode = 3;
	this.sessionStorage = new Array();

	// ActiveX available?  If so, use it.
	if ( IsExplorer )
	{
		try {
			this.fso = new ActiveXObject("Scripting.FileSystemObject");
			if ( this.fso )
			{
				// If no fso this already threw.
				this.mode = 1;
			
				var p = window.location.pathname;
				p = decodeURI(p);	// handle the possible %20's.
				var front = ( p.indexOf("/") == 0 ) ? 1 : 0;
				this.dbdir = p.substring(front, p.lastIndexOf("/")) + "/activexdb/";
				this.cfdir = p.substring(front, p.lastIndexOf("/")) + "/../ConsolidatedFiles/";
			}
		} catch(e2) {
			// Uh oh.  Probably User said "No", or this is an http session.
			this.fso = -1;
		}
	}
	// jStorage available?	(If no ActiveX)
	if ( this.mode != 1 )
	{
		if ( $.jStorage && $.jStorage.storageAvailable() && $.jStorage.currentBackend() )
			this.mode = 2;
	}
	
	this._setStamp();
};

// ----------------
// Return mode.  Negative version if marker failed.  If failed, ensure 'mode' switches to SessionFallback!
//
this.getMode = function()
{
	// when opened, was the validation stamp saved successfully?
	var dbStamp = this.get("imrgt");
	if ( dbStamp && (dbStamp.search(this.stamp) >= 0) )
	{
		return this.mode;				// success.
	} else {
		return (this.mode < 0) ? this.mode : -1 * this.mode;	// return the negative.
	}
}
// ----------------
// Caller has acknowledged an error situation and is switching to session fallback.
//
this.setSessionMode = function()
{
	this.mode = 3;
}

// ----------------
// Return a string equvalence for mode.
//
this.getModeString = function()
{
	var mode = this.getMode();
	var modeString = "NONE";
	switch ( mode )
	{
		case 0:	modeString = "No database mode set.";												break;
		case 1: modeString = "ActiveX to file in directory '" + this.dbdir + "'";					break;
		case 2: modeString = "jstorage, with backend '" + $.jStorage.currentBackend() + "'";		break;
		case 3: modeString = "Session Storage";														break;
		case -1: modeString = "ActiveX - With Validation Error!";									break;
		case -2: modeString = "jstorage - With Validation Error!";									break;
		case -3: modeString = "Session Storage - With Validation Error!";							break;
		default: modeString = "NONE";
	}
	return modeString;
}
// ----------------
// returns the used value.
this.set = function( key, val )
{
	var ret = null;
	val = "" + val;	// force to string.
	if ( key )
	{
		if ( this.mode == 1 )
		{
			var f = this.fso.OpenTextFile(this.dbdir + key + ".txt", 2, true); // name, forWriting/Destroy, create if necessary.
			f.WriteLine(val);
			f.Close();
			ret = val;
		}
		if ( this.mode == 2 )
		{
			ret = $.jStorage.set(key, val);
		}
		if ( this.mode == 3 )
		{
			this.sessionStorage[key] = val;
			ret = val;
		}
	}
	return ret;
};

// ----------------
// on failure, return null
//
this.get = function( key )
{
	if ( this.prefetch && this.prefetch.length )
	{
		var value = this.prefetch;
		this.prefetch = "";
		return value;
	}
	var value = null;
	if ( key )
	{
		if ( this.mode == 1 )
		{
			var filename = this.dbdir + key + ".txt";
			if ( this.fso.FileExists(filename) )
			{
				var f = this.fso.OpenTextFile(filename, 1, false); 	// name, readonly, do not create.
				value = f.ReadLine();
				f.Close();
			}
		}
		if ( this.mode == 2 )
		{
			value = $.jStorage.get(key);
		}
		if ( this.mode == 3 )
		{
			value = this.sessionStorage[key];
			if ( typeof(value) == "undefined" )
				value = null;
		}
	}
	return value;
};

// ----------------
// Be Careful !!
//
this.deleteKey = function( key )
{
	this.set( key, "" );
}

// ----------------
// Explicitly get contents of an actual file from cfdir. Path won't be allowed/passed, so either it's there or bust.
// Mode 1 (ActiveX) only. Return null for all else.
//
this.getFile = function( filename )
{
	var value = null;
	if ( ( filename ) && ( filename.length ) && ( this.mode == 1 ) )
	{
		var fullpath = (filename.search(":")) ? filename : this.cfdir + filename;
		if ( this.fso.FileExists(fullpath) )
		{
			var f = this.fso.OpenTextFile(fullpath, 1, false); 	// name, readonly, do not create.
			value = f.ReadLine();
			f.Close();
		}
	}
	return value;
};

// ----------------
// Load from specific file, rather than from key. (Consolidated Dir request.)
// Store in prefetch member variable on async loads to be grabbed later on the 'get' request.
//
this.prefetchFile = function( filename )
{
	this.prefetch = "";
	if ( filename )
	{
		if ( this.mode == 1 )
		{
			if ( this.fso.FileExists(filename) )
			{
				var f = this.fso.OpenTextFile(filename, 1, false); 	// name, readonly, do not create.
				this.prefetch = f.ReadLine();
				f.Close();
			}
		}
		if ( this.mode > 1 )
		{
			if ( 1 )
			{
				readTextFile("ESM.txt");
			}
			if ( 0 )
			{
				if ( window.File && window.FileReader )
				{
				var reader = new FileReader();
				reader.onload = function(e) {
					alert("file baby: " + e.target.result); this.prefetch = e.target.result; 
					};
				reader.onerror = function(e) { ; /* it's not there. we know. */ };
				reader.readAsText(filename);
				}
			}
			if ( 0 )
			{
				var fs = requestFileSystemSync(TEMPORARY, 1024*1024 /*1MB*/);
				var fileEntry = fs.root.getFile(filename, {create: false});
			}
		}
	}
	return true;
};

// ----------------
// Set the validation stamp on this instance.  Proving we can save and retrieve something.
//
this._setStamp = function()
{
	this.stamp = new Date().getTime();
	this.set("imrgt", this.stamp);
}

// Conscientiously not implementing index, delete, flush.
};	// end ToolDB
// Delay-set Singleton.
setTimeout(function() {ToolDB = new oToolDB(); ToolDB.init();}, 200);

function readTextFile(file)
{
  window.URL = window.webkitURL || window.URL; // Vendor prefixed in Chrome.

  var boogie = window.URL.createObjectURL("ESM.txt");
  alert (boogie);
	return ;
	
	
    var rawFile = new XMLHttpRequest();
    rawFile.open("GET", file, false);
    rawFile.onreadystatechange = function ()
    {
        if(rawFile.readyState === 4)
        {
            if(rawFile.status === 200 || rawFile.status == 0)
            {
                var allText = rawFile.responseText;
                alert(allText);
            }
        }
    }
    rawFile.send(null);
}
