// ***********************************************************************
// Common and Helper functions
// ***********************************************************************
//
var IsExplorer = (	( navigator.appName.search(/Explorer/i) > 0 ) ||
					( navigator.appVersion.toLowerCase().match(/(msie)/) ) ||
					( navigator.userAgent.toLowerCase().match(/(trident)/) ));
					
// ---------------------------------------------------------------------
// Given a root object, an id, and a type (i.e., 'input', 'textarea')
// return the FIRST element of that type which either MATCHES that id or STARTS with the id+separator
// Speed not too important, as this is off a user interaction. (very similar to getInputsByIdPrefix)
//
function getFirstElementById( root, targetid, inputType, separator )
{
	var retElem = null;
	var allElems = root.getElementsByTagName( inputType );
	for ( var i=0; i < allElems.length; i++ )
	{
		if ( allElems[i].id == targetid )
			return allElems[i];
		// If not, try "targetid + separator" as a prefix for this id.
		if ( (separator.length) && ( allElems[i].id.length >= (targetid.length + separator.length) ) )
		{
			var targetPrefix = targetid + separator;
			var idPrefix = allElems[i].id.substr(0, targetid.length + separator.length);
			if ( targetPrefix == idPrefix )
				return allElems[i];
		}
	}
};
// -----------------------------
// Length of object. No language-native way to do this for associate arrays.
//
function objectLength( o )
{
	if ( typeof(o)=="undefined" ) return null;
	var len = 0;
	for (var key in o)
	{
		if ( o.hasOwnProperty(key) )
			len++;
    }
	return len;
}
// -----------------------------
// Return "first" key of an object. Or rather, "a" key, because object is unordered.
// No language-native way to do this for associative arrays.
//
function firstKey( o )
{
	if ( typeof(o)=="undefined" ) return null;
	var len = 0;
	for (var key in o)
	{
		if ( o.hasOwnProperty(key) )
			return key;
    }
	return null;
}
// -----------------------------
// indexOf for associative arrays.
// No language-native way to do this for associative arrays.
//
function keyOf( o, val )
{
	if ( typeof(o)=="undefined" ) return null;
	var len = 0;
	for (var key in o)
	{
		if ( ( o.hasOwnProperty(key) ) && ( o[key] === val ) )
			return key;
    }
	return null;
}
// -----------------------------
// Return SORTED array of keys for an object/Array.  numeric = sort array as numbers? false = lexigraphical.
//
function sortedKeys(obj, numeric)
{
    var keys = [];
    for(var key in obj)
    {
        if(obj.hasOwnProperty(key))
        {
            keys.push(key);
        }
    }
	numeric = ( (typeof(numeric) == "undefined") || (numeric == 0) ) ? false : true;
	if ( numeric )
		keys.sort(function(a, b){return a-b});
	else
		keys.sort();
	return keys;
}

// -----------------------------
// Given anything, return String equivalent. Always returns a String.
//
function makeString (x)
{
	var type = typeof(x);
	if ( type == "string" )
		return x;
	else if ( (type == "undefined") || (type == "null") )
		return "";
	else
		return "" + x;
}

// -----------------------------
// Dynamically load and attach script anytime after page-load
//
function loadScript( filename )
{
	var current = isScriptLoaded(filename);
	if ( (current != null) )
	{
		current.parentNode.removeChild(current);
	}
	var E = document.createElement('script');
	E.setAttribute("type", "text/javascript");
	E.setAttribute("src", filename);
	document.getElementsByTagName("head")[0].appendChild(E);
}
// -----------------------------
// Determine if a given script is loaded already. Return dom obj.
//
function isScriptLoaded( filename )
{
	var scripts = document.getElementsByTagName("script");
	for ( var i=0 ; i < scripts.length ; i++ )
	{
		if ( scripts[i].getAttribute("src") == filename )
			return scripts[i];
	}
	return null;
}
// -----------------------------
// encode to html. (This isn't in JS language?)
//
function htmlEncode(s)
{
	return String(s)
				.replace(/&/g, '&amp;')
				.replace(/"/g, '&quot;')
				.replace(/'/g, '&#39;')
				.replace(/</g, '&lt;')
				.replace(/>/g, '&gt;');
}
// -----------------------------
// Strip quotes for HTML output in an onclick/onblur/etc action.
// Since a link (or other action) gets embedded in html as a string, single or double quotes destroy the call.
// Cannot use html encoding, as browsers properly process an encoded quote as an actual quote.
// (Note: TinyBox gets around this, but only because it processes the text while displaying.
//
function stripQuotes(s)
{
	return String(s).replace(/"/g, "").replace(/'/g, "");
}
// -----------------------------
// Date functions don't have a built-in way to do two-digit days/months.
//
function pad0(n)
{
	var s = makeString(n);
	return (n<10) ? "0"+s : s;
}
