//
// DropDown Menu controller.
//
// DDM controls the show/hide of any collection of Absolute-placed divs.
// DDM's can be most classically menus, but also tool tips and pop-ups.
// The object is a Static Singleton so there can only be one active/open menu at a time.
//
// (Original base courtesy (http://javascript-array.com/scripts/simple_drop_down_menu/)
// Tool tip expansion and Objectification to ensure uniqueness and 508c across a large project: bkenney.
//
var ddm = {
	timeout:		500,	/* mouseout grace factor. configurable. */
	closeTimer:		0,		/* closeTimer semiphore */
	closeLock:		0,		/* popping semiphore lock. prevents click-through click events from closing before paint. */
	openMenu:		0,		/* active menu obj. */

// open this id.  Make visible where it is.
open: function(id)
{
	obj = document.getElementById(id);
	
	if ( (this.openMenu) && (this.openMenu.id == obj.id) )
	{
		this.cancelCloseTime();		// If this layer already active, leave it alone.
	} else {
		this.close();								// If another layer is active, close it.
		this.closeLock = window.setTimeout(function(){ddm.cancelCloseLock()}, ddm.timeout); // Set closeLock semiphore
		this.openMenu = obj;						// Set and show new layer.
		this.openMenu.style.visibility = 'visible';
	}
},

// pop this id.  Make visible at the anchor object's pos, so one id can move to different locations.
//				anchorObj may be DOM obj or mouse click event.
//				@title, @text: fill in dynamic text if provided.
//
pop: function(anchorObj, id, title, text)
{
	obj = document.getElementById(id);
	
	if ( (this.openMenu) && (this.openMenu.id == obj.id) )
	{
		this.close();	// clicked while open? close.
	} else {
		// set title/text
		document.getElementById(id + "Title").innerHTML = title;
		document.getElementById(id + "Text").innerHTML = text;
		// Grab X/Y location.  	Use mouse if event is a mouse event, use obj location is event is dom obj.
		// 						Do not check on "hasOwnProperty" because IE fails that test, because...IE.
		var thisLeft = 0;
		var thisTop = 0;
		if ( anchorObj.clientX )
		{
			thisLeft = anchorObj.clientX;
			thisTop = anchorObj.clientY;
		} else if ( anchorObj.offsetLeft ) {
			thisLeft = anchorObj.offsetLeft;
			thisTop = anchorObj.offsetTop;
		}
		// move to target location.
		var xOffset = Math.max(document.documentElement.scrollLeft,document.body.scrollLeft);
		var yOffset = Math.max(document.documentElement.scrollTop,document.body.scrollTop);
		var xScreenW = Math.min(window.innerWidth, document.body.scrollWidth);
		xScreenW = ( xScreenW ) ? xScreenW : thisLeft;
		var objW = obj.style.width ? obj.style.width : 500;

		var leftNum = thisLeft + xOffset + 15 /* size-of-pointer */;
		leftNum = Math.min(leftNum, xScreenW - objW - 3); /* 3 for border */
		var topNum = thisTop + yOffset;
		obj.style.left = "" + leftNum + "px";	// Setting as the string is the proper method.
		obj.style.top = "" + topNum + "px";
		// and open
		this.open(id);
	}
},

// close showed layer
close: function()
{
	if ( this.openMenu && ! this.closeLock )
	{
		this.openMenu.style.visibility = 'hidden';
		this.openMenu = 0;
		this.cancelCloseTime();
	}
},

// start or reset close timer
closeTime: function()
{
	this.cancelCloseTime();
	this.closeTimer = window.setTimeout(function(){ddm.close()}, ddm.timeout);
},

// cancel just the close lock
cancelCloseLock: function()
{
	this.closeLock = 0;
},

// cancel close timer
cancelCloseTime: function()
{
	if ( this.closeTimer )
	{
		window.clearTimeout(this.closeTimer);
		this.closeTimer = null;
		this.closeLock = 0;
	}
}
}; // end ddm

// close layer when user clicks anywhere.  including trigger and menu.
document.onclick = function(){ddm.close();}; 