﻿//
// Components, Modules, and Questions.   All associative arrays.
//
//	Modules can be overridden per-Component.  
//	data_<component>.js file customizes questions as needed.
//
var Components = {
	"OWQM":	"Online Water Quality Monitoring",
	"CCS":	"Customer Complaint Surveillance",
	"ESM":	"Enhanced Security Monitoring",
	"PHS":	"Public Health Surveillance",
	"CM":	"Consequence Management",
	"STR":	"System Technical Requirements"
};
var ComponentsIndex = {
	0: "OWQM",
	1: "CCS",
	2: "ESM",
	3: "PHS",
	4: "CM",
	5: "STR"
};

// Default Modules.  Can be overridden per module file.  Zero not allowed.
var CommonModules = {
	1:		["Expected Uses of the System", ["Overview", "Questions"]],
	2:		["Data to be Managed", 		["Overview", "Questions"]],
	3:		["Requirements Rating",		["Overview", "User Interface", "Data Access", "Alerting", "Data Storage", "Additional Requirements"]],
	4:		["Consolidated View", 		["Overview", "Expected Uses of the System Review", "Data to be Managed Review",
											 "Requirements Rating Review"]]
};
// Default Module Abbreviations. Used for Categories in the Consolidated area.  Structure must match CommonModules.
var CommonModulesAbbrs = {
	1:		["Uses", ["OV", "Qs"]],
	2:		["Data", ["OV", "Qs"]],
	3:		["Reqs", ["OV", "UI", "DA", "Alert", "DS", "AR"]],
	4:		["CV", 	 ["OV", "EU", "DM",	 "RRR"]]
};
var Modules = null; 	// declare as global now.  Modules is either defined by component, or CommonModules is used.
var ModulesAbbrs = null; // declare as global now. ModulesAbbrs is either defined by component, or CommonModulesAbbrs is used.
//
// Options for radio buttons defined as "req".  Also defines the # and values by virtue of index
//
var RequirementsOptions = ["Don't Need It", "Would Be Nice", "Highly Desired", "Critical"];
//
// Questions:
//		key: unique questions id.  (uqi).	
//		val: type, title, shortDescription, text, [text for type-dependent sub-parts] .. [] .. [] ..
//
// Component-Specific text, Category association, and user-facing question number appear in component data file (data_<component>.js).
//
// As a matter of _convention only_ to organize it in these files, the numbering of uqis are: 
//			0-100: Expected Uses, 
//			100-200 Data to be Managed, 
//			200-499 Requirements,
//			500-700 System Tech Requirements.
//
// Types:
//		"req"		: Requirement: Displays 4-value radio button. (Don't Need, Would be Nice, Highly Desired, Critical.
//		"radiotext1": Radio Text : Displays a Radio button with No/Yes followed by text field with label next element in 'val'.
//		"radiotext2": Radio Text : radiotext1, with 2 text fields. Labels defined by next 2 elements in 'val'.
//		"radiotextX": Radio Text : X may be any number.
//		"checkboxes": Checkboxes : Displays checkboxes.  Labels defined in extended data.
//		"checkboxestextX" : Checkboxes Text : Displays checkboxes, and X text fields. All labels defined in extended text, 
//
var Questions = {
1: ["radiotext1", "Call management", 
	"The information management system is used to document and track response to customer calls.",
	"The information management system is used to document and track response to customer calls.",
	"Will the system be used in this way?",
	"Additional details:"
	],
2: ["radiotext1", "Regular Data Review", 
	"Data is reviewed via the information management system regularly as specified by utility standard operating procedures.",
	"<p>Data is reviewed via the information management system regularly as specified by utility standard operating procedures.</p> \
<p>Examples:</p> \
<ul> \
<li>System operators review data at the beginning of every shift to assess real-time water quality and support system operation</li>\
<li>Water quality specialists or managers review data twice daily, looking for abnormal water quality</li>\
<li>Equipment technicians review data weekly to identify equipment maintenance needs</li>\
</ul>",
	"Will the system be used in this way?",
	"Additional details:"
	],
3: ["radiotext1", "Continuous monitoring", 
	"The user interface is active and viewable continuously.",
	"<p>The user interface is active and viewable continuously.</p> \
<p>Example:  a dedicated screen in the control room continuously displays real-time water quality data and alerts</p>",
	"Will the system be used in this way?",
	"Additional details:"
	],
4: ["radiotext1", "Triggered data review", 
	"The information management system is accessed to investigate data for a specific purpose.",
	"<p>The information management system is accessed to investigate data for a specific purpose.</p> \
<p>Examples:</p> \
<ul>\
<li>Water quality staff use the system to investigate possible water quality anomalies identified through manual data review or by an automated event detection system</li>\
<li>The system is monitored to ensure water quality is preserved during periods of operations changes or distribution system work</li>\
<li>Managers review water quality data if an elevated number of customer complaints are received</li>\
</ul>",
	"Will the system be used in this way?",
	"Additional details:"
	],
5: ["radiotext1", "Investigation tracking", 
	"The alert investigation process is completed and documented within the information management system.",
	"<p>The alert investigation process is completed and documented within the information management system.</p> \
<p>Examples:</p> \
<ul>\
<li>At the end of each OWQM alert investigation, the investigator enters the final determination of alert cause into the user interface</li>\
<li>When an OWQM alert is received, the investigator opens an online form that walks them through the alert investigation procedures and allows them to enter all relevant information and findings</li>\
<li>Information about alert investigation activities are entered into the system immediately, allowing all users to see progress and even communicate about findings (for example, an OWQM investigator could see that CCS staff have already investigated a similar alert and found it to be possibly valid)</li>\
</ul>",
	"Will the system be used in this way?",
	"Additional details:"
	],
6: ["radiotext1", "Off-line analysis", 
	"Historical data is analyzed to learn typical data patterns and values and to configure the system.",
	"<p>Historical data is analyzed to learn typical data patterns and values and to configure the system.</p> \
<p>Examples:</p> \
<ul>\
<li>Data from the same season in previous years is reviewed to understand seasonal variation in water quality</li>\
<li>Historical data is used to configure data analysis tools, either using an automated or manual evaluation process</li>\
</ul>",
	"Will the system be used in this way?",
	"Additional details:"
	],
101: ["checkboxestext", "Acceptable data management solutions",
	"Which of the following are acceptable data management solutions?",
	"Which of the following are acceptable data management solutions?", /* appended to by component */
	"a)	Select all that apply:",
		[	"Non-digital storage, such as physical binders or log books",
			"A spreadsheet or other simple file-based digital storage",
			"A database or other advanced data storage mechanism",
			"Other (explain in text area below)"
		],
	"b)  Additional details:",
	],
102: ["checkboxestext", "Data storage types",
	"What types of new or existing data will be stored in the information management system?",
	"What types of new or existing data will be stored in the information management system?",
	"a)	Select all that apply:",
		[	"Datastreams currently being collected",
			"New datastreams",
			"Alerts already being generated",
			"New alert types",
			"Other (describe below)",
			"No decision has been made"
		],
	"b)  Additional details:",
	],
103: ["checkboxestext", "Manual or automatic data entry",
	"Will data be entered manually by utility staff or automatically transmitted to the system?",
	"Will data be entered manually by utility staff or automatically transmitted to the system?",
	"a)	Select all that apply:",
		[	"Manual entry",
			"Automatic data transmission",
		],
	"b)  Additional details:",
	],
104: ["text2", "Data transmission frequency", 
	"How frequently will data be transmitted to the information management system?",
	"How frequently will data be transmitted to the information management system (how many minutes are there between data points)?",
	"Enter a numeric value, in minutes:",
	"Additional Details:"
	],
105: ["radiotext1", "Large quantity transmission",
	"Will any equipment transmit abnormally large quantities of data?", 
	"Will any equipment transmit abnormally large quantities of data?",
	"Will any equipment transmit abnormally large quantities of data?",
	"Additional Details:"
	],
106: ["text2", "Data points per day",
	"Approximately how many new data points generated through this component will be entered into the information management system each day?", 
	"Approximately how many new data points generated through this component will be entered into the information management system each day?", 
	"Enter numeric value(s):",
	"Additional Details:"
	],
107: ["checkboxestext", "Manual or automatic data entry",
	"Which types of supplemental information will be transmitted to the information management system?",
	"Which of the following types of supplemental information will be transmitted to the information management system?",
	"Select all that apply:",
		[	"Status indicators or faults from individual instruments",
			"Indicators of individual monitoring station health, such as indicators of power loss",
			"Overall system health indicators, such as the status of the communications system",
			"No decision has been made",
		],
	"b)  Additional details:",
	],
108: ["text2", "Systems where component data is currently being stored",
	"List all systems where component data is currently being stored.",
	"List all systems where component data is currently being stored, if applicable.",
	"Enter Text:",
	"Additional Details:"
	],
109: ["text2", "Days of data available",
	"How many days of the most recent data would ideally be readily available through the user interface?",
	"How many days of the most recent data would ideally be readily available through the user interface?",
	"Enter a numeric value, in days:",
	"Additional Details:"
	],
110: ["checkboxestext", "Needed video-related functionality",
	"Which of the following video-related functionality will be needed through the information management system?",
	"Which of the following video-related functionality will be needed through the information management system?",
	"a) Select all that apply:",
		[	"Video editing",
			"Frame-by-frame advancement",
			"The ability to re-position cameras remotely",
			"The ability to zoom in at high resolution",
			"Video analytics",
			"Audio included in video datastream",
			"Facial recognition",
			"Other (describe below)",
			"No decision has been made",
		],
	"b)  Additional details:",
	],
111: ["checkboxestext", "Information generated outside this component",
	"What information not generated through this component will be used in system operation and alert investigation?",
	"What information not generated through this component will be used in system operation and alert investigation?",
	"a) Select all that apply:",
		[	"Alerts from other components",
			"Data from other components",
			"Information on distribution system maintenance activities",
			"Other (describe below)",
			"No decision has been made",
		],
	"b)  Additional details:",
	],
112: ["checkboxestext", "Data manipulation with external software",
	"What external software products will be used to view and manipulate data exported from the information management system?",
	"What external software products will be used to view and manipulate data exported from the information management system?",
	"a) Select all that apply:",
		[	"Spreadsheet-based application",
			"Advanced statistical or analytics software",
			"Internet or app plugin",
			"Video player or editor",
			"GIS",
			"Database-based product",
			"Other (describe below)",
			"None of these",
		],
	"b)  Additional details:",
	],
113: ["checkboxestext", "Data analysis method(s)",
	"What method(s) for data analysis have been selected?",
	"What method(s) for data analysis have been selected?",
	"a) Select all that apply:",
		[	"Regular manual data review (for example, utility staff review data every eight hours)",
			"Automated alerts based on parameter setpoints or thresholds",
			"Automated analysis using specialized data analysis techniques",
			"Other (describe below)",
			"No decision has been made",
		],
	"b)  Additional details:",
	],

201: ["req", "An intuitive interface",
	"An intuitive user interface which users can begin using with little or no training.",
	"<p>Information management system with intuitive user interfaces are clear to use.  They often function like webpages or common computer software that most users are accustomed to, and thus users can begin using the system with little to no training.  Conversely, other systems may require hours or even days of training before users feel comfortable using the system and getting the information they need.</p> \
<p>A user-friendly system becomes increasingly important as the number and variety of expected system users increases.  It is suggested that this requirement be prioritized if a large number of users is expected, if there will be users from different departments or agencies, or if new users will be frequently added.</p>"
	],
202: ["req", "A quick and easy process for accessing data",
	"A quick and easy process for accessing the data which allows users to obtain the data or reports they desire with just a few clicks.",
	"<p>In a system with a quick and simple process for accessing data, the user can easily obtain the information, tables, or plots they desire with just a few clicks.  In systems without a streamlined data access process, users may have to spend significant time initializing the system, specifying the information they desire, or waiting for plots or reports to be generated.</p> \
<p>The importance of fast access increases as the frequency of information management system use increases.  As the system will be accessed multiple times per day for OWQM, it is suggested that easy access be a strong consideration; users may become frustrated if it is tedious to access the information they need.</p>"
	],

203: ["req", "The ability to analyze and plot data within the user interface",
	"The ability to analyze and plot data within the system user interface, as opposed to having to export data and do these analyses using external tools",
	"<p>Most automated information management systems contain a user interface through which users can directly access and view data.  Generally, data can be viewed in a variety of formats including tabular summaries, time-series plots, control charts, and statistical summaries over an established interval.  Without this functionality, the user must query or export data from the system and then use external tools (such as Microsoft Excel) to analyze or plot the data.  More specific requirements associated with data viewing and plotting are listed under the Data Access category.</p> \
<p>This functionality can dramatically increase the usability of the system – particularly if data is viewed frequently.  It is suggested that this requirement be prioritized unless project constraints make it infeasible.</p>"
	],
204: ["req", "A customizable user interface",
	"A customizable user interface which allows the user to create their own experience, including custom page layouts and links between pages.",
	"<p>A customizable user interface allows the utility to design the user interface to best meet their users' needs, including specifying screen layouts and navigation through screens. The alternative is a system in which the layout and functionality of the interface are pre-defined within the product.  With the ability to customize an interface, screens can be created to match screens from existing user interfaces or designed to specifically support standard operating procedures.</p> \
<p>This functionality is generally valuable if and only if utility staff are interested in and have the skills necessary to design and implement a custom interface.  In many cases, pre-defined interfaces can be sufficient and easy to implement – particularly in products commonly used in the drinking water industry.</p>"
	],
205: ["req", "The ability to easily modify the user interface",
	"A user interface that allows for easy and efficient updates.",
	"<p>This functionality allows for efficient user-requested updates to the user interface.  For example, it is common that through system use, users identify new screens or functionality that would allow for more effective or efficient monitoring.  Without this functionality, changes may require complex coding or significant system re-configuration to implement.</p> \
<p>This functionality is important if there is a strong desire to maintain an effective and user-friendly interface, and if there will be significant system use and thus opportunities to identify desired updates. Unless there is a high degree of confidence that modifications won't be necessary, it is suggested that this functionality be prioritized.  Without the capability to update the interface, the ability of the OWQM component to grow and evolve will be limited.</p>"
	],
206: ["req", "The ability to continuously display real-time data",
	"The ability to develop a real-time, continuously updated display of the most recent data values and alerts.",
	"<p>With this functionality, screens can be developed that are continuously updated with the most recent data.  These screens, which often show real-time data values, plots, a GIS display, or a list of alerts, are intended to be constantly displayed and visible to users.</p> \
<p>This functionality is critical if and only if it is expected that the user interface will be active and viewable continuously, such as displayed on a monitor in the utility control room.</p>"
	],
207: ["req", "The ability to save analyses and views in a digital format",
	"The ability to save analyses, plots, and other views displayed on the user interface in a digital format, such as an Excel or image file.",
	"<p>This functionality allows users to save analyses, plots, and views they've produced within the information management system as a digital file.  They can save their work for their own future use or share it with others electronically.</p> \
<p>This ability is valuable if the information management system can only be accessed from a limited number of locations or if limited users have rights to access the system.  In general, electronic files are an efficient way to save and share information from the information management system.</p>"
	],
208: ["req", "The ability to access data from multiple sources",
	"The ability to access data from multiple data sources through a single user interface.",
	"<p>This functionality allows the user to access data from more than one source within a single interface.  This commonly includes integration of data from multiple SRS components into one display (often referred to as a dashboard).  Without an integrated interface, users generally access the additional data types by logging into separate systems or by contacting individuals who manage the other systems (such as customer service representatives) for the information.  For OWQM users, other data sources that may be useful include information about customer complaints, results from recent distribution system grab samples, system maintenance activities, and operations data such as tank levels or flow.</p> \
<p>An integrated interface is useful to OWQM if and only if there is information stored in separate data system(s) that would be used regularly by OWQM users, and if access to those system(s) is such that time and effort would be saved by not having to enter multiple systems.</p>"
	],
209: ["req", "The ability to develop custom data entry screens",
	"The ability to develop custom screens or forms that allow users to enter data into the system.",
	"FULL TEXT The ability to develop custom screens or forms that allow users to enter data into the system."
	],
210: ["req", "GIS capability",
	"The ability to display and interact with information from the SRS on geographic information systems (GIS) screen(s).",
	"<p>This functionality allows the user to develop Geographic Information Systems (GIS) screens for viewing and interacting with data.  Information from the SRS is displayed spatially over basic GIS layers such as the distribution system pipe network or a street map.  A GIS-based user interface for OWQM generally shows each monitoring location spatially identified, as well as an indication of the current status of each via color-coding or different symbol types.  Common characteristics to be shown for each station include alert status, equipment faults, low flow or pressure indicators, and the status of the communication link.  Below is an example which uses the utility's distribution map.  All utility facilities are included, and OWQM monitoring stations are indicated by a drop of water colored either red or green to show the station's status.</p> \
	<p><img src='qdb/figures/SCADA_Screen_Shot_OWQM.jpg'></p> \
	<p>GIS displays are commonly used when creating a dashboard, which integrates data from multiple data management systems into a single user interface and displays the real-time status of multiple SRS components.  However, they can still be useful if used only for OWQM.  Particularly as the number of monitoring locations increases, a GIS interface can be an efficient way to view information for the entire OWQM component.  Often, a GIS interface is used to create a home page from which users can navigate to the desired information.  A spatial display also allows users to more clearly see the connectivity between monitoring points.</p>"
	],
211: ["req", "The ability to access or control equipment through the information management system",
	"The ability to access or control equipment (such as sensor hardware) through the information management system, which requires the system to send information out in addition to collecting it.",
	"<p>With this functionality, the user is able to access or control equipment through the information management system.  Examples of how this could be used for OWQM include logging into a sensor's user interface to check for instrument faults, running remote diagnostics on the equipment, and actuating autosamplers.</p> \
<p>This functionality is relevant only if there is equipment installed that can be remotely controlled or has an interface that can be remotely accessed.</p>"
	],
212: ["req", "The ability to access the interface from multiple locations",
	"The ability to access the information management system user interface and data from more than one workstation.",
	"<p>This functionality allows users to access the user interface and data from more than one location.  The alternative is access through a single, pre-defined workstation.</p> \
<p>Access from multiple locations is likely not necessary for utilities where all users will be located in the same area (such as if all users work in or near a control room).  However, it becomes increasingly important as the number of expected users increases.</p>"
	],
213: ["req", "Flexible access points",
	"No requirement to pre-define all access points from which the information management system can be accessed.",
	"<p>This functionality allows flexibility in the location of information management system access points.  A common solution is to configure the system so that anyone signed into the utility's computer network can access the user interface.  An alternative (which still allows access from multiple locations) is to establish fixed workstations from which the information management system can be accessed such as laboratories, managers' offices, or in the operations center.</p> \
<p>This functionality generally facilitates system use and staff productivity, allowing users to access the data and interface wherever they are located.  It also provides flexibility if staff change work locations frequently.</p>"
	],
214: ["req", "The ability to access the system from outside the utility network",
	"The ability to access the system from outside the utility network",
	"<p>With this functionality, users outside of the utility network can access the information management system.  External users may include utility crews working in the field, utility staff working from home, and non-utility personnel associated with partner organizations.  One solution that is becoming increasingly popular is to provide access through the internet, allowing users to log in from any device connected to the internet.</p> \
<p>This solution is most useful if the system will frequently be accessed by off-site staff.  It is also convenient if the utility does not have an easily accessible network, or if on-site access points are not available during non-business hours.</p>"
	],
215: ["req", "The ability to control user view privileges",
	"The ability to limit the information and screens that can be viewed by individual users.",
	"<p>With this functionality, administrators can limit the information and screens that can be viewed by individual users.  For example, laboratory staff could be provided water quality data but be blocked from seeing system operations or alert investigation details.</p> \
<p>This functionality may be important if any of the information accessed through the information management system is considered sensitive or if a large variety of users, particularly users outside of the utility, have access to the system.</p>"
	],
216: ["req", "The ability to control user write privileges",
	"The ability to limit individual users' ability to change or store information on the system.",
	"<p>With this functionality, administrators can limit individual users' ability to make any changes or input information into the system.  These users can still view and plot the data as they wish.  Comparing it to a spreadsheet application, they could open and work with a file but not save it.  This ensures that information and system configuration is not changed by users, either intentionally or accidentally.</p> \
<p>This functionality is relevant only if there are opportunities to 'write' to the system (some systems provide only data access and have no ways to enter information).  It becomes increasingly important as the number of users increases, particularly those with no responsibilities requiring them to input information.</p>"
	],
217: ["req", "Individual login accounts with activity tracking",
	"Individual accounts for each user and activity tracking so that the administrator can view system use for individual users.",
	"<p>With this functionality, each user has their own account, and administrators can track system use for individual users.  This may include times the user is logged on and actions they take.  This functionality can be used to document which users are involved in the acknowledgement and investigation of specific alerts.</p> \
<p>This functionality is useful if there are multiple users with defined responsibilities and if there is a desire to track system utilization and evaluate staff performance during investigations.  Note that, for this functionality to provide value, users must consistently log in and out of the system using their own login information.</p>"
	],
218: ["req", "The ability to create custom tables",
	"The ability to create ad hoc custom tabular data summaries, as opposed to being confined to table structures defined during system design.",
	"<p>This functionality allows for the efficient creation of user-defined tables at any time, including selection of the information and time period to display in the table.  Without this ability, the user can only view tables that were pre-defined during system design.</p> \
<p>The large volume of data produced through OWQM generally makes plotting a more effective means for data review compared to tables.  Thus, this functionality is likely not critical unless there are users that expect to build custom tables frequently.</p>"
	],
219: ["req", "The ability to save table templates",
	"The ability to save frequently-used table structures for repeated use.",
	"FULL TEXT The ability to save frequently-used table structures for repeated use."
	],
220: ["req", "The ability to generate tabular summaries of historical data",
	"The ability to generate tabular summaries of historical data (beyond the recent data that is currently active in the system).",
	"FULL TEXT The ability to generate tabular summaries of historical data (beyond the recent data that is currently active in the system)."
	],
221: ["req", "The ability to include metadata in tables",
	"The ability to include supplemental information about data points, such as data quality (i.e., metadata).",
	"FULL TEXT The ability to include supplemental information about data points, such as data quality (i.e., metadata)."
	],
222: ["req", "The ability to include data from more than one data source in tables",
	"The ability to join data from more than one data source in a single table, such as a summary of alerts from multiple SRS components.",
	"FULL TEXT The ability to join data from more than one data source in a single table, such as a summary of alerts from multiple SRS components."
	],
223: ["req", "The ability to create time-series plots",
	"The ability to generate plots showing the value of a datastream as a function of time within the user interface.",
	"<p>Time-series plots show the values of a single parameter across time and are an efficient way to view large amounts of time-series data.  Many information management systems allow users to create time-series plots of monitored parameters within the user interface (the plots shown under the next several requirements are examples).  Without this functionality, users can export data from the system and use external tools such as Excel to create plots.</p> \
<p>Time-series plots are essential for OWQM:  it is infeasible to absorb the large volume of data values produced by looking at tables of values.  Thus, to improve ease of use and reduce effort required by users to review data, it is suggested that this requirement be prioritized.</p>"
	],
224: ["req", "The ability to create custom plots",
	"The ability to create custom plots (including chart type and datastream(s) plotted) as opposed to being confined to figures defined during system design.",
	"<p>This functionality allows for the efficient creation of user-defined plots at any time, including selection of the datastreams and time period to display in the plot.  Without this ability, the user can only view plots that were pre-defined during system design, or export data and use an external tool to produce the desired plots.</p> \
<p>Plots are used extensively in OWQM for regular data review and alert investigation.  Thus, it is suggested that this functionality be prioritized – especially if there are users experienced with generating and manipulating plots (such as in Excel) who would likely expect and frequently use this functionality.</p>"
	],
225: ["req", "The ability to save plot templates",
	"The ability to save templates of frequently-used plots for easy re-generation.",
	"<p>Users often generate the same plots repeatedly as they regularly review water quality data and investigate alerts.  Some information management systems allow the user to save templates for these commonly used plots for easy access.  The plots can then be generated simply by clicking the desired template as opposed to having to re-select the datastream(s), time period and axes.</p> \
<p>The ability to save plot templates can significantly reduce the time required for data review.  The value of this functionality is directly related to the number of datastreams that must be analyzed, the complexity of water quality plots that will be generated, and the level of effort required to create plots in the selected information management system.</p>"
	],
226: ["req", "The ability to plot more than one datastream concurrently",
	"The ability to view more than one datastream concurrently on a single plot.",
	"<p>Significant insight can be gained by viewing more than one parameter on the same plot.  For OWQM, the following data combinations can be useful for data analysis: \
<ul>\
<li>Viewing more than one water quality parameter to investigate if multiple parameters are changing concurrently</li>\
<li>Viewing water quality data along with operations data to see if water quality changes are related to changes in system operations</li>\
<li>Viewing the same water quality parameter from multiple monitoring locations to track propagation of a water quality anomaly through the system</li>\
</ul>\
The figure below illustrates the value of this functionality.  Two water quality parameters (chloramines and conductivity, shown in blue and yellow) from the same location are shown along with the status of a nearby system pump (in green).  This plot clearly demonstrates the relationship between pump status and water quality.</p> \
<p><img src='qdb/figures/Multiple_datastreams.jpg'></p> \
<p>This functionality can be useful for investigating causal relationships and correlations among various datastreams.  It is especially valuable if there are users experienced with reviewing data and generating plots who would likely expect and frequently use this functionality in the information management system.</p>"
	],
227: ["req", "The ability to change the period of data plotted",
	"The ability to change the time period of recent data plotted, such as changing from one day to one hour of data.",
	"<p>This functionality allows users to change the length of time shown on plots (change the x-axis).  Review of time-series data on different timescales can provide insight into trends at various levels of detail.  For example, a short time period can allow for analysis of daily trends impacted by operational changes, whereas longer time periods will reflect seasonal trends impacted by changes in source water quality and treatment processes.  In the following plots the user changed the view from one day to one week to determine if the observed change in chlorine was normal at that site.</p> \
<p><img src='qdb/figures/Change_time_period.jpg'></p> \
<p>The ability to easily change the time period of time-series data plots, rather than being hard-coded to always show data for a set time period (such as the most recent 24 hours) is very useful for understanding system water quality patterns and for investigating potential water quality anomalies with respect to both short and long-term trends.  This functionality is particularly valuable if there are users experienced in data analysis who would likely expect and frequently use this functionality.</p>"
	],
228: ["req", "The ability to change the y-axis scale of data plots",
	"The ability to change the y-axis of data plots in the user interface, which determines the range of data values shown on the plot.",
	"<p>This functionality allows the user to change a plot's y-axis to best view current data.  In systems without this capability, the data range generally needs to be very wide to accommodate all possible values, making analysis of smaller changes in data difficult.  Also, data values do not appear on the plot if they fall outside of the defined range.  In the following plots, the user changed the y-axis range from 0 – 5 to 0 – 1.5 to better view the changes in chlorine.</p> \
<p><img src='qdb/figures/Change_y_axis.jpg'></p> \
<p>It is suggested that this requirement be prioritized if possible, especially if water quality values vary significantly.</p>"
	],
229: ["req", "The ability to view parameter values by clicking a trend line",
	"The ability to view exact parameter values associated with a given data point on a plot by clicking or hovering over the trend line.",
	"<p>This functionality allows the user to click on a data point and view the exact data value associated with the point.  Without this functionality, the user generally must access the data directly to get exact values.  In the example plot below, the user clicked the point just after an unusual drop in chlorine to open a box showing the exact time and parameter value of that point.</p> \
<p><img src='qdb/figures/Data_label.jpg'></p> \
<p>This functionality is valuable for users seeking to do detailed data analysis.  However, the water quality changes and approximate data values, which can be seen without this functionality, are sufficient for many users.  The importance of this functionality is also directly related to the difficulty in obtaining data values from the system in other ways.</p>"
	],
230: ["req", "The ability to maintain a consistent x-axis with inconsistent data",
	"The ability to plot data and maintain a consistent x-axis time interval even if data points are missing or if data is not reported at a regular time interval.",
	"<p>With this feature, time-series plots will always maintain a consistent x-axis plotting interval even if the data reporting interval is inconsistent, which is most commonly caused by timesteps of missing data.  It is also inherent in data that is not reported at a regular interval.  The plots below show the same data which has several periods where data was not successfully received.  In the first plot which utilizes this functionality, the reporting remains consistent and it is clear where data is missing.  In the second, the available data points are simply plotted:  the gaps in data are not shown, and the reporting times on the x-axis become distorted due to timesteps that are not shown.</p> \
<p><img src='qdb/figures/Missing_timesteps_1.jpg'>&nbsp;<img src='qdb/figures/Missing_timesteps_2.jpg'></p> \
<p>This functionality is critical for accurate analysis if data is not reported at a regular interval.  It is less crucial for regularly, reliably reported data, though it can be useful to clearly see when data is missing and to know when a communications error has occurred.</p>"
	],
231: ["req", "Advanced plotting capabilities",
	"Advanced plotting capabilities such as the ability to generate three-dimensional plots or to plot data from different data sources concurrently.",
	"<p>With this functionality, additional, more advanced plots (beyond simple time-series plots) can be generated through the user interface.  Examples include the ability to generate scatter plots, cumulative frequency distribution plots, three-dimensional plots, or box-and-whisker plots.</p> \
<p>This functionality is likely not necessary for most utilities:  basic plotting can be sufficient for most applications.  However, advanced plotting can allow for more advanced data analysis.  It may also facilitate interpretation of some data types, such as from a spectral instrument.</p>"
	],
232: ["req", "The ability to extract custom datasets from stored data",
	"The ability to extract user-defined datasets, including the ability to choose the datastreams and time period of data to include.",
	"<p>This functionality allows the user to extract desired datasets at any time, including the ability to choose the datastreams and time period of data to include.</p> \
<p>It is highly recommended that this functionality be prioritized if there is a desire to export data for current use or to save data for later use.  This is particularly valuable if the information management system is not accessible from all user workstations, if data is to be shared with outside entities such as researchers or a data analysis software vendor, or if data is archived in a way such that it cannot be easily accessed.</p>"

	],
233: ["req", "The ability to export data in time-series format",
	"The ability to export data in time-series / column-based format, in which all parameters for a given timestep are written in one row.",
	"<p>With this functionality, data can be exported from the system in time-series / column-based format, in which all parameters for a given timestep are written in one row.  With the alternative, which is available in most information management systems, each row provides the value for one parameter for one timestep.  Time-series format allows for clearer tracking of individual parameter values.  To illustrate this, the two tables below show the same data:  the first table is in time-series format and the second is in parameter-based format.</p> \
<p><img src='qdb/figures/Time_series_table.jpg'></p> \
<p><img src='qdb/figures/Parameter_based_table.jpg'></p> \
<p>Time-series format is very conducive for viewing and plotting data.  If it is expected that files will be frequently exported and used – particularly if plots will be generated or if users expect to visually review the data – it is suggested that this functionality be prioritized.</p>"
	],
234: ["req", "The ability to export data in a format that can be used by external software",
	"The ability to export data in a format that can be opened and read by external software (such as Excel).",
	"<p>This functionality ensures that any exported data is in a format that can be used by external software, so that the functionality of the external software can be used to view and analyze the data.  External software commonly includes spreadsheet applications, and may also include statistical analysis packages or text editors.</p> \
<p>It is highly recommended that this be prioritized if there is a desire to export data for external use.  It ensures that maximum benefit can be received from data exported from the information management system.</p>"
	],
235: ["req", "The ability to create custom reports",
	"The ability to create ad hoc custom reports summarizing data or system information, as opposed to being confined to reports defined during system design.",
	"<p>Reports are different from the data exports covered in previous requirements:  reports summarize data as opposed to providing specific data values.  Example reports include statistical summaries of water quality data values, summaries of recent water quality excursions, and system usage reports for use by IT staff.  With this functionality, users can generate desired reports as needed.  Without this functionality, the average user is unable to create custom reports and is limited to standard reports specified when the information management system was designed.</p> \
<p>When ranking this functionality, consider what reports would be used by staff.  For many systems in which the data produced is the focus, advanced reporting functionality may be unnecessary.</p>"
	],
236: ["req", "The ability to save report templates",
	"The ability to save report templates for regular use.",
	"FULL TEXT The ability to save report templates for regular use."
	],
237: ["req", "The ability to obtain a list of events that meet specific criteria",
	"The ability to generate a list of events stored in the system that meet specified criteria, such as a list of alerts or a list of times that a parameter fell below an acceptable value.",
	"<p>With this functionality, users can obtain a list of incidents that meet specified criteria.  For example, they could generate a list of alerts, a list of times that chlorine fell below an acceptable value, or a list of times when the communication system was down.</p> \
<p>The importance of this functionality depends on whether this information is needed to achieve the intended use of the system.  Note that these lists can be difficult to generate manually from the data, and thus it is suggested that this functionality be included if it is expected that lists would be desired.</p>"
	],
238: ["req", "The ability to produce alerts based on setpoints",
	"The ability to generate alerts if user-defined parameter setpoints are surpassed.",
	"<p>This functionality allows users to implement parameter setpoint (or threshold) alerting in which the user defines minimum and/or maximum acceptable values for individual datastreams and an alert is generated if a value received surpass these thresholds.  For example, a low chlorine setpoint could be established so that an alert is produced if chlorine values fall below the specified value.</p> \
<p>Setpoint alerting is an excellent functionality for utilities who want to do basic automated analysis.  This is generally an easily-implemented data analysis solution that has shown to be effective in detecting significant incidents of abnormal water quality.</p>"
	],
239: ["req", "The ability to produce alerts based on thresholds for cumulative values",
	"The ability to generate alerts if user-defined thresholds for a datastream's cumulative total are surpassed.",
	"FULL TEXT The ability to generate alerts if user-defined thresholds for a datastream's cumulative total are surpassed."
	],
240: ["req", "Additional real-time analysis capabilities",
	"Additional real-time data analysis capabilities built into the system - beyond setpoint alerting.",
	"<p>With this functionality, the information management system has additional built-in data analysis capabilities beyond parameter setpoints.  These can include standard statistical methods or fully-integrated event detection tools.</p> \
<p>This functionality is generally used at utilities with staff with the expertise and initiative to select and implement these algorithms.  As described above, setpoint analysis is generally an effective and easily implemented solution for most utilities.</p>"
	],
241: ["req", "The ability to run multiple data analysis functions concurrently",
	"The ability to implement multiple data analysis techniques / algorithms concurrently.",
	"<p>This functionality allows for multiple data analysis functions to run concurrently.  For example, a utility may run specialized data analysis software alongside setpoint alerting.</p> \
<p>This functionality is generally not necessary for an effective OWQM system.  However, this is clearly necessary if there are plans to implement multiple data analysis techniques.</p>"
	],
242: ["req", "The ability to enter advanced alerting logic",
	"The ability to enter advanced logic to determine which alerts are generated and conveyed to utility staff, such as suppressing alerts during a communication failure.",
	"<p>This functionality allows the user to enter advanced logic to determine which alerts are conveyed to utility staff.  The number of alerts received can be significantly reduced by entering logic to suppress alerts that are clearly invalid or redundant.  For example, alerts can be suppressed that occur within X minutes of another alert.</p> \
<p>Utilities that have leveraged this functionality have found it to be extremely effective in reducing the number of alerts received, and thus the number of alert investigations performed by utility staff.  Though the logic may take some effort to implement and optimize, it is highly recommended if alerts will be investigated in real time.  This functionality is relevant regardless of the data analysis method used.</p>"
	],
243: ["req", "The ability to convey alerts through the user interface",
	"The ability to convey alerts to staff using visual and/or audible cues within the user interface.",
	"<p>With this functionality, alerts can be conveyed to staff using visual and/or audible cues within the user interface.  Methods to convey alerts to users vary from a simple list of alerts to a sophisticated display using a GIS interface.</p> \
<p>This functionality is relevant for utilities that will have a continuously-running user interface through which alerts will be conveyed to staff.</p>"
	],
244: ["req", "The ability to automatically transmit alerts alerts to appropriate personnel",
	"The ability to automatically transmit alerts generated to specified staff members, generally via e-mail or text message.",
	"<p>With this functionality, alerts can be automatically transmitted to specified staff members, generally via e-mail or text message.  Alert customization options vary across information management systems, with some systems even allowing different individuals to be notified depending on the day and time.</p> \
<p>This functionality is important if the user interface is not continuously monitored by staff responsible for alert investigation, or if multiple individuals (such as managers) are interested in being notified of alerts produced.</p>"
	],
245: ["req", "The ability to include supplemental information in alert notifications",
	"The ability to include supplemental information, such as the location of the alert, in automatically-generated alert notifications.",
	"<p>This functionality allows the user to customize the information that is included in automatically-generated alert notifications.  By including relevant summary information, users can often get a sense of the potential cause or significance of an alert at a glance.  For example, the message could specify the monitoring location at which the alert was generated and the water quality parameters that were deemed abnormal.  It may even be possible to include the most recent data values or data plots in the messages.</p> \
<p>Staff at utilities who have implemented automatic transmission of alerts have found this functionality extremely useful.  They appreciate the convenience of getting an overview of alerts without having to log into the information management system, which is particularly useful when they are away from the office, such as during non-business hours or during a meeting.</p>"
	],
246: ["req", "The ability to enter advanced alert notification logic",
	"The ability to enter advanced logic to determine who receives automated alert notifications, such as different recipients based on the time or day of the week.",
	"<p>This functionality allows users to enter advanced logic to determine who will receive automated alert notifications.  For example, it may be possible to send alerts to different groups of users depending on the time or day of the week.</p> \
<p>This functionality is generally appreciated by staff who receive alerts as they do not receive notifications of alerts they are not responsible for investigating, including alerts occurring when they are not working.</p>"
	],
247: ["req", "The ability to require alert acknowledgement",
	"The ability to require users to acknowledge receipt of alerts and to generate follow-up notifications if alerts are not acknowledged in a specified amount of time.",
	"<p>This functionality allows the system to be configured to produce follow-up notifications if alerts are not acknowledged in a defined period of time.  For example, an audible alert generated at a workstation could be repeated every X minutes until the alert is acknowledged, or e-mails could be re-sent (or even sent to alternate personnel) if not acknowledged.  In general, an acknowledgment indicates that the alert is being addressed.</p> \
<p>This functionality can help ensure that all alerts are responded to in real time, and is particularly useful in situations in which multiple individuals share responsibility for investigating alerts.</p>"
	],
248: ["req", "The ability to enter alert investigation details",
	"The ability to enter alert investigation details in the information system user interface, either for documentation or as a way for users to share information during investigations.",
	"<p>This functionality allows users to enter investigation details through the user interface.  This is a convenient way to document investigations and ensures that information is saved for future reference.  In addition, it may be possible to configure the system to guide the user through the investigation process or to require key fields to be populated before the data input is considered complete.</p> \
<p>This functionality is not necessary for an effective OWQM component, and many utilities will not need or use it.  However, it can streamline alert investigations, particularly if multiple staff members participate in the investigation of a single water quality event.  This feature also provides an efficient method of documenting alert investigation, foregoing the need to maintain investigation documentation in a separate system.  Furthermore, storing alert investigation details electronically makes them much easier to query, which can serve as an effective resource during future investigations.</p>"
	],
249: ["req", "The ability to test data analysis tools using historical data",
	"The ability to evaluate the performance of different data analysis tools or configurations within the information management system using historical data and perhaps simulated events.",
	"<p>This functionality facilitates implementation of automated data analysis tools by allowing the user to evaluate the performance of different data analysis tools or configurations within the information management system.  For example, the user may be able to select a data analysis method, a period of historical data, and possibly even water quality anomalies to simulate, and then obtain a list of the alerts that would have been generated using that method.</p> \
<p>Data analysis tools and configurations strongly impact system performance, as they determine the alerts that are generated.  Thus it is important to ensure that the solution selected detects desired water quality excursions while producing minimal invalid alerts.  Built-in testing functionality provides an efficient means to estimate performance.  Other options include exporting data and performing analysis outside of the system, using the USEPA-developed EDDIES software, or relying on expert judgment.</p>"
	],
250: ["req", "Easy access to archived data",
	"Easy, fast access to older data which has been archived or moved to a data historian.",
	"<p>This functionality ensures quick and easy access to older data which has been archived or moved to a data historian.  Without this, data extraction is more complicated and time-consuming, and may even require staff with specialized privileges or training to fulfill the data request.</p> \
<p>The importance of this functionality depends on the expected frequency at which archived data will need to be accessed.  This is a function of the amount of 'short term' data available in the system relative to the amount of data typically required to meet the expected system uses (for example, if long term water quality trends will be analyzed).</p>"
	],
251: ["req", "Data security",
	"Safeguards implemented to protect information from unauthorized viewing or modification.",
	"<p>With data security, safeguards are implemented to protect information from being viewed or modified by unauthorized individuals.</p> \
<p>This requirement will be defined in more detail by technical staff.  When ranking this here, consider if there is information or views generated through OWQM that you consider particularly sensitive.</p>"
	],
252: ["req", "The ability to store time-stamped user comments for datastreams",
	"The ability to store time-stamped user comments for a datastream, intended to provide supplemental information for future reference.",
	"<p>This functionality allows for time-stamped user comments for a datastream.  This is generally intended to provide supplemental information for future reference.  For example, a note could be added when the equipment producing the datastream is calibrated so that the cause of the resulting change in data values can be easily identified during future data review.</p> \
<p>This information about datastreams is useful if historical data will be frequently analyzed.  An alternative is to store this supplemental information separately – such as in electronic or physical logs.</p>"
	],
253: ["req", "Automatic assignment of data quality value",
	"Automatic assignment of a data quality indicator by the system to each data point as it is received.",
	"<p>With this functionality, a quality indicator is automatically assigned to each data point as it is received.  This determination often takes into account communication status, sensor fault indicators or a range of valid values identified by the user.  A quality indicator can be useful when reviewing data and analyzing system health.  This value may also be able to be leveraged by an automated data analysis tool or alert manager.  For example, it may be possible to configure the system so that alerts are not produced if bad quality is indicated.</p> \
<p>If automated alert generation will be used and can leverage data quality information, it is highly recommended that this functionality be prioritized.  It can also be useful for system analysis and reporting.</p>"
	],
254: ["req", "Automatic data cleaning and smoothing functionality",
	"Automatic processes to perform data cleaning and smoothing, seeking to replace data values that are deemed inaccurate with values assumed to be closer to the true value.",
	"<p>With this functionality, the information management system seeks to 'fix' data values that are deemed inaccurate (including those indicated as having bad quality per the above requirement), replacing them with values that are assumed to be closer to the actual value.  This is generally based on statistical analysis of recent data.  The 'clean' data can then be shown on data plots or used during data analysis, potentially reducing invalid alerts.</p> \
<p>The primary application of this functionality is in automated data analysis to reduce or eliminate the generation of invalid alerts resulting from inaccurate data.  It also makes data plots 'cleaner', as outliers are generally removed.  Note, however, that it is possible that the derived values are not accurate and thus real anomalies could be missed.</p>"
	],
255: ["req", "The ability to add or modify datastreams",
	"The ability to have datastreams added, modified, or removed as needed.",
	"<p>This functionality allows for addition or modification of OWQM datastreams.  For example, additional datastreams would need to be added to the information management system if a new monitoring location were added or if new sensors were added to an existing monitoring location.  Other modifications might include removal of obsolete sensors or renaming of specific datastreams.</p> \
<p>When rating this functionality, consider how often you expect datastreams to be added or modified.  Unless there is a high degree of confidence that such modifications won't be necessary, it is suggested that this functionality be prioritized.  Without the capability to modify datastreams, the ability of the OWQM component to grow and evolve will be limited.</p>"
	],

/* SYSTEM TECHNICAL REQUIREMENTS RANGE 500+ */
501: ["checkboxestext", "Programming expertise levels",
	"What level(s) of required programming expertise are acceptable for implementing the system?",
	"<p>Information management solutions vary widely in the level of programming expertise needed to install and configure them.  The responses below assume the following:</p> \
	<p><ul>\
<li>Most IT staff have basic programming skills and would be able to implement products that are largely ready to use \"out of the box\" with clear and simple instructions for getting started.</li>\
<li>Staff with experience designing or implementing IT systems generally have intermediate programming skills.  They are able to do some integration work, perhaps working with multiple data management systems and using packaged tools or applications to link them together.</li>\
<li>Staff with advanced programming or system integration experience are able to do development work.  They are able to build user interfaces and create connections between data sources in house, leveraging existing tools and creating custom code as needed.</li>\
</ul></p> \
<p>When identifying the maximum acceptable skill level, consider the technical expertise and availability of in-house staff to implement the information management system.  Alternately, consider if obtaining technical support from a vendor or consultant could be used to supplement in-house expertise.</p>",
	"a)	Select all that apply:",
		[	"Basic",
			"Intermediate",
			"Advanced"
		],
	"b)  Additional details:",
	],
502: ["checkboxestext", "System troubleshooting and maintenance",
	"Which solution(s) for system troubleshooting and maintenance are acceptable?",
	"Which solution(s) for system troubleshooting and maintenance are acceptable?",
	"a)	Select all that are acceptable:",
		[	"Fully in-house",
			"In-house with external support when needed",
			"Full maintenance by an outside entity"
		],
	"b)  Additional details:",
	],
503: ["radiotext2", "System recovery time",
	"Is there a threshold for maximum acceptable time to full system recovery? State it.",
	"<p>Full system recovery is the process of restoring the information management system to normal operation after a failure.  Time for recovery is closely tied to the time for qualified personnel to become engaged and the time required to execute system fixes.</p> \
<p>The time required for personnel to become engaged is closely tied to the previous question.  Many service contracts specify a maximum time for response, which can range from hours to days.  Also, utility staff vary in their ability to stop other work and attend to system issues.</p> \
<p>Enter a maximum acceptable time for typical system recovery in hours (with the understanding that some complex issues may require more time).  The decision of an adequate recovery time is a balance between the cost of the system being down and the cost of rapid response to system problems.</p>",
	"",
	"Enter a numeric value, in days:",
	"Additional Details:"
	],
504: ["text2", "Software and systems compatibility",
	"List software and systems the information management system must be compatible with.",
	"<p>List software and systems the information management system must be compatible with.  Examples of such systems include:</p> \
	<p><ul>\
<li>Systems storing information that must be available through the information management system, such as LIMS, SCADA or call management systems</li>\
<li>Software products that will be used to view or manipulate data, such as event detection algorithms, Microsoft Excel or a statistical software package</li>\
<li>Systems used to build or display the user interface, such as GIS, web browsers and plug-ins</li>\
</ul></p>",
	"List all systems here:",
	"Additional Details:"
	],
505: ["text2", "Hardware requirements",
	"List hardware requirements for the system.",
	"<p>Hardware requirements and limitations are often based on existing resources, budgetary or storage limitations, or adherence to IT policies.  Examples of hardware requirements include use of a specified hardware manufacturer, use of computers with a specified operating system, or a limitation on the space available for servers.</p>",
	"List hardware requirements here:",
	"Additional Details:"
	],
506: ["radiotext1", "Remote access constraints",
	"Are there constraints that would affect remote access settings?",
	"<p>With remote access, users can access the information management system from a device connected to the Internet. Common external users include staff working from home and local partners.</p> \
	<p>IT policies might limit or prevent remote access in order to protect against cybersecurity threats or to comply with data use agreements.  If constraints exist, please describe them in the free entry box.</p>",
	"",
	"Define contraints and provide additional details:"
	],
507: ["radiotext1", "Offsite data storage",
	"Is offsite data storage a viable option?",
	"<p>With off-site storage, information is stored outside of the utility IT infrastructure (not on utility servers or hardware) and may be managed by an external entity.  Some utilities use only external data storage, while others use off-site storage for backup and recovery in the case of system corruption.  Examples of off-site storage include cloud storage, hosting by an information management system vendor, or data management by a regional IT entity.</p> \
	<p>As with remote access, there may be IT policies that limit the ability to use off-site data storage.  If that is the case, please describe the constraints in the free entry box.</p>",
	"",
	"Additional details:"
	],
508: ["checkboxestext", "Data transfer methods",
	"What modes of data transfer methods are acceptable?",
	"<p>Data transfer is generally initiated by an external process or through the information management system.  In the former, new data is automatically pushed to the system whenever it becomes available.  For example, an indication that an alarmed door has been opened can be automatically sent to the system.</p> \
<p>In the case of data queries, the system requests data from an external source, often at a defined interval.  For example, the system may query all OWQM hardware every two minutes for the most recent data.  This can be done either through queries sent to the data source or through a direct connection where the information management system can directly access the information.</p> \
<p>Select the data transfer method(s) that the system must support.  Do not select a method if it is prohibited by IT policies.</p>",
	"a)	Select all that are acceptable:",
		[	"Data pushed to the system",
			"Data queried by the system",
			"Direct connection with bi-directional flow of data"
		],
	"b)  Additional details:",
	],

531: ["req", "Efficient handling of time-series data",
	"Efficient method of collecting, storing and accessing time-series data.",
	"<p>A large volume of time-series data can be generated through an SRS.  A system that is efficient at handling time-series data minimizes the time necessary for data receipt, storage, retrieval, display and analysis, and thus users can access the data or figures they desire almost instantaneously.  Also, data is stored efficiently, minimizing the space needed for data storage.</p> \
<p>For an SRS in which a large number of data points will be generated (which generally is the case if OWQM and ESM are implemented), efficient handling of time-series data may be necessary for an effective and sustainable system.  Excessive processing times for data storage or retrieval may limit the ability of the system to support real-time system functions.  Also, without efficient data storage the amount of data that can be maintained in the primary information management system may be limited.</p>"
	],
532: ["req", "Cybersecurity",
	"Data availability, integrity, and confidentiality maintained.",
	"<p>In a secure system, unauthorized access to sensitive data and information systems is limited.  The National Institute of Standards and Technology (NIST) and the International Organization for Standardization (ISO) have developed standards that can be used to guide cybersecurity practices and maximize data availability, integrity, and confidentiality.</p> \
<p>Cybersecurity should be a priority for all utilities and thus it is recommended that this requirement be prioritized.</p>"
	],
533: ["req", "Automated backup capabilities",
	"Automatic backup to easily restore the system if it is corrupted.",
	"<p>With this capability, an information management system can be configured to automatically generate a backup file at a defined interval that can be used to easily (perhaps even automatically) restore the system configuration and stored data in the event of a system failure.  Without this functionality, system backup must be done manually, and the technical expertise and time needed to do this varies across information management systems.</p> \
<p>Regular backup is a best practice for any information management system, and it is suggested that all utilities implement a regular system backup plan.  Less technical expertise is needed to carry out an automated backup, and it eliminates the chance that someone will forget to implement a manual process.  It also eliminates the chance that someone will forget to implement a manual process.</p>"
	],
534: ["req", "The ability to implement a failover system",
	"In the event of a serious system problem, a failover is activated to keep the information management system operational.",
	"<p>With a failover system, redundant components are activated to keep the information management system operational in the event of a system problem such as a power loss or server crash.  This is often accomplished by switching to a standby computer server, data system, power supply or hardware component.  In some systems this is automatic, whereas in others a user must initiate the switch.</p> \
<p>The value of a failover system depends on the importance placed on maintaining uninterrupted availability of the SRS information management system.  Without it, the system would be inoperative until the failed element is repaired or replaced, which could take days if a new part has to be ordered and installed, or if external support is needed.  While inclusion of a failover system can be expensive to implement, it can allow for longer response times to correct problems with the primary system.</p>"
	],
535: ["req", "The ability to hot swap system components",
	"Individual elements can be replaced without interrupting the system.",
	"<p>Hot-swapping allows for individual system components to be replaced or removed without interrupting the system.  This can be used to add or remove components, to replace faulty components, to change system configuration, or to perform routine maintenance without interrupting its operation.</p> \
<p>Similar to a failover system, the importance of hot swap capabilities is directly related to the important placed on maintaining continuous system operation.</p>"
	],
536: ["req", "Administrator accounts",
	"An administrator account with exclusive rights to make system changes.",
	"<p>An administrator account has exclusive rights to make system changes including updating the user interface, adding or modifying other user accounts, and upgrading software.  This ensures that system configuration cannot be changed by non-administrative users - either intentionally or unintentionally.</p> \
<p>A separate administrator account becomes increasingly important as the complexity of the system increases, as there are more elements that can be compromised and it can be more difficult to restore the system.  It also becomes more important as the number of users increases.</p>"
	],
537: ["req", "The ability to restrict user read and write privileges",
	"The ability to restrict what individual users can view and their ability to input or modify information.",
	"<p>With this functionality, the IT manager can limit the information and screens individual users can view (read privileges) and their ability to input or modify information in the system (write privileges).  In general, these privileges are based on the users' job functions and the activities they will need to carry out in the information management system.</p> \
<p>The ability to limit individual user read privileges may be important if any information available through the information management system is considered sensitive.  The ability to limit individual user write privileges helps ensure information integrity and generally becomes more important as the number and variety of users increases.</p>",
	],
538: ["req", "The ability to log or monitor user activity",
	"The ability to track system use by individual users.",
	"<p>With this functionality, each user has their own account and use of the system by individual users can be tracked.  For example, this feature may be used to track the times a user is logged on and the actions they take.</p> \
<p>This functionality can be useful for identifying which users have been involved in the investigation of alerts, troubleshooting system problems resulting from user actions, and monitoring user compliance with business processes.</p>",
	],
539: ["req", "The ability to easily manage user accounts",
	"The ability to easily manage user accounts.",
	"<p>Management of user accounts often involves adding or removing user accounts from the system, as well as possibly changing the privileges of individual users (including read and write privileges) due to changes in roles and responsibilities.  With this functionality, changes to user accounts can be implemented easily and efficiently.  Otherwise, updates to user accounts may require significant system reconfiguration and staff with specialized skills.</p> \
<p>When rating this functionality, consider the anticipated frequency at which user accounts and privileges will need to be updated and the level of immediacy in implementing account updates.  Also consider whether the utility has staff capable of making technically complex system changes.</p>",
	],
540: ["req", "The ability to easily modify the user interface",
	"The ability to easily modify the user interface without specialized skills required.",
	"<p>Changes to the information management system are inevitable as users become familiar with the system and identify desired modifications or enhancements.  With this functionality, updates can be implemented easily, efficiently and generally without specialized skills.  Otherwise modifications to the user interface may require complex coding or significant system re-configuration.</p> \
<p>When ranking this functionality, consider whether there are staff with the time and ability to make technically complex system changes.  Also consider whether it is a priority to promptly make suggested updates to maximize system usability (if changes can be easily implemented, they can likely be completed more quickly).</p>",
	],
541: ["req", "The ability to easily modify data elements",
	"The ability to easily modify data elements such as data streams, monitoring locations, and data types.",
	"<p>This functionality allows for easy addition, deletion or modification of data elements in the information management system including datastreams, monitoring locations and data types.  Examples of physical changes to the SRS that would require modification of data elements include the addition of new ESM sensors, relocation of OWQM equipment or renaming customer complaint categories.  Generally, updates to the information management systems must be made before the system can accurately collect and manage the updated data elements.</p> \
<p>The importance of this requirement is directly related to the availability of technical staff able to make more difficult changes to the system.  It is also impacted by the expected frequency of such changes.</p>",
	],
542: ["req", "The ability to operate in a distributed computing environment",
	"The ability to operate in an environment with distributed data storage and software components.",
	"<p>In a distributed computing environment, system components are located on separate computers and servers but are linked to present a single interface to users.  This feature can include distributed data storage and software components.</p> \
<p>This requirement is relevant if and only if a distributed environment is an acceptable solution.  It is also impacted by the feasibility of installing required hardware and software at utility facilities.</p>",
	],
543: ["req", "Open architecture database (ODBC Compliant)",
	"ODBC compliance makes it possible to access data, regardless of which database management system is handling the data.",
	"<p>The Open DataBase Connectivity (ODBC) database access method was developed by the SQL Access Group to make it possible to access any data from any application, regardless of which database management system is handling the data.  This can facilitate integration of multiple data sources into an information management system.</p> \
<p>This requirement is relevant if and only if SRS data will be stored in more than one data management system.  If more than one system will be used, consider the availability of technical staff able to manually create connections between non-ODBC compliant source systems.</p>",
	],
544: ["req", "Unlimited seat licenses",
	"The system can be used by unlimited users with no additional fee.",
	"<p>With unlimited seat licenses, the system can be accessed from any workstation and unlimited users without additional costs.  The alternative is a contract in which there is a charge for each user or workstation.</p> \
<p>When rating this requirement, consider the number of users - both initial users and users or access points that may be added in the future.  Typically there is a breakeven point at which the cost of an unlimited seat license is less than the cost of individual seat licenses.</p>",
	],
545: ["req", "Unlimited data elements",
	"Unlimited data elements can be added without additional cost.",
	"<p>With this type of system, unlimited data elements can be added without additional cost.  Data elements may include new OWQM monitoring locations and datastreams, additional CCS complaint categories, or new data types altogether.</p> \
<p>This feature is relevant if there are a large number of datastreams or there is the possibility of adding a significant number of new data elements.  As with seat licenses, there is generally a breakeven point where it becomes more cost-effective to have unlimited data elements.</p>",
	],
546: ["req", "The ability to generate system diagnostic reports",
	"The ability to generate reports summarizing system performance and reliability metrics.",
	"<p>With this functionality, users can generate system diagnostic reports as needed, which can be used to proactively identify potential performance issues and troubleshoot issues when they occur.  These reports can contain a variety of performance and reliability metrics including system availability, usage, and available memory.</p> \
<p>When rating this functionality, consider if IT staff will use this information.  Note that the system performance information listed above can be difficulty to capture without this functionality.</p>",
	],
547: ["req", "The ability to receive automatic storage capacity notifications",
	"The ability to receive a warning message when storage capacity is approaching a specified limit.",
	"<p>With this functionality, a warning message can be generated when the storage capacity of the system is approaching a user-specified limit (for example, 90% full).  This information allows users to take proactive action and helps to prevent unnecessary system downtime due to the inability to store new data for analysis.</p> \
<p>It is good business practice to monitor storage capacity.  Though this can be achieved through establishing procedures to regularly check available storage capacity, automatic notifications can help ensure that utility staff are aware of storage issues.</p>",
	],
548: ["req", "The ability to receive automatic notification of system malfunction",
	"The ability to receive automatic notification if an element of the system malfunctions.",
	"<p>With this functionality, error messages can be conveyed to designated personnel when an element of the system malfunctions.  For example, a notification can be generated if new data is not received as expected or if there is no response to a query of a source system.  Without this, the system may continue to malfunction until a user notices the issue, which may take hours or days depending on the frequency of system use and how obvious the issue is.  For example, if an automated data analysis tool stalls, it may not be noticed for a long time since the only time information from this component is shown is when an alert is generated.</p> \
<p>This functionality allows for timely identification of system malfunction, facilitating rapid response and return to normal system operations.  The value of this feature is directly related to the value placed on maximizing system availability.</p>",
	],
549: ["req", "The ability to receive processing time notification",
	"The ability to receive a warning when processing time exceeds a specified length.",
	"<p>With this functionality, users receive a warning message when a processing time exceeds a user-defined length.  Unusually long processing times may be indicative of system issues including component failure, a runaway process consuming computing resources, or a breach in cybersecurity.</p> \
<p>As with the previous functionality, processing time notifications allow for timely identification of system issues, facilitating rapid response and return to normal system operations.  The value of this feature is directly related to the valued placed on maximizing system availability.</p>",
	],
550: ["req", "The ability to test connectivity with remote sites",
	"The built-in ability to test communications between the information management system and remote sites.",
	"<p>This functionality allows users to test the communication pathway between the information management system and remote sites, such as OWQM monitoring locations.  The time required to receive a response when a query is sent to the remote site is measured, along with the completeness of the response packets received.  The ability to ping remote sites can be used during system design and configuration to verify the communication connection is strong and functioning, and to troubleshoot the cause of specific data communication failures or delays.</p> \
<p>When rating this functionality, consider whether staff will use this ability to test connectivity with remote sites.  Note that without this feature, site visits may be necessary to test connectivity and troubleshoot communication problems.</p>",
	],
551: ["req", "Real-time routine troubleshooting",
	"Staff available for immediate troubleshooting of routine system issues.",
	"<p>With real-time support, staff is available to troubleshoot and fix routine system issues within a few hours.  Depending on the system, this could be done by utility IT staff, vendors or consultants.  Without real-time support, it could be days (during which the system is not operating properly) before qualified staff are engaged.</p> \
<p>Real-time troubleshooting is valuable if high system availability is a priority, as it minimizes the delay in resolving issues and returning the system to normal operation.  Note that more in-depth support (and longer response time) may be needed if the issue is not routine.</p>",
	],
552: ["req", "Prompt resolution of significant issues",
	"Prompt resolution of non-routine system issues.",
	"<p>There may be instances in which a utility encounters an issue for which there is no clear solution (for example, a commercial product fails in a manner that has not been encountered before).  Depending on the availability of qualified staff for troubleshooting and development of a solution, it could be days, weeks, or even months before a more difficult problem is resolved.</p> \
<p>Prompt resolution is important if system availability is a priority.  Note that the probability of encountering a non-routine issue increases with the complexity of the system, including the number of data sources and access points. Also, these issues are generally less common with established products that have been extensively used by water utilities.</p>",
	],
553: ["req", "Vendor-provided training",
	"System training  to technical staff and/or end users by the vendor.",
	"<p>With vendor-provided training, vendor staff come to the utility to provide structured or unstructured training to utility staff on implementation, use of, and maintenance of the system.  Without this, staff generally must rely on system documentation or develop their own training.</p> \
<p>This training is only relevant if a vendor-provided solution will be used.  In-person training becomes more important if the system is not intuitive to implement and use, and can prove valuable as system complexity or the number of users increases.</p>",
	],
554: ["req", "Full product warranty and support available",
	"A fixed-price product warranty and system support provided by the vendor.",
	"<p>A product warranty and system support allow for predictable maintenance and repair costs for the duration of the warranty.  Depending on the terms of the warranty, there may be no costs to the utility if a system component fails and needs replacement.  Furthermore, the warranty may cover the cost of common maintenance activities.</p> \
<p>Predictable system costs can be useful for budgeting operating and maintenance costs and insures against the high costs of repairing a serious system failure.  When ranking this functionality, the benefits of an extended warranty and service agreement must be weighed against the additional costs.</p>"
	]
};

//
// This array defines the Alternate Screen-Reading Text for each question/requirement of the Tool.
//
// The number is the UQI of the question, as defined above in the corresponding Questions array.
// If a question has component-specific text, mark it as shown.  Items without a component-specific marking will be
// the default for any component.
//		4-OWQM: ["OWQM-specific Alt Text for Radio No", "OWQM-specific Alt Text for Radio Yes", "OWQM-specific Alt Text for Text Field"],
//
var QuestionsAltText = {
1: ["No, the system will not be used to track customer calls", "Yes the system will be used to track customer calls", "Enter any additional details on customer call tracking in this box"],
2: ["No, data will not be reviewed via the infromation management system regularly", "Yes, data will be reviewed via the infromation management system regularly", "Enter any additional details on data review in this box"],
3: ["No, the user interface will not be active continuously", "Yes, the user interface will be active continuously", "Enter any comments on the user interface in this text box"],
4: ["No, the information management system will not be accessed to investigate data", "Yes, the information management system will be accessed to investigate data", "Enter any additional details investigation data access in this box"],
5: ["No, the alert investigation will not be completed in the information management system", "Yes, the alert investigation will not be completed in the information management system", "Enter any additional details on alert investigations in this box"],
6: ["No, historical data will not be analyzed", "Yes, historical data will be analyzed", "Enter any additional details on historical data in this box"],
101: ["Non-digital storage, such as physical binders or log books is an acceptable data management solution",
			"A spreadsheet or other simple file-based digital storage is an acceptable data management solution",
			"A database or other advanced data storage mechanism is an acceptable data management solution",
			"Explain other data management solutions in text area below)"],
102: ["Datastreams currently being collected",
			"New datastreams will be stored in the information management system",
			"Alerts already being generated will be stored in the information management system",
			"New alert types will be stored in the information management system",
			"Describe other datastreams that will be stored in the information management system below",
			"No decision has been made"],
103: [	"Data will be entered manually",
			"Data will be automatically transmitted",
		],
104: ["Enter the frequency of data transmission", "Enter any additional details in this box"],
105: ["No, no equipment will transmit abnormally large quantities of data?", 
	"Yes, some equipment will transmit abnormally large quantities of data?",
	"Will any equipment transmit abnormally large quantities of data?",
	"Enter any additional details on the quantity of data transmitted in this box"
	],
106: [ "Enter how many new data points generated through this component that will be entered into the information management system each day",
	"Enter any additional details on the number of data points in this box"
	],
107: [	"Status indicators or faults from individual instruments will be transmitted to the information managment system",
			"Indicators of individual monitoring station health, such as indicators of power loss, will be transmitted to the information managment system",
			"Overall system health indicators, such as the status of the communications system will be transmitted to the information managment system",
			"No decision has been made on what will be transmitted to the information managment system",
	  "Enter any additional details on what will be transmitted in this box",
	],
108: [
	"List all systems where component data is currently being stored, if applicable.",
	"Enter any additional details on component data systems in this box"
	],
109: ["text2", "Days of data available",
	"How many days of the most recent data would ideally be readily available through the user interface?",
	"How many days of the most recent data would ideally be readily available through the user interface?",
	"Enter the number days of the most recent data would ideally be readily available through the user interface",
	"Enter any additional details on the days of data available in this box"
	],
110: 	[	"Video editing will be needed through the information management system",
			"Frame-by-frame advancement will be needed through the information management system",
			"The ability to re-position cameras remotely will be needed through the information management system",
			"The ability to zoom in at high resolution will be needed through the information management system",
			"Other abilities that will be needed through the information management system and will be entered below",
			"No decision has been made on what video-related functionality will be needed through the information management system",	
	"Enter any additional details in this box, including other abilities that will be needed through the information management system ",
	],
111: [	"Alerts from other components will be used in system operation and alert investigation",
			"Data from other components will be used in system operation and alert investigation",
			"Information on distribution system maintenance activities will be used in system operation and alert investigation",
			"Other information will be used in system operation and alert investigation and will be entered below",
			"No decision has been made on information that will be used in system operation and alert investigation"
		],
112: ["Spreadsheet-based application will be used to view / manipulate data exported from the information management system",
			"Advanced statistical / analytics software will be used to view / manipulate data exported from the information management system",
			"Internet / app plugin will be used to view / manipulate data exported from the information management system",
			"Video player or editor will be used to view / manipulate data exported from the information management system",
			"GIS will be used to view / manipulate data exported from the information management system",
			"Database-based product will be used to view / manipulate data exported from the information management system",
			"Other external software will be used to view / manipulate data exported from the information management system, and will be entered below",
			"No decision has been made on what will be used to view / manipulate data exported from the information management system",
	"Enter any additional details in this box, including other external software that will be used to view / manipulate data exported from the information management system",
	],
113: ["Regular manual data review (for example, utility staff review data every eight hours)",
			"Automated alerts based on parameter setpoints / thresholds",
			"Automated analysis using specialized data analysis techniques / software",
			"Other methods for data analysis, and will be entered below",
			"No decision has been made on methods for data analysis",
	"Enter any additional details below, including other methods for data analysis",
	],

201: [     "An intuitive interface is not needed", 
         "An intuitive interface would be nice", 
         "An intuitive interface is highly desired", 
         "An intuitive interface is critical", 
         "Enter additional details concerning the need for an intuitive interface"],
202: [     "A quick and easy process for accessing data is not needed", 
         "A quick and easy process for accessing data Would Be Nice", 
         "A quick and easy process for accessing data is highly desired", 
         "A quick and easy process for accessing data is critical", 
         "Enter additional details concerning the need for a quick and easy process for accessing data"],

203: [     "The ability to analyze and plot data within the user interface is not needed", 
         "The ability to analyze and plot data within the user interface would be nice", 
         "The ability to analyze and plot data within the user interface is highly desired", 
         "The ability to analyze and plot data within the user interface is critical", 
         "Enter additional details concerning the need for the ability to analyze and plot data within the user interface"],
204: [     "A customizable user interface is not needed", 
         "A customizable user interface would be nice", 
         "A customizable user interface is highly desired", 
         "A customizable user interface is critical", 
         "Enter additional details concerning the need for a customizable user interface"],
205: [     "The ability to modify the user interface is not needed", 
         "The ability to modify the user interface would be nice", 
         "The ability to modify the user interface is highly desired", 
         "The ability to modify the user interface is critical", 
         "Enter additional details concerning the need for the ability to modify the user interface"],
206: [     "The ability to continuously display real-time data is not needed", 
         "The ability to continuously display real-time data would be nice", 
         "The ability to continuously display real-time data is highly desired", 
         "The ability to continuously display real-time data is critical", 
         "Enter additional details concerning the need for The ability to continuously display real-time data"],
207: [     "The ability to continuously display real-time data is not needed", 
         "The ability to continuously display real-time data would be nice", 
         "The ability to continuously display real-time data is highly desired", 
         "The ability to continuously display real-time data is critical", 
         "Enter additional details concerning the need for the ability to continuously display real-time data"],
208: [     "The ability to access data from multiple sources is not needed", 
         "The ability to access data from multiple sources would be nice", 
         "The ability to access data from multiple sources is highly desired", 
         "The ability to access data from multiple sources is critical", 
         "Enter additional details concerning the need for the ability to access data from multiple sources"],
209: [     "The ability to develop custom data entry screens is not needed", 
         "The ability to develop custom data entry screens would be nice", 
         "The ability to develop custom data entry screens is highly desired", 
         "The ability to develop custom data entry screens is critical", 
         "Enter additional details concerning the need for The ability to develop custom data entry screens"],
210: [     "GIS capability is not needed", 
         "GIS capability would be nice", 
         "GIS capability is highly desired", 
         "GIS capability is critical", 
         "Enter additional details concerning the need for GIS capability"],
211: [     "The ability to access and/or control equipment through the information management system is not needed", 
         "The ability to access and/or control equipment through the information management system would be nice", 
         "The ability to access and/or control equipment through the information management system is highly desired", 
         "The ability to access and/or control equipment through the information management system is critical", 
         "Enter additional details concerning the need for The ability to access and/or control equipment through the information management system"],
212: [     "The ability to access the interface from multiple locations is not needed", 
         "The ability to access the interface from multiple locations would be nice", 
         "The ability to access the interface from multiple locations is highly desired", 
         "The ability to access the interface from multiple locations is critical", 
         "Enter additional details concerning the need for the ability to access the interface from multiple locations"],
213: [     "Flexible access points are not needed", 
         "Flexible access points would be nice", 
         "Flexible access points are highly desired", 
         "Flexible access points are critical", 
         "Enter additional details concerning the need for flexible access points"],
214: [     "The ability to access the system from outside the utility network is not needed", 
         "The ability to access the system from outside the utility network would be nice", 
         "The ability to access the system from outside the utility network is highly desired", 
         "The ability to access the system from outside the utility network is critical", 
         "Enter additional details concerning the need for the ability to access the system from outside the utility network"],
215: [     "The ability to control user view privileges is not needed", 
         "The ability to control user view privileges would be nice", 
         "The ability to control user view privileges is highly desired", 
         "The ability to control user view privileges is critical", 
         "Enter additional details concerning the need for The ability to control user view privileges"],
216: [     "The ability to control user write privileges is not needed", 
         "The ability to control user write privileges would be nice", 
         "The ability to control user write privileges is highly desired", 
         "The ability to control user write privileges is critical", 
         "Enter additional details concerning the need for The ability to control user write privileges"],
217: [     "Individual login accounts with activity tracking are not needed", 
         "Individual login accounts with activity tracking would be nice", 
         "Individual login accounts with activity tracking are highly desired", 
         "Individual login accounts with activity tracking are critical", 
         "Enter additional details concerning the need for individual login accounts with activity tracking"],
218: [     "The ability to create custom tables is not needed", 
         "The ability to create custom tables would be nice", 
         "The ability to create custom tables is highly desired", 
         "The ability to create custom tables is critical", 
         "Enter additional details concerning the need for the ability to create custom tables"],
219: [     "The ability to save table templates is not needed", 
         "The ability to save table templates would be nice", 
         "The ability to save table templates is highly desired", 
         "The ability to save table templates is critical", 
         "Enter additional details concerning the need for The ability to save table templates"],
220: [     "The ability to generate tabular summaries of historical data is not needed", 
         "The ability to generate tabular summaries of historical data would be nice", 
         "The ability to generate tabular summaries of historical data is highly desired", 
         "The ability to generate tabular summaries of historical data is critical", 
         "Enter additional details concerning the need for the ability to generate tabular summaries of historical data"],
221: [     "The ability to include metadata in tables is not needed", 
         "The ability to include metadata in tables would be nice", 
         "The ability to include metadata in tables is highly desired", 
         "The ability to include metadata in tables is critical", 
         "Enter additional details concerning the need for the ability to include metadata in tables"],
222: [     " The ability to include data from more than one data source in tables is not needed", 
         "The ability to include data from more than one data source in tables would be nice", 
         "The ability to include data from more than one data source in tables is highly desired", 
         "The ability to include data from more than one data source in tables is critical", 
         "Enter additional details concerning the need for the ability to include data from more than one data source in tables"],
223: [     "The ability to create time-series plots is not needed", 
         "The ability to create time-series plots would be nice", 
         "The ability to create time-series plots is highly desired", 
         "The ability to create time-series plots is critical", 
         "Enter additional details concerning the need for the ability to create time-series plots"],
224: [     "The ability to create custom plots is not needed", 
         "The ability to create custom plots would be nice", 
         "The ability to create custom plots is highly desired", 
         "The ability to create custom plots is critical", 
         "Enter additional details concerning the need for the ability to create custom plots"],
225: [     "The ability to save plot templates is not needed", 
         "The ability to save plot templates would be nice", 
         "The ability to save plot templates is highly desired", 
         "The ability to save plot templates is critical", 
         "Enter additional details concerning the need for the ability to save plot templates"],
226: [     "The ability to plot more than one datastream concurrently is not needed", 
         "The ability to plot more than one datastream concurrently would be nice", 
         "The ability to plot more than one datastream concurrently is highly desired", 
         "The ability to plot more than one datastream concurrently is critical", 
         "Enter additional details concerning the need for the ability to plot more than one datastream concurrently"],
227: [     "The ability to change the period of data plotted is not needed", 
         "The ability to change the period of data plotted would be nice", 
         "The ability to change the period of data plotted is highly desired", 
         "The ability to change the period of data plotted is critical", 
         "Enter additional details concerning the need for the ability to change the period of data plotted"],
228: [     "The ability to change the period of data plotted is not needed", 
         "The ability to change the period of data plotted would be nice", 
         "The ability to change the period of data plotted is highly desired", 
         "The ability to change the period of data plotted is critical", 
         "Enter additional details concerning the need for The ability to change the period of data plotted"],
229: [     "The ability to view parameter values by clicking a trend line is not needed", 
         "The ability to view parameter values by clicking a trend line would be nice", 
         "The ability to view parameter values by clicking a trend line is highly desired", 
         "The ability to view parameter values by clicking a trend lineis critical", 
         "Enter additional details concerning the need for The ability to view parameter values by clicking a trend line"],
230: [     "The ability to maintain a consistent x-axis with inconsistent data is not needed", 
         "The ability to maintain a consistent x-axis with inconsistent data would be nice", 
         "The ability to maintain a consistent x-axis with inconsistent data is highly desired", 
         "The ability to maintain a consistent x-axis with inconsistent data is critical", 
         "Enter additional details concerning the need for The ability to maintain a consistent x-axis with inconsistent data"],
231: [     "Advanced plotting capabilities are not needed", 
         "Advanced plotting capabilities would be nice", 
         "Advanced plotting capabilities are highly desired", 
         "Advanced plotting capabilities are critical", 
         "Enter additional details concerning the need for Advanced plotting capabilities"],
232: [     "The ability to extract custom datasets from stored data is not needed", 
         "The ability to extract custom datasets from stored data would be nice", 
         "The ability to extract custom datasets from stored data is highly desired", 
         "The ability to extract custom datasets from stored data is critical", 
         "Enter additional details concerning the need for the ability to extract custom datasets from stored data"],
233: [     "The ability to export data in time-series format is not needed", 
         "The ability to export data in time-series format would be nice", 
         "The ability to export data in time-series format is highly desired", 
         "The ability to export data in time-series format is critical", 
         "Enter additional details concerning the need for the ability to export data in time-series format"],
234: [     "The ability to export data in a format that can be used by external software is not needed", 
         "The ability to export data in a format that can be used by external software would be nice", 
         "The ability to export data in a format that can be used by external software is highly desired", 
         "The ability to export data in a format that can be used by external software is critical", 
         "Enter additional details concerning the need for The ability to export data in a format that can be used by external software"],
235: [     "Alt Text is not needed", 
         "Alt Text would be nice", 
         "Alt Text is highly desired", 
         "Alt Text is critical", 
         "Enter additional details concerning the need for "],
236: [     "The ability to save report templates is not needed", 
         "The ability to save report templates would be nice", 
         "The ability to save report templates is highly desired", 
         "The ability to save report templates is critical", 
         "Enter additional details concerning the need for the ability to save report templates"],
237: [     "The ability to obtain a list of events that meet specific criteria is not needed", 
         "The ability to obtain a list of events that meet specific criteria would be nice", 
         "The ability to obtain a list of events that meet specific criteria is highly desired", 
         "The ability to obtain a list of events that meet specific criteria is critical", 
         "Enter additional details concerning the need for the ability to obtain a list of events that meet specific criteria"],
238: [     "The ability to produce alerts based on setpoints is not needed", 
         "The ability to produce alerts based on setpoints would be nice", 
         "The ability to produce alerts based on setpoints is highly desired", 
         "The ability to produce alerts based on setpoints is critical", 
         "Enter additional details concerning the need for the ability to produce alerts based on setpoints"],
239: [     "The ability to produce alerts based on thresholds for cumulative values is not needed", 
         "The ability to produce alerts based on thresholds for cumulative values would be nice", 
         "The ability to produce alerts based on thresholds for cumulative values is highly desired", 
         "The ability to produce alerts based on thresholds for cumulative values is critical", 
         "Enter additional details concerning the need for The ability to produce alerts based on thresholds for cumulative values"],
240: [     "Additional real-time analysis capabilities are not needed", 
         "Additional real-time analysis capabilities would be nice", 
         "Additional real-time analysis capabilities are highly desired", 
         "Additional real-time analysis capabilities is critical", 
         "Enter additional details concerning the need for additional real-time analysis capabilities"],
241: [     "The ability to run multiple data analysis functions concurrently is not needed", 
         "The ability to run multiple data analysis functions concurrently would be nice", 
         "The ability to run multiple data analysis functions concurrently is highly desired", 
         "The ability to run multiple data analysis functions concurrently is critical", 
         "Enter additional details concerning the need for The ability to run multiple data analysis functions concurrently"],
242: [     "The ability to enter advanced alerting logic is not needed", 
         "The ability to enter advanced alerting logic would be nice", 
         "The ability to enter advanced alerting logic is highly desired", 
         "The ability to enter advanced alerting logic is critical", 
         "Enter additional details concerning the need for the ability to enter advanced alerting logic"],
243: [     "The ability to convey alerts through the user interface is not needed", 
         "The ability to convey alerts through the user interface would be nice", 
         "The ability to convey alerts through the user interface is highly desired", 
         "The ability to convey alerts through the user interface is critical", 
         "Enter additional details concerning the need for the ability to convey alerts through the user interface"],
244: [     "The ability to automatically transmit alerts alerts to appropriate personnel is not needed", 
         "The ability to automatically transmit alerts alerts to appropriate personnel would be nice", 
         "The ability to automatically transmit alerts alerts to appropriate personnel is highly desired", 
         "The ability to automatically transmit alerts alerts to appropriate personnel is critical", 
         "Enter additional details concerning the need for the ability to automatically transmit alerts alerts to appropriate personnel"],
245: [     "The ability to include supplemental information in alert notifications is not needed", 
         "The ability to include supplemental information in alert notifications would be nice", 
         "The ability to include supplemental information in alert notifications is highly desired", 
         "The ability to include supplemental information in alert notifications is critical", 
         "Enter additional details concerning the need for The ability to include supplemental information in alert notifications"],
246: [     "The ability to enter advanced alert notification logic is not needed", 
         "The ability to enter advanced alert notification logic would be nice", 
         "The ability to enter advanced alert notification logic is highly desired", 
         "The ability to enter advanced alert notification logic is critical", 
         "Enter additional details concerning the need for the ability to enter advanced alert notification logic"],
247: [     "The ability to require alert acknowledgement is not needed", 
         "The ability to require alert acknowledgement would be nice", 
         "The ability to require alert acknowledgement is highly desired", 
         "The ability to require alert acknowledgement is critical", 
         "Enter additional details concerning the need for the ability to require alert acknowledgement"],
248: [     "The ability to enter alert investigation details is not needed", 
         "The ability to enter alert investigation details would be nice", 
         "The ability to enter alert investigation details is highly desired", 
         "The ability to enter alert investigation details is critical", 
         "Enter additional details concerning the need for The ability to enter alert investigation details"],
249: [     "The ability to test data analysis tools using historical data is not needed", 
         "The ability to test data analysis tools using historical data would be nice", 
         "The ability to test data analysis tools using historical data is highly desired", 
         "The ability to test data analysis tools using historical data is critical", 
         "Enter additional details concerning the need for The ability to test data analysis tools using historical data"],
250: [     "Easy access to archived data is not needed", 
         "Easy access to archived data would be nice", 
         "Easy access to archived data is highly desired", 
         "Easy access to archived data is critical", 
         "Enter additional details concerning the need for easy access to archived data"],
251: [     "Data security is not needed", 
         "Data security would be nice", 
         "Data security is highly desired", 
         "Data security is critical", 
         "Enter additional details concerning the need for data security"],
252: [     "The ability to store time-stamped user comments for datastreams is not needed", 
         "The ability to store time-stamped user comments for datastreams would be nice", 
         "The ability to store time-stamped user comments for datastreams is highly desired", 
         "The ability to store time-stamped user comments for datastreams is critical", 
         "Enter additional details concerning the need for the ability to store time-stamped user comments for datastreams"],
253: [     "Automatic assignment of data quality value is not needed", 
         "Automatic assignment of data quality value would be nice", 
         "Automatic assignment of data quality value is highly desired", 
         "Automatic assignment of data quality value is critical", 
         "Enter additional details concerning the need for automatic assignment of data quality value"],
254: [     "Automatic data cleaning and smoothing functionality is not needed", 
         "Automatic data cleaning and smoothing functionality would be nice", 
         "Automatic data cleaning and smoothing functionality is highly desired", 
         "Automatic data cleaning and smoothing functionality is critical", 
         "Enter additional details concerning the need for automatic data cleaning and smoothing functionality"],
255: [     "The ability to add or modify datastreams is not needed", 
         "The ability to add or modify datastreams would be nice", 
         "The ability to add or modify datastreams is highly desired", 
         "The ability to add or modify datastreams is critical", 
         "Enter additional details concerning the need for the ability to add or modify datastreams"],

/* SYSTEM TECHNICAL REQUIREMENTS RANGE 500+ */
501: [	"Basic programming expertise is acceptable for implementing the system",
			"Intermediate programming expertise is acceptable for implementing the system",
			"Advanced programming expertise is acceptable for implementing the system",
      "Enter any additional details in this box"],
502: 
		[	"Fully in-house system troubleshooting and maintenance is acceptable",
			"In-house with external support system troubleshooting and maintenance is acceptable",
			"Full maintenance by an outside entity system troubleshooting and maintenance is acceptable",
	"Enter any additional details in this box"
	],
503: ["Yes, there is minimum acceptable timeframe for full system recovery",
     "No, there is not a minimum acceptable timeframe for system recovery",
     "Enter a numeric time value acceptable for full system recovery",
	"Enter any additional details in this box"
	],
504: ["text2", "Software and systems compatibility",
	"List software and systems the information management system must be compatible with.",
	"<p>List software and systems the information management system must be compatible with.  Examples of such systems include:</p> \
	<p><ul>\
<li>Systems storing information that must be available through the information management system, such as LIMS, SCADA or call management systems</li>\
<li>Software products that will be used to view or manipulate data, such as event detection algorithms, Microsoft Excel or a statistical software package</li>\
<li>Systems used to build or display the user interface, such as GIS, web browsers and plug-ins</li>\
</ul></p>",
	"List all systems here:",
	"Enter any additional details in this box"
	],
505: ["List hardware requirements for the system here.",
	"Enter any additional details in this box"
	],
506: ["Yes, there are constraints that would affect remote access settings",
     "No, there are not any constraints that would affect remote access settings",
	"Define contraints that would affect remote access settings and provide additional details:"
	],
507: [
     "Yes, offsite data storage a viable option?",
	   "No, offsite data storage is not a viable option",
	"Enter any additional details in this box"
	],
508: [	"Data pushed to the system is acceptable for data transfer",
			"Data queried by the system is acceptable for data transfer",
			"Direct connection with bi-directional flow of data is acceptable for data transfer",
	"Enter any additional details in this box"
	],

531: [     "Efficient handling of time-series data is not needed", 
         "Efficient handling of time-series data would be nice", 
         "Efficient handling of time-series data is highly desired", 
         "Efficient handling of time-series data is critical", 
         "Enter additional details concerning the need for efficient handling of time-series data"],
532: [     "Cybersecurity measures is not needed", 
         "Cybersecurity measures would be nice", 
         "Cybersecurity measures are highly desired", 
         "Cybersecurity measures are critical", 
         "Enter additional details concerning the need for cybersecurity ,easures"],
533: [     "Automatic backup is not needed", 
         "Automatic backup would be nice", 
         "Automatic backup is highly desired", 
         "Automatic backup is critical", 
         "Enter additional details concerning the need for automatic backup"],
534: 
	[     "The ability to implement a failover system is not needed", 
         "The ability to implement a failover system would be nice", 
         "The ability to implement a failover system is highly desired", 
         "The ability to implement a failover system is critical", 
         "Enter additional details concerning the need for the ability to implement a failover system"
	],
535: [     "The ability to hot swap system components is not needed", 
         "The ability to hot swap system components would be nice", 
         "The ability to hot swap system components is highly desired", 
         "The ability to hot swap system components is critical", 
         "Enter additional details concerning the need for the ability to hot swap system components"],
536: [     "Administrator accounts are not needed", 
         "Administrator accounts would be nice", 
         "Administrator accounts are highly desired", 
         "Administrator accounts are critical", 
         "Enter additional details concerning the need for administrator accounts"],
537: [     "The ability to restrict user read and write privileges is not needed", 
         "The ability to restrict user read and write privileges would be nice", 
         "The ability to restrict user read and write privileges is highly desired", 
         "The ability to restrict user read and write privileges is critical", 
         "Enter additional details concerning the need for the ability to restrict user read and write privileges"],
538: [     "The ability to log or monitor user activity is not needed", 
         "The ability to log or monitor user activity would be nice", 
         "The ability to log or monitor user activity is highly desired", 
         "The ability to log or monitor user activity is critical", 
         "Enter additional details concerning the need for the ability to log or monitor user activity"],
539: [     "The ability to easily manage user accounts is not needed", 
         "The ability to easily manage user accounts would be nice", 
         "The ability to easily manage user accounts is highly desired", 
         "The ability to easily manage user accounts is critical", 
         "Enter additional details concerning the need for the ability to easily manage user accounts"],
540: [     "The ability to easily modify the user interface is not needed", 
         "The ability to easily modify the user interface would be nice", 
         "The ability to easily modify the user interface is highly desired", 
         "The ability to easily modify the user interface is critical", 
         "Enter additional details concerning the need for the ability to easily modify the user interface"],
541: [     "The ability to easily modify data elements is not needed", 
         "The ability to easily modify data elements would be nice", 
         "The ability to easily modify data elements is highly desired", 
         "The ability to easily modify data elements is critical", 
         "Enter additional details concerning the need for the ability to easily modify data elements"],
542: [     "The ability to easily modify data elements is not needed", 
         "The ability to easily modify data elements would be nice", 
         "The ability to easily modify data elements is highly desired", 
         "The ability to easily modify data elements is critical", 
         "Enter additional details concerning the need for the ability to easily modify data elements"],
543: [     "Open architecture database is not needed", 
         "Open architecture database would be nice", 
         "Open architecture database is highly desired", 
         "Open architecture database is critical", 
         "Enter additional details concerning the need for open architecture database"],
544: [     "Unlimited seat licenses are not needed", 
         "Unlimited seat licenses would be nice", 
         "Unlimited seat licenses are highly desired", 
         "Unlimited seat licenses are critical", 
         "Enter additional details concerning the need for Unlimited seat licenses"],
545: [     "Unlimited data elements are not needed", 
         "Unlimited data elements would be nice", 
         "Unlimited data elements are highly desired", 
         "Unlimited data elements are critical", 
         "Enter additional details concerning the need for unlimited data elements"],
546: [     "The ability to generate system diagnostic reports is not needed", 
         "The ability to generate system diagnostic reports would be nice", 
         "The ability to generate system diagnostic reports is highly desired", 
         "The ability to generate system diagnostic reports is critical", 
         "Enter additional details concerning the need for the ability to generate system diagnostic reports"],
547: [     "The ability to receive automatic storage capacity notifications is not needed", 
         "The ability to receive automatic storage capacity notifications would be nice", 
         "The ability to receive automatic storage capacity notifications is highly desired", 
         "The ability to receive automatic storage capacity notifications is critical", 
         "Enter additional details concerning the need for the ability to receive automatic storage capacity notifications"],
548: [     "The ability to receive automatic notification of system malfunction is not needed", 
         "The ability to receive automatic notification of system malfunction would be nice", 
         "The ability to receive automatic notification of system malfunction is highly desired", 
         "The ability to receive automatic notification of system malfunction is critical", 
         "Enter additional details concerning the need for the ability to receive automatic notification of system malfunction"],
549: [     "The ability to receive processing time notification is not needed", 
         "The ability to receive processing time notification would be nice", 
         "The ability to receive processing time notification is highly desired", 
         "The ability to receive processing time notification is critical", 
         "Enter additional details concerning the need for the ability to receive processing time notification"],
550: [     "The ability to test connectivity with remote sites is not needed", 
         "The ability to test connectivity with remote sites would be nice", 
         "The ability to test connectivity with remote sites is highly desired", 
         "The ability to test connectivity with remote sites is critical", 
         "Enter additional details concerning the need for the ability to test connectivity with remote sites"],
551: [     "Real-time routine troubleshooting is not needed", 
         "Real-time routine troubleshooting would be nice", 
         "Real-time routine troubleshooting is highly desired", 
         "Real-time routine troubleshooting is critical", 
         "Enter additional details concerning the need for real-time routine troubleshooting"],
552: [     "Prompt resolution of significant issues is not needed", 
         "Prompt resolution of significant issues would be nice", 
         "Prompt resolution of significant issues is highly desired", 
         "Prompt resolution of significant issues is critical", 
         "Enter additional details concerning the need for prompt resolution of significant issues"],
553: [     "Vendor-provided training is not needed", 
         "Vendor-provided training would be nice", 
         "Vendor-provided training is highly desired", 
         "Vendor-provided trainingt is critical", 
         "Enter additional details concerning the need for vendor-provided training"],
554: [     "Full product warranty and support available is not needed", 
         "Full product warranty and support available would be nice", 
         "Full product warranty and support available is highly desired", 
         "Full product warranty and support available is critical", 
         "Enter additional details concerning the need for full product warranty and support available"]
};
